Class: Google::Apis::DocsV1::DateElement

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

A date instance mentioned in a document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DateElement

Returns a new instance of DateElement.



787
788
789
# File 'lib/google/apis/docs_v1/classes.rb', line 787

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#date_element_propertiesGoogle::Apis::DocsV1::DateElementProperties

Properties of a DateElement. Corresponds to the JSON property dateElementProperties



741
742
743
# File 'lib/google/apis/docs_v1/classes.rb', line 741

def date_element_properties
  @date_element_properties
end

#date_idString

Output only. The unique ID of this date. Corresponds to the JSON property dateId

Returns:

  • (String)


746
747
748
# File 'lib/google/apis/docs_v1/classes.rb', line 746

def date_id
  @date_id
end

#suggested_date_element_properties_changesHash<String,Google::Apis::DocsV1::SuggestedDateElementProperties>

The suggested changes to the date element properties, keyed by suggestion ID. Corresponds to the JSON property suggestedDateElementPropertiesChanges



751
752
753
# File 'lib/google/apis/docs_v1/classes.rb', line 751

def suggested_date_element_properties_changes
  @suggested_date_element_properties_changes
end

#suggested_deletion_idsArray<String>

IDs for suggestions that remove this date from the document. A DateElement might have multiple deletion IDs if, for example, multiple users suggest deleting it. If empty, then this date isn't suggested for deletion. Corresponds to the JSON property suggestedDeletionIds

Returns:

  • (Array<String>)


758
759
760
# File 'lib/google/apis/docs_v1/classes.rb', line 758

def suggested_deletion_ids
  @suggested_deletion_ids
end

#suggested_insertion_idsArray<String>

IDs for suggestions that insert this date into the document. A DateElement might have multiple insertion IDs if it's a nested suggested change (a suggestion within a suggestion made by a different user, for example). If empty, then this date isn't a suggested insertion. Corresponds to the JSON property suggestedInsertionIds

Returns:

  • (Array<String>)


766
767
768
# File 'lib/google/apis/docs_v1/classes.rb', line 766

def suggested_insertion_ids
  @suggested_insertion_ids
end

#suggested_text_style_changesHash<String,Google::Apis::DocsV1::SuggestedTextStyle>

The suggested text style changes to this DateElement, keyed by suggestion ID. Corresponds to the JSON property suggestedTextStyleChanges



771
772
773
# File 'lib/google/apis/docs_v1/classes.rb', line 771

def suggested_text_style_changes
  @suggested_text_style_changes
end

#text_styleGoogle::Apis::DocsV1::TextStyle

Represents the styling that can be applied to text. Inherited text styles are represented as unset fields in this message. A text style's parent depends on where the text style is defined: * The TextStyle of text in a Paragraph inherits from the paragraph's corresponding named style type. * The TextStyle on a named style inherits from the normal text named style. * The TextStyle of the normal text named style inherits from the default text style in the Docs editor. * The TextStyle on a Paragraph element that's contained in a table may inherit its text style from the table style. If the text style does not inherit from a parent, unsetting fields will revert the style to a value matching the defaults in the Docs editor. Corresponds to the JSON property textStyle



785
786
787
# File 'lib/google/apis/docs_v1/classes.rb', line 785

def text_style
  @text_style
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



792
793
794
795
796
797
798
799
800
# File 'lib/google/apis/docs_v1/classes.rb', line 792

def update!(**args)
  @date_element_properties = args[:date_element_properties] if args.key?(:date_element_properties)
  @date_id = args[:date_id] if args.key?(:date_id)
  @suggested_date_element_properties_changes = args[:suggested_date_element_properties_changes] if args.key?(:suggested_date_element_properties_changes)
  @suggested_deletion_ids = args[:suggested_deletion_ids] if args.key?(:suggested_deletion_ids)
  @suggested_insertion_ids = args[:suggested_insertion_ids] if args.key?(:suggested_insertion_ids)
  @suggested_text_style_changes = args[:suggested_text_style_changes] if args.key?(:suggested_text_style_changes)
  @text_style = args[:text_style] if args.key?(:text_style)
end