Class: Google::Apis::DocsV1::DeleteHeaderRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Deletes a Header from the document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeleteHeaderRequest

Returns a new instance of DeleteHeaderRequest.



1000
1001
1002
# File 'lib/google/apis/docs_v1/classes.rb', line 1000

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#header_idString

The id of the header to delete. If this header is defined on DocumentStyle, the reference to this header is removed, resulting in no header of that type for the first section of the document. If this header is defined on a SectionStyle, the reference to this header is removed and the header of that type is now continued from the previous section. Corresponds to the JSON property headerId

Returns:

  • (String)


988
989
990
# File 'lib/google/apis/docs_v1/classes.rb', line 988

def header_id
  @header_id
end

#tab_idString

The tab containing the header to delete. When omitted, the request is applied to the first tab. In a document containing a single tab: - If provided, must match the singular tab's ID. - If omitted, the request applies to the singular tab. In a document containing multiple tabs: - If provided, the request applies to the specified tab. - If omitted, the request applies to the first tab in the document. Corresponds to the JSON property tabId

Returns:

  • (String)


998
999
1000
# File 'lib/google/apis/docs_v1/classes.rb', line 998

def tab_id
  @tab_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1005
1006
1007
1008
# File 'lib/google/apis/docs_v1/classes.rb', line 1005

def update!(**args)
  @header_id = args[:header_id] if args.key?(:header_id)
  @tab_id = args[:tab_id] if args.key?(:tab_id)
end