Class: Google::Apis::DocsV1::DeleteNamedRangeRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Deletes a NamedRange.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeleteNamedRangeRequest

Returns a new instance of DeleteNamedRangeRequest.



1025
1026
1027
# File 'lib/google/apis/docs_v1/classes.rb', line 1025

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the range(s) to delete. All named ranges with the given name will be deleted. Corresponds to the JSON property name

Returns:

  • (String)


1013
1014
1015
# File 'lib/google/apis/docs_v1/classes.rb', line 1013

def name
  @name
end

#named_range_idString

The ID of the named range to delete. Corresponds to the JSON property namedRangeId

Returns:

  • (String)


1018
1019
1020
# File 'lib/google/apis/docs_v1/classes.rb', line 1018

def named_range_id
  @named_range_id
end

#tabs_criteriaGoogle::Apis::DocsV1::TabsCriteria

A criteria that specifies in which tabs a request executes. Corresponds to the JSON property tabsCriteria



1023
1024
1025
# File 'lib/google/apis/docs_v1/classes.rb', line 1023

def tabs_criteria
  @tabs_criteria
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1030
1031
1032
1033
1034
# File 'lib/google/apis/docs_v1/classes.rb', line 1030

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @named_range_id = args[:named_range_id] if args.key?(:named_range_id)
  @tabs_criteria = args[:tabs_criteria] if args.key?(:tabs_criteria)
end