Class: Google::Apis::DocsV1::DeleteParagraphBulletsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Deletes bullets from all of the paragraphs that overlap with the given range. The nesting level of each paragraph will be visually preserved by adding indent to the start of the corresponding paragraph.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeleteParagraphBulletsRequest



1053
1054
1055
# File 'lib/google/apis/docs_v1/classes.rb', line 1053

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rangeGoogle::Apis::DocsV1::Range

Specifies a contiguous range of text. Corresponds to the JSON property range



1051
1052
1053
# File 'lib/google/apis/docs_v1/classes.rb', line 1051

def range
  @range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1058
1059
1060
# File 'lib/google/apis/docs_v1/classes.rb', line 1058

def update!(**args)
  @range = args[:range] if args.key?(:range)
end