Class: Google::Apis::DocsV1::DocumentStyleSuggestionState
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::DocumentStyleSuggestionState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
A mask that indicates which of the fields on the base DocumentStyle have been changed in this suggestion. For any field set to true, there's a new suggested value.
Instance Attribute Summary collapse
-
#background_suggestion_state ⇒ Google::Apis::DocsV1::BackgroundSuggestionState
A mask that indicates which of the fields on the base Background have been changed in this suggestion.
-
#default_footer_id_suggested ⇒ Boolean
(also: #default_footer_id_suggested?)
Indicates if there was a suggested change to default_footer_id.
-
#default_header_id_suggested ⇒ Boolean
(also: #default_header_id_suggested?)
Indicates if there was a suggested change to default_header_id.
-
#even_page_footer_id_suggested ⇒ Boolean
(also: #even_page_footer_id_suggested?)
Indicates if there was a suggested change to even_page_footer_id.
-
#even_page_header_id_suggested ⇒ Boolean
(also: #even_page_header_id_suggested?)
Indicates if there was a suggested change to even_page_header_id.
-
#first_page_footer_id_suggested ⇒ Boolean
(also: #first_page_footer_id_suggested?)
Indicates if there was a suggested change to first_page_footer_id.
-
#first_page_header_id_suggested ⇒ Boolean
(also: #first_page_header_id_suggested?)
Indicates if there was a suggested change to first_page_header_id.
-
#flip_page_orientation_suggested ⇒ Boolean
(also: #flip_page_orientation_suggested?)
Optional.
-
#margin_bottom_suggested ⇒ Boolean
(also: #margin_bottom_suggested?)
Indicates if there was a suggested change to margin_bottom.
-
#margin_footer_suggested ⇒ Boolean
(also: #margin_footer_suggested?)
Indicates if there was a suggested change to margin_footer.
-
#margin_header_suggested ⇒ Boolean
(also: #margin_header_suggested?)
Indicates if there was a suggested change to margin_header.
-
#margin_left_suggested ⇒ Boolean
(also: #margin_left_suggested?)
Indicates if there was a suggested change to margin_left.
-
#margin_right_suggested ⇒ Boolean
(also: #margin_right_suggested?)
Indicates if there was a suggested change to margin_right.
-
#margin_top_suggested ⇒ Boolean
(also: #margin_top_suggested?)
Indicates if there was a suggested change to margin_top.
-
#page_number_start_suggested ⇒ Boolean
(also: #page_number_start_suggested?)
Indicates if there was a suggested change to page_number_start.
-
#page_size_suggestion_state ⇒ Google::Apis::DocsV1::SizeSuggestionState
A mask that indicates which of the fields on the base Size have been changed in this suggestion.
-
#use_custom_header_footer_margins_suggested ⇒ Boolean
(also: #use_custom_header_footer_margins_suggested?)
Indicates if there was a suggested change to use_custom_header_footer_margins.
-
#use_even_page_header_footer_suggested ⇒ Boolean
(also: #use_even_page_header_footer_suggested?)
Indicates if there was a suggested change to use_even_page_header_footer.
-
#use_first_page_header_footer_suggested ⇒ Boolean
(also: #use_first_page_header_footer_suggested?)
Indicates if there was a suggested change to use_first_page_header_footer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DocumentStyleSuggestionState
constructor
A new instance of DocumentStyleSuggestionState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DocumentStyleSuggestionState
Returns a new instance of DocumentStyleSuggestionState.
1652 1653 1654 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1652 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background_suggestion_state ⇒ Google::Apis::DocsV1::BackgroundSuggestionState
A mask that indicates which of the fields on the base Background have been
changed in this suggestion. For any field set to true, the Backgound has a new
suggested value.
Corresponds to the JSON property backgroundSuggestionState
1541 1542 1543 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1541 def background_suggestion_state @background_suggestion_state end |
#default_footer_id_suggested ⇒ Boolean Also known as:
Indicates if there was a suggested change to default_footer_id.
Corresponds to the JSON property defaultFooterIdSuggested
1546 1547 1548 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1546 def @default_footer_id_suggested end |
#default_header_id_suggested ⇒ Boolean Also known as: default_header_id_suggested?
Indicates if there was a suggested change to default_header_id.
Corresponds to the JSON property defaultHeaderIdSuggested
1552 1553 1554 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1552 def default_header_id_suggested @default_header_id_suggested end |
#even_page_footer_id_suggested ⇒ Boolean Also known as:
Indicates if there was a suggested change to even_page_footer_id.
Corresponds to the JSON property evenPageFooterIdSuggested
1558 1559 1560 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1558 def @even_page_footer_id_suggested end |
#even_page_header_id_suggested ⇒ Boolean Also known as: even_page_header_id_suggested?
Indicates if there was a suggested change to even_page_header_id.
Corresponds to the JSON property evenPageHeaderIdSuggested
1564 1565 1566 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1564 def even_page_header_id_suggested @even_page_header_id_suggested end |
#first_page_footer_id_suggested ⇒ Boolean Also known as:
Indicates if there was a suggested change to first_page_footer_id.
Corresponds to the JSON property firstPageFooterIdSuggested
1570 1571 1572 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1570 def @first_page_footer_id_suggested end |
#first_page_header_id_suggested ⇒ Boolean Also known as: first_page_header_id_suggested?
Indicates if there was a suggested change to first_page_header_id.
Corresponds to the JSON property firstPageHeaderIdSuggested
1576 1577 1578 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1576 def first_page_header_id_suggested @first_page_header_id_suggested end |
#flip_page_orientation_suggested ⇒ Boolean Also known as: flip_page_orientation_suggested?
Optional. Indicates if there was a suggested change to flip_page_orientation.
Corresponds to the JSON property flipPageOrientationSuggested
1582 1583 1584 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1582 def flip_page_orientation_suggested @flip_page_orientation_suggested end |
#margin_bottom_suggested ⇒ Boolean Also known as: margin_bottom_suggested?
Indicates if there was a suggested change to margin_bottom.
Corresponds to the JSON property marginBottomSuggested
1588 1589 1590 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1588 def margin_bottom_suggested @margin_bottom_suggested end |
#margin_footer_suggested ⇒ Boolean Also known as:
Indicates if there was a suggested change to margin_footer.
Corresponds to the JSON property marginFooterSuggested
1594 1595 1596 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1594 def @margin_footer_suggested end |
#margin_header_suggested ⇒ Boolean Also known as: margin_header_suggested?
Indicates if there was a suggested change to margin_header.
Corresponds to the JSON property marginHeaderSuggested
1600 1601 1602 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1600 def margin_header_suggested @margin_header_suggested end |
#margin_left_suggested ⇒ Boolean Also known as: margin_left_suggested?
Indicates if there was a suggested change to margin_left.
Corresponds to the JSON property marginLeftSuggested
1606 1607 1608 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1606 def margin_left_suggested @margin_left_suggested end |
#margin_right_suggested ⇒ Boolean Also known as: margin_right_suggested?
Indicates if there was a suggested change to margin_right.
Corresponds to the JSON property marginRightSuggested
1612 1613 1614 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1612 def margin_right_suggested @margin_right_suggested end |
#margin_top_suggested ⇒ Boolean Also known as: margin_top_suggested?
Indicates if there was a suggested change to margin_top.
Corresponds to the JSON property marginTopSuggested
1618 1619 1620 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1618 def margin_top_suggested @margin_top_suggested end |
#page_number_start_suggested ⇒ Boolean Also known as: page_number_start_suggested?
Indicates if there was a suggested change to page_number_start.
Corresponds to the JSON property pageNumberStartSuggested
1624 1625 1626 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1624 def page_number_start_suggested @page_number_start_suggested end |
#page_size_suggestion_state ⇒ Google::Apis::DocsV1::SizeSuggestionState
A mask that indicates which of the fields on the base Size have been changed
in this suggestion. For any field set to true, the Size has a new suggested
value.
Corresponds to the JSON property pageSizeSuggestionState
1632 1633 1634 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1632 def page_size_suggestion_state @page_size_suggestion_state end |
#use_custom_header_footer_margins_suggested ⇒ Boolean Also known as:
Indicates if there was a suggested change to use_custom_header_footer_margins.
Corresponds to the JSON property useCustomHeaderFooterMarginsSuggested
1637 1638 1639 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1637 def @use_custom_header_footer_margins_suggested end |
#use_even_page_header_footer_suggested ⇒ Boolean Also known as:
Indicates if there was a suggested change to use_even_page_header_footer.
Corresponds to the JSON property useEvenPageHeaderFooterSuggested
1643 1644 1645 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1643 def @use_even_page_header_footer_suggested end |
#use_first_page_header_footer_suggested ⇒ Boolean Also known as:
Indicates if there was a suggested change to use_first_page_header_footer.
Corresponds to the JSON property useFirstPageHeaderFooterSuggested
1649 1650 1651 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1649 def @use_first_page_header_footer_suggested end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1657 def update!(**args) @background_suggestion_state = args[:background_suggestion_state] if args.key?(:background_suggestion_state) @default_footer_id_suggested = args[:default_footer_id_suggested] if args.key?(:default_footer_id_suggested) @default_header_id_suggested = args[:default_header_id_suggested] if args.key?(:default_header_id_suggested) @even_page_footer_id_suggested = args[:even_page_footer_id_suggested] if args.key?(:even_page_footer_id_suggested) @even_page_header_id_suggested = args[:even_page_header_id_suggested] if args.key?(:even_page_header_id_suggested) @first_page_footer_id_suggested = args[:first_page_footer_id_suggested] if args.key?(:first_page_footer_id_suggested) @first_page_header_id_suggested = args[:first_page_header_id_suggested] if args.key?(:first_page_header_id_suggested) @flip_page_orientation_suggested = args[:flip_page_orientation_suggested] if args.key?(:flip_page_orientation_suggested) @margin_bottom_suggested = args[:margin_bottom_suggested] if args.key?(:margin_bottom_suggested) @margin_footer_suggested = args[:margin_footer_suggested] if args.key?(:margin_footer_suggested) @margin_header_suggested = args[:margin_header_suggested] if args.key?(:margin_header_suggested) @margin_left_suggested = args[:margin_left_suggested] if args.key?(:margin_left_suggested) @margin_right_suggested = args[:margin_right_suggested] if args.key?(:margin_right_suggested) @margin_top_suggested = args[:margin_top_suggested] if args.key?(:margin_top_suggested) @page_number_start_suggested = args[:page_number_start_suggested] if args.key?(:page_number_start_suggested) @page_size_suggestion_state = args[:page_size_suggestion_state] if args.key?(:page_size_suggestion_state) @use_custom_header_footer_margins_suggested = args[:use_custom_header_footer_margins_suggested] if args.key?(:use_custom_header_footer_margins_suggested) @use_even_page_header_footer_suggested = args[:use_even_page_header_footer_suggested] if args.key?(:use_even_page_header_footer_suggested) @use_first_page_header_footer_suggested = args[:use_first_page_header_footer_suggested] if args.key?(:use_first_page_header_footer_suggested) end |