Class: Google::Apis::DocsV1::EmbeddedObject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

An embedded object in the document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EmbeddedObject

Returns a new instance of EmbeddedObject.



1861
1862
1863
# File 'lib/google/apis/docs_v1/classes.rb', line 1861

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

The description of the embedded object. The title and description are both combined to display alt text. Corresponds to the JSON property description

Returns:

  • (String)


1806
1807
1808
# File 'lib/google/apis/docs_v1/classes.rb', line 1806

def description
  @description
end

#embedded_drawing_propertiesGoogle::Apis::DocsV1::EmbeddedDrawingProperties

The properties of an embedded drawing and used to differentiate the object type. An embedded drawing is one that's created and edited within a document. Note that extensive details are not supported. Corresponds to the JSON property embeddedDrawingProperties



1813
1814
1815
# File 'lib/google/apis/docs_v1/classes.rb', line 1813

def embedded_drawing_properties
  @embedded_drawing_properties
end

#embedded_object_borderGoogle::Apis::DocsV1::EmbeddedObjectBorder

A border around an EmbeddedObject. Corresponds to the JSON property embeddedObjectBorder



1818
1819
1820
# File 'lib/google/apis/docs_v1/classes.rb', line 1818

def embedded_object_border
  @embedded_object_border
end

#image_propertiesGoogle::Apis::DocsV1::ImageProperties

The properties of an image. Corresponds to the JSON property imageProperties



1823
1824
1825
# File 'lib/google/apis/docs_v1/classes.rb', line 1823

def image_properties
  @image_properties
end

#linked_content_referenceGoogle::Apis::DocsV1::LinkedContentReference

A reference to the external linked source content. Corresponds to the JSON property linkedContentReference



1828
1829
1830
# File 'lib/google/apis/docs_v1/classes.rb', line 1828

def linked_content_reference
  @linked_content_reference
end

#margin_bottomGoogle::Apis::DocsV1::Dimension

A magnitude in a single direction in the specified units. Corresponds to the JSON property marginBottom



1833
1834
1835
# File 'lib/google/apis/docs_v1/classes.rb', line 1833

def margin_bottom
  @margin_bottom
end

#margin_leftGoogle::Apis::DocsV1::Dimension

A magnitude in a single direction in the specified units. Corresponds to the JSON property marginLeft



1838
1839
1840
# File 'lib/google/apis/docs_v1/classes.rb', line 1838

def margin_left
  @margin_left
end

#margin_rightGoogle::Apis::DocsV1::Dimension

A magnitude in a single direction in the specified units. Corresponds to the JSON property marginRight



1843
1844
1845
# File 'lib/google/apis/docs_v1/classes.rb', line 1843

def margin_right
  @margin_right
end

#margin_topGoogle::Apis::DocsV1::Dimension

A magnitude in a single direction in the specified units. Corresponds to the JSON property marginTop



1848
1849
1850
# File 'lib/google/apis/docs_v1/classes.rb', line 1848

def margin_top
  @margin_top
end

#sizeGoogle::Apis::DocsV1::Size

A width and height. Corresponds to the JSON property size



1853
1854
1855
# File 'lib/google/apis/docs_v1/classes.rb', line 1853

def size
  @size
end

#titleString

The title of the embedded object. The title and description are both combined to display alt text. Corresponds to the JSON property title

Returns:

  • (String)


1859
1860
1861
# File 'lib/google/apis/docs_v1/classes.rb', line 1859

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
# File 'lib/google/apis/docs_v1/classes.rb', line 1866

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @embedded_drawing_properties = args[:embedded_drawing_properties] if args.key?(:embedded_drawing_properties)
  @embedded_object_border = args[:embedded_object_border] if args.key?(:embedded_object_border)
  @image_properties = args[:image_properties] if args.key?(:image_properties)
  @linked_content_reference = args[:linked_content_reference] if args.key?(:linked_content_reference)
  @margin_bottom = args[:margin_bottom] if args.key?(:margin_bottom)
  @margin_left = args[:margin_left] if args.key?(:margin_left)
  @margin_right = args[:margin_right] if args.key?(:margin_right)
  @margin_top = args[:margin_top] if args.key?(:margin_top)
  @size = args[:size] if args.key?(:size)
  @title = args[:title] if args.key?(:title)
end