Class: Google::Apis::DocsV1::ImageProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

The properties of an image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageProperties

Returns a new instance of ImageProperties.



2382
2383
2384
# File 'lib/google/apis/docs_v1/classes.rb', line 2382

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#angleFloat

The clockwise rotation angle of the image, in radians. Corresponds to the JSON property angle

Returns:

  • (Float)


2337
2338
2339
# File 'lib/google/apis/docs_v1/classes.rb', line 2337

def angle
  @angle
end

#brightnessFloat

The brightness effect of the image. The value should be in the interval [-1.0, 1.0], where 0 means no effect. Corresponds to the JSON property brightness

Returns:

  • (Float)


2343
2344
2345
# File 'lib/google/apis/docs_v1/classes.rb', line 2343

def brightness
  @brightness
end

#content_uriString

A URI to the image with a default lifetime of 30 minutes. This URI is tagged with the account of the requester. Anyone with the URI effectively accesses the image as the original requester. Access to the image may be lost if the document's sharing settings change. Corresponds to the JSON property contentUri

Returns:

  • (String)


2351
2352
2353
# File 'lib/google/apis/docs_v1/classes.rb', line 2351

def content_uri
  @content_uri
end

#contrastFloat

The contrast effect of the image. The value should be in the interval [-1.0, 1. 0], where 0 means no effect. Corresponds to the JSON property contrast

Returns:

  • (Float)


2357
2358
2359
# File 'lib/google/apis/docs_v1/classes.rb', line 2357

def contrast
  @contrast
end

#crop_propertiesGoogle::Apis::DocsV1::CropProperties

The crop properties of an image. The crop rectangle is represented using fractional offsets from the original content's 4 edges. - If the offset is in the interval (0, 1), the corresponding edge of crop rectangle is positioned inside of the image's original bounding rectangle. - If the offset is negative or greater than 1, the corresponding edge of crop rectangle is positioned outside of the image's original bounding rectangle. - If all offsets and rotation angles are 0, the image is not cropped. Corresponds to the JSON property cropProperties



2368
2369
2370
# File 'lib/google/apis/docs_v1/classes.rb', line 2368

def crop_properties
  @crop_properties
end

#source_uriString

The source URI is the URI used to insert the image. The source URI can be empty. Corresponds to the JSON property sourceUri

Returns:

  • (String)


2374
2375
2376
# File 'lib/google/apis/docs_v1/classes.rb', line 2374

def source_uri
  @source_uri
end

#transparencyFloat

The transparency effect of the image. The value should be in the interval [0.0, 1.0], where 0 means no effect and 1 means transparent. Corresponds to the JSON property transparency

Returns:

  • (Float)


2380
2381
2382
# File 'lib/google/apis/docs_v1/classes.rb', line 2380

def transparency
  @transparency
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2387
2388
2389
2390
2391
2392
2393
2394
2395
# File 'lib/google/apis/docs_v1/classes.rb', line 2387

def update!(**args)
  @angle = args[:angle] if args.key?(:angle)
  @brightness = args[:brightness] if args.key?(:brightness)
  @content_uri = args[:content_uri] if args.key?(:content_uri)
  @contrast = args[:contrast] if args.key?(:contrast)
  @crop_properties = args[:crop_properties] if args.key?(:crop_properties)
  @source_uri = args[:source_uri] if args.key?(:source_uri)
  @transparency = args[:transparency] if args.key?(:transparency)
end