Class: Google::Apis::DocsV1::InlineObject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

An object that appears inline with text. An InlineObject contains an EmbeddedObject such as an image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InlineObject

Returns a new instance of InlineObject.



2495
2496
2497
# File 'lib/google/apis/docs_v1/classes.rb', line 2495

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inline_object_propertiesGoogle::Apis::DocsV1::InlineObjectProperties

Properties of an InlineObject. Corresponds to the JSON property inlineObjectProperties



2472
2473
2474
# File 'lib/google/apis/docs_v1/classes.rb', line 2472

def inline_object_properties
  @inline_object_properties
end

#object_id_propString

The ID of this inline object. Can be used to update an object’s properties. Corresponds to the JSON property objectId

Returns:

  • (String)


2477
2478
2479
# File 'lib/google/apis/docs_v1/classes.rb', line 2477

def object_id_prop
  @object_id_prop
end

#suggested_deletion_idsArray<String>

The suggested deletion IDs. If empty, then there are no suggested deletions of this content. Corresponds to the JSON property suggestedDeletionIds

Returns:

  • (Array<String>)


2483
2484
2485
# File 'lib/google/apis/docs_v1/classes.rb', line 2483

def suggested_deletion_ids
  @suggested_deletion_ids
end

#suggested_inline_object_properties_changesHash<String,Google::Apis::DocsV1::SuggestedInlineObjectProperties>

The suggested changes to the inline object properties, keyed by suggestion ID. Corresponds to the JSON property suggestedInlineObjectPropertiesChanges



2488
2489
2490
# File 'lib/google/apis/docs_v1/classes.rb', line 2488

def suggested_inline_object_properties_changes
  @suggested_inline_object_properties_changes
end

#suggested_insertion_idString

The suggested insertion ID. If empty, then this is not a suggested insertion. Corresponds to the JSON property suggestedInsertionId

Returns:

  • (String)


2493
2494
2495
# File 'lib/google/apis/docs_v1/classes.rb', line 2493

def suggested_insertion_id
  @suggested_insertion_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2500
2501
2502
2503
2504
2505
2506
# File 'lib/google/apis/docs_v1/classes.rb', line 2500

def update!(**args)
  @inline_object_properties = args[:inline_object_properties] if args.key?(:inline_object_properties)
  @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop)
  @suggested_deletion_ids = args[:suggested_deletion_ids] if args.key?(:suggested_deletion_ids)
  @suggested_inline_object_properties_changes = args[:suggested_inline_object_properties_changes] if args.key?(:suggested_inline_object_properties_changes)
  @suggested_insertion_id = args[:suggested_insertion_id] if args.key?(:suggested_insertion_id)
end