Class: Google::Apis::DocsV1::InsertDateRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Inserts a date at the specified location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertDateRequest

Returns a new instance of InsertDateRequest.



2625
2626
2627
# File 'lib/google/apis/docs_v1/classes.rb', line 2625

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#date_element_propertiesGoogle::Apis::DocsV1::DateElementProperties

Properties of a DateElement. Corresponds to the JSON property dateElementProperties



2612
2613
2614
# File 'lib/google/apis/docs_v1/classes.rb', line 2612

def date_element_properties
  @date_element_properties
end

#end_of_segment_locationGoogle::Apis::DocsV1::EndOfSegmentLocation

Location at the end of a body, header, footer or footnote. The location is immediately before the last newline in the document segment. Corresponds to the JSON property endOfSegmentLocation



2618
2619
2620
# File 'lib/google/apis/docs_v1/classes.rb', line 2618

def end_of_segment_location
  @end_of_segment_location
end

#locationGoogle::Apis::DocsV1::Location

A particular location in the document. Corresponds to the JSON property location



2623
2624
2625
# File 'lib/google/apis/docs_v1/classes.rb', line 2623

def location
  @location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2630
2631
2632
2633
2634
# File 'lib/google/apis/docs_v1/classes.rb', line 2630

def update!(**args)
  @date_element_properties = args[:date_element_properties] if args.key?(:date_element_properties)
  @end_of_segment_location = args[:end_of_segment_location] if args.key?(:end_of_segment_location)
  @location = args[:location] if args.key?(:location)
end