Class: Google::Apis::DocsV1::InsertSectionBreakRequest
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::InsertSectionBreakRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
Inserts a section break at the given location. A newline character will be inserted before the section break.
Instance Attribute Summary collapse
-
#end_of_segment_location ⇒ Google::Apis::DocsV1::EndOfSegmentLocation
Location at the end of a body, header, footer or footnote.
-
#location ⇒ Google::Apis::DocsV1::Location
A particular location in the document.
-
#section_type ⇒ String
The type of section to insert.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InsertSectionBreakRequest
constructor
A new instance of InsertSectionBreakRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InsertSectionBreakRequest
Returns a new instance of InsertSectionBreakRequest.
2829 2830 2831 |
# File 'lib/google/apis/docs_v1/classes.rb', line 2829 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_of_segment_location ⇒ Google::Apis::DocsV1::EndOfSegmentLocation
Location at the end of a body, header, footer or footnote. The location is
immediately before the last newline in the document segment.
Corresponds to the JSON property endOfSegmentLocation
2817 2818 2819 |
# File 'lib/google/apis/docs_v1/classes.rb', line 2817 def end_of_segment_location @end_of_segment_location end |
#location ⇒ Google::Apis::DocsV1::Location
A particular location in the document.
Corresponds to the JSON property location
2822 2823 2824 |
# File 'lib/google/apis/docs_v1/classes.rb', line 2822 def location @location end |
#section_type ⇒ String
The type of section to insert.
Corresponds to the JSON property sectionType
2827 2828 2829 |
# File 'lib/google/apis/docs_v1/classes.rb', line 2827 def section_type @section_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2834 2835 2836 2837 2838 |
# File 'lib/google/apis/docs_v1/classes.rb', line 2834 def update!(**args) @end_of_segment_location = args[:end_of_segment_location] if args.key?(:end_of_segment_location) @location = args[:location] if args.key?(:location) @section_type = args[:section_type] if args.key?(:section_type) end |