Class: Google::Apis::DocsV1::InsertTableRequest
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::InsertTableRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
Inserts a table at the specified location. A newline character will be inserted before the inserted table.
Instance Attribute Summary collapse
-
#columns ⇒ Fixnum
The number of columns in the table.
-
#end_of_segment_location ⇒ Google::Apis::DocsV1::EndOfSegmentLocation
Location at the end of a body, header, footer or footnote.
-
#location ⇒ Google::Apis::DocsV1::Location
A particular location in the document.
-
#rows ⇒ Fixnum
The number of rows in the table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InsertTableRequest
constructor
A new instance of InsertTableRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InsertTableRequest
Returns a new instance of InsertTableRequest.
2895 2896 2897 |
# File 'lib/google/apis/docs_v1/classes.rb', line 2895 def initialize(**args) update!(**args) end |
Instance Attribute Details
#columns ⇒ Fixnum
The number of columns in the table.
Corresponds to the JSON property columns
2877 2878 2879 |
# File 'lib/google/apis/docs_v1/classes.rb', line 2877 def columns @columns end |
#end_of_segment_location ⇒ Google::Apis::DocsV1::EndOfSegmentLocation
Location at the end of a body, header, footer or footnote. The location is
immediately before the last newline in the document segment.
Corresponds to the JSON property endOfSegmentLocation
2883 2884 2885 |
# File 'lib/google/apis/docs_v1/classes.rb', line 2883 def end_of_segment_location @end_of_segment_location end |
#location ⇒ Google::Apis::DocsV1::Location
A particular location in the document.
Corresponds to the JSON property location
2888 2889 2890 |
# File 'lib/google/apis/docs_v1/classes.rb', line 2888 def location @location end |
#rows ⇒ Fixnum
The number of rows in the table.
Corresponds to the JSON property rows
2893 2894 2895 |
# File 'lib/google/apis/docs_v1/classes.rb', line 2893 def rows @rows end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2900 2901 2902 2903 2904 2905 |
# File 'lib/google/apis/docs_v1/classes.rb', line 2900 def update!(**args) @columns = args[:columns] if args.key?(:columns) @end_of_segment_location = args[:end_of_segment_location] if args.key?(:end_of_segment_location) @location = args[:location] if args.key?(:location) @rows = args[:rows] if args.key?(:rows) end |