Class: Google::Apis::DocsV1::InsertTextRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Inserts text at the specified location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertTextRequest

Returns a new instance of InsertTextRequest.



2963
2964
2965
# File 'lib/google/apis/docs_v1/classes.rb', line 2963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_of_segment_locationGoogle::Apis::DocsV1::EndOfSegmentLocation

Location at the end of a body, header, footer or footnote. The location is immediately before the last newline in the document segment. Corresponds to the JSON property endOfSegmentLocation



2943
2944
2945
# File 'lib/google/apis/docs_v1/classes.rb', line 2943

def end_of_segment_location
  @end_of_segment_location
end

#locationGoogle::Apis::DocsV1::Location

A particular location in the document. Corresponds to the JSON property location



2948
2949
2950
# File 'lib/google/apis/docs_v1/classes.rb', line 2948

def location
  @location
end

#textString

The text to be inserted. Inserting a newline character will implicitly create a new Paragraph at that index. The paragraph style of the new paragraph will be copied from the paragraph at the current insertion index, including lists and bullets. Text styles for inserted text will be determined automatically, generally preserving the styling of neighboring text. In most cases, the text style for the inserted text will match the text immediately before the insertion index. Some control characters (U+0000-U+0008, U+000C-U+001F) and characters from the Unicode Basic Multilingual Plane Private Use Area (U+E000- U+F8FF) will be stripped out of the inserted text. Corresponds to the JSON property text

Returns:

  • (String)


2961
2962
2963
# File 'lib/google/apis/docs_v1/classes.rb', line 2961

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2968
2969
2970
2971
2972
# File 'lib/google/apis/docs_v1/classes.rb', line 2968

def update!(**args)
  @end_of_segment_location = args[:end_of_segment_location] if args.key?(:end_of_segment_location)
  @location = args[:location] if args.key?(:location)
  @text = args[:text] if args.key?(:text)
end