Class: Google::Apis::DocsV1::Link

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

A reference to another portion of a document or an external URL resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Link

Returns a new instance of Link.



3023
3024
3025
# File 'lib/google/apis/docs_v1/classes.rb', line 3023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bookmarkGoogle::Apis::DocsV1::BookmarkLink

A reference to a bookmark in this document. Corresponds to the JSON property bookmark



2982
2983
2984
# File 'lib/google/apis/docs_v1/classes.rb', line 2982

def bookmark
  @bookmark
end

#bookmark_idString

The ID of a bookmark in this document. Legacy field: Instead, set includeTabsContent to true and use Link.bookmark for read and write operations. This field is only returned when includeTabsContent is set to false in documents containing a single tab and links to a bookmark within the singular tab. Otherwise, Link.bookmark is returned. If this field is used in a write request, the bookmark is considered to be from the tab ID specified in the request. If a tab ID is not specified in the request, it is considered to be from the first tab in the document. Corresponds to the JSON property bookmarkId

Returns:

  • (String)


2994
2995
2996
# File 'lib/google/apis/docs_v1/classes.rb', line 2994

def bookmark_id
  @bookmark_id
end

#headingGoogle::Apis::DocsV1::HeadingLink

A reference to a heading in this document. Corresponds to the JSON property heading



2999
3000
3001
# File 'lib/google/apis/docs_v1/classes.rb', line 2999

def heading
  @heading
end

#heading_idString

The ID of a heading in this document. Legacy field: Instead, set includeTabsContent to true and use Link.heading for read and write operations. This field is only returned when includeTabsContent is set to false in documents containing a single tab and links to a heading within the singular tab. Otherwise, Link.heading is returned. If this field is used in a write request, the heading is considered to be from the tab ID specified in the request. If a tab ID is not specified in the request, it is considered to be from the first tab in the document. Corresponds to the JSON property headingId

Returns:

  • (String)


3011
3012
3013
# File 'lib/google/apis/docs_v1/classes.rb', line 3011

def heading_id
  @heading_id
end

#tab_idString

The ID of a tab in this document. Corresponds to the JSON property tabId

Returns:

  • (String)


3016
3017
3018
# File 'lib/google/apis/docs_v1/classes.rb', line 3016

def tab_id
  @tab_id
end

#urlString

An external URL. Corresponds to the JSON property url

Returns:

  • (String)


3021
3022
3023
# File 'lib/google/apis/docs_v1/classes.rb', line 3021

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3028
3029
3030
3031
3032
3033
3034
3035
# File 'lib/google/apis/docs_v1/classes.rb', line 3028

def update!(**args)
  @bookmark = args[:bookmark] if args.key?(:bookmark)
  @bookmark_id = args[:bookmark_id] if args.key?(:bookmark_id)
  @heading = args[:heading] if args.key?(:heading)
  @heading_id = args[:heading_id] if args.key?(:heading_id)
  @tab_id = args[:tab_id] if args.key?(:tab_id)
  @url = args[:url] if args.key?(:url)
end