Class: Google::Apis::DocsV1::ListPropertiesSuggestionState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

A mask that indicates which of the fields on the base ListProperties have been changed in this suggestion. For any field set to true, there's a new suggested value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPropertiesSuggestionState

Returns a new instance of ListPropertiesSuggestionState.



3158
3159
3160
# File 'lib/google/apis/docs_v1/classes.rb', line 3158

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nesting_levels_suggestion_statesArray<Google::Apis::DocsV1::NestingLevelSuggestionState>

A mask that indicates which of the fields on the corresponding NestingLevel in nesting_levels have been changed in this suggestion. The nesting level suggestion states are returned in ascending order of the nesting level with the least nested returned first. Corresponds to the JSON property nestingLevelsSuggestionStates



3156
3157
3158
# File 'lib/google/apis/docs_v1/classes.rb', line 3156

def nesting_levels_suggestion_states
  @nesting_levels_suggestion_states
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3163
3164
3165
# File 'lib/google/apis/docs_v1/classes.rb', line 3163

def update!(**args)
  @nesting_levels_suggestion_states = args[:nesting_levels_suggestion_states] if args.key?(:nesting_levels_suggestion_states)
end