Class: Google::Apis::DocsV1::PageBreak

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

A ParagraphElement representing a page break. A page break makes the subsequent text start at the top of the next page.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PageBreak

Returns a new instance of PageBreak.



3632
3633
3634
# File 'lib/google/apis/docs_v1/classes.rb', line 3632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#suggested_deletion_idsArray<String>

The suggested deletion IDs. If empty, then there are no suggested deletions of this content. Corresponds to the JSON property suggestedDeletionIds

Returns:

  • (Array<String>)


3605
3606
3607
# File 'lib/google/apis/docs_v1/classes.rb', line 3605

def suggested_deletion_ids
  @suggested_deletion_ids
end

#suggested_insertion_idsArray<String>

The suggested insertion IDs. A PageBreak may have multiple insertion IDs if it' s a nested suggested change. If empty, then this is not a suggested insertion. Corresponds to the JSON property suggestedInsertionIds

Returns:

  • (Array<String>)


3611
3612
3613
# File 'lib/google/apis/docs_v1/classes.rb', line 3611

def suggested_insertion_ids
  @suggested_insertion_ids
end

#suggested_text_style_changesHash<String,Google::Apis::DocsV1::SuggestedTextStyle>

The suggested text style changes to this PageBreak, keyed by suggestion ID. Corresponds to the JSON property suggestedTextStyleChanges



3616
3617
3618
# File 'lib/google/apis/docs_v1/classes.rb', line 3616

def suggested_text_style_changes
  @suggested_text_style_changes
end

#text_styleGoogle::Apis::DocsV1::TextStyle

Represents the styling that can be applied to text. Inherited text styles are represented as unset fields in this message. A text style's parent depends on where the text style is defined: * The TextStyle of text in a Paragraph inherits from the paragraph's corresponding named style type. * The TextStyle on a named style inherits from the normal text named style. * The TextStyle of the normal text named style inherits from the default text style in the Docs editor. * The TextStyle on a Paragraph element that's contained in a table may inherit its text style from the table style. If the text style does not inherit from a parent, unsetting fields will revert the style to a value matching the defaults in the Docs editor. Corresponds to the JSON property textStyle



3630
3631
3632
# File 'lib/google/apis/docs_v1/classes.rb', line 3630

def text_style
  @text_style
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3637
3638
3639
3640
3641
3642
# File 'lib/google/apis/docs_v1/classes.rb', line 3637

def update!(**args)
  @suggested_deletion_ids = args[:suggested_deletion_ids] if args.key?(:suggested_deletion_ids)
  @suggested_insertion_ids = args[:suggested_insertion_ids] if args.key?(:suggested_insertion_ids)
  @suggested_text_style_changes = args[:suggested_text_style_changes] if args.key?(:suggested_text_style_changes)
  @text_style = args[:text_style] if args.key?(:text_style)
end