Class: Google::Apis::DocsV1::ParagraphBorder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

A border around a paragraph.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ParagraphBorder

Returns a new instance of ParagraphBorder.



3776
3777
3778
# File 'lib/google/apis/docs_v1/classes.rb', line 3776

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#colorGoogle::Apis::DocsV1::OptionalColor

A color that can either be fully opaque or fully transparent. Corresponds to the JSON property color



3759
3760
3761
# File 'lib/google/apis/docs_v1/classes.rb', line 3759

def color
  @color
end

#dash_styleString

The dash style of the border. Corresponds to the JSON property dashStyle

Returns:

  • (String)


3764
3765
3766
# File 'lib/google/apis/docs_v1/classes.rb', line 3764

def dash_style
  @dash_style
end

#paddingGoogle::Apis::DocsV1::Dimension

A magnitude in a single direction in the specified units. Corresponds to the JSON property padding



3769
3770
3771
# File 'lib/google/apis/docs_v1/classes.rb', line 3769

def padding
  @padding
end

#widthGoogle::Apis::DocsV1::Dimension

A magnitude in a single direction in the specified units. Corresponds to the JSON property width



3774
3775
3776
# File 'lib/google/apis/docs_v1/classes.rb', line 3774

def width
  @width
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3781
3782
3783
3784
3785
3786
# File 'lib/google/apis/docs_v1/classes.rb', line 3781

def update!(**args)
  @color = args[:color] if args.key?(:color)
  @dash_style = args[:dash_style] if args.key?(:dash_style)
  @padding = args[:padding] if args.key?(:padding)
  @width = args[:width] if args.key?(:width)
end