Class: Google::Apis::DocsV1::ParagraphStyleSuggestionState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

A mask that indicates which of the fields on the base ParagraphStyle have been changed in this suggestion. For any field set to true, there's a new suggested value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ParagraphStyleSuggestionState

Returns a new instance of ParagraphStyleSuggestionState.



4192
4193
4194
# File 'lib/google/apis/docs_v1/classes.rb', line 4192

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alignment_suggestedBoolean Also known as: alignment_suggested?

Indicates if there was a suggested change to alignment. Corresponds to the JSON property alignmentSuggested

Returns:

  • (Boolean)


4068
4069
4070
# File 'lib/google/apis/docs_v1/classes.rb', line 4068

def alignment_suggested
  @alignment_suggested
end

#avoid_widow_and_orphan_suggestedBoolean Also known as: avoid_widow_and_orphan_suggested?

Indicates if there was a suggested change to avoid_widow_and_orphan. Corresponds to the JSON property avoidWidowAndOrphanSuggested

Returns:

  • (Boolean)


4074
4075
4076
# File 'lib/google/apis/docs_v1/classes.rb', line 4074

def avoid_widow_and_orphan_suggested
  @avoid_widow_and_orphan_suggested
end

#border_between_suggestedBoolean Also known as: border_between_suggested?

Indicates if there was a suggested change to border_between. Corresponds to the JSON property borderBetweenSuggested

Returns:

  • (Boolean)


4080
4081
4082
# File 'lib/google/apis/docs_v1/classes.rb', line 4080

def border_between_suggested
  @border_between_suggested
end

#border_bottom_suggestedBoolean Also known as: border_bottom_suggested?

Indicates if there was a suggested change to border_bottom. Corresponds to the JSON property borderBottomSuggested

Returns:

  • (Boolean)


4086
4087
4088
# File 'lib/google/apis/docs_v1/classes.rb', line 4086

def border_bottom_suggested
  @border_bottom_suggested
end

#border_left_suggestedBoolean Also known as: border_left_suggested?

Indicates if there was a suggested change to border_left. Corresponds to the JSON property borderLeftSuggested

Returns:

  • (Boolean)


4092
4093
4094
# File 'lib/google/apis/docs_v1/classes.rb', line 4092

def border_left_suggested
  @border_left_suggested
end

#border_right_suggestedBoolean Also known as: border_right_suggested?

Indicates if there was a suggested change to border_right. Corresponds to the JSON property borderRightSuggested

Returns:

  • (Boolean)


4098
4099
4100
# File 'lib/google/apis/docs_v1/classes.rb', line 4098

def border_right_suggested
  @border_right_suggested
end

#border_top_suggestedBoolean Also known as: border_top_suggested?

Indicates if there was a suggested change to border_top. Corresponds to the JSON property borderTopSuggested

Returns:

  • (Boolean)


4104
4105
4106
# File 'lib/google/apis/docs_v1/classes.rb', line 4104

def border_top_suggested
  @border_top_suggested
end

#direction_suggestedBoolean Also known as: direction_suggested?

Indicates if there was a suggested change to direction. Corresponds to the JSON property directionSuggested

Returns:

  • (Boolean)


4110
4111
4112
# File 'lib/google/apis/docs_v1/classes.rb', line 4110

def direction_suggested
  @direction_suggested
end

#heading_id_suggestedBoolean Also known as: heading_id_suggested?

Indicates if there was a suggested change to heading_id. Corresponds to the JSON property headingIdSuggested

Returns:

  • (Boolean)


4116
4117
4118
# File 'lib/google/apis/docs_v1/classes.rb', line 4116

def heading_id_suggested
  @heading_id_suggested
end

#indent_end_suggestedBoolean Also known as: indent_end_suggested?

Indicates if there was a suggested change to indent_end. Corresponds to the JSON property indentEndSuggested

Returns:

  • (Boolean)


4122
4123
4124
# File 'lib/google/apis/docs_v1/classes.rb', line 4122

def indent_end_suggested
  @indent_end_suggested
end

#indent_first_line_suggestedBoolean Also known as: indent_first_line_suggested?

Indicates if there was a suggested change to indent_first_line. Corresponds to the JSON property indentFirstLineSuggested

Returns:

  • (Boolean)


4128
4129
4130
# File 'lib/google/apis/docs_v1/classes.rb', line 4128

def indent_first_line_suggested
  @indent_first_line_suggested
end

#indent_start_suggestedBoolean Also known as: indent_start_suggested?

Indicates if there was a suggested change to indent_start. Corresponds to the JSON property indentStartSuggested

Returns:

  • (Boolean)


4134
4135
4136
# File 'lib/google/apis/docs_v1/classes.rb', line 4134

def indent_start_suggested
  @indent_start_suggested
end

#keep_lines_together_suggestedBoolean Also known as: keep_lines_together_suggested?

Indicates if there was a suggested change to keep_lines_together. Corresponds to the JSON property keepLinesTogetherSuggested

Returns:

  • (Boolean)


4140
4141
4142
# File 'lib/google/apis/docs_v1/classes.rb', line 4140

def keep_lines_together_suggested
  @keep_lines_together_suggested
end

#keep_with_next_suggestedBoolean Also known as: keep_with_next_suggested?

Indicates if there was a suggested change to keep_with_next. Corresponds to the JSON property keepWithNextSuggested

Returns:

  • (Boolean)


4146
4147
4148
# File 'lib/google/apis/docs_v1/classes.rb', line 4146

def keep_with_next_suggested
  @keep_with_next_suggested
end

#line_spacing_suggestedBoolean Also known as: line_spacing_suggested?

Indicates if there was a suggested change to line_spacing. Corresponds to the JSON property lineSpacingSuggested

Returns:

  • (Boolean)


4152
4153
4154
# File 'lib/google/apis/docs_v1/classes.rb', line 4152

def line_spacing_suggested
  @line_spacing_suggested
end

#named_style_type_suggestedBoolean Also known as: named_style_type_suggested?

Indicates if there was a suggested change to named_style_type. Corresponds to the JSON property namedStyleTypeSuggested

Returns:

  • (Boolean)


4158
4159
4160
# File 'lib/google/apis/docs_v1/classes.rb', line 4158

def named_style_type_suggested
  @named_style_type_suggested
end

#page_break_before_suggestedBoolean Also known as: page_break_before_suggested?

Indicates if there was a suggested change to page_break_before. Corresponds to the JSON property pageBreakBeforeSuggested

Returns:

  • (Boolean)


4164
4165
4166
# File 'lib/google/apis/docs_v1/classes.rb', line 4164

def page_break_before_suggested
  @page_break_before_suggested
end

#shading_suggestion_stateGoogle::Apis::DocsV1::ShadingSuggestionState

A mask that indicates which of the fields on the base Shading have been changed in this suggested change. For any field set to true, there's a new suggested value. Corresponds to the JSON property shadingSuggestionState



4172
4173
4174
# File 'lib/google/apis/docs_v1/classes.rb', line 4172

def shading_suggestion_state
  @shading_suggestion_state
end

#space_above_suggestedBoolean Also known as: space_above_suggested?

Indicates if there was a suggested change to space_above. Corresponds to the JSON property spaceAboveSuggested

Returns:

  • (Boolean)


4177
4178
4179
# File 'lib/google/apis/docs_v1/classes.rb', line 4177

def space_above_suggested
  @space_above_suggested
end

#space_below_suggestedBoolean Also known as: space_below_suggested?

Indicates if there was a suggested change to space_below. Corresponds to the JSON property spaceBelowSuggested

Returns:

  • (Boolean)


4183
4184
4185
# File 'lib/google/apis/docs_v1/classes.rb', line 4183

def space_below_suggested
  @space_below_suggested
end

#spacing_mode_suggestedBoolean Also known as: spacing_mode_suggested?

Indicates if there was a suggested change to spacing_mode. Corresponds to the JSON property spacingModeSuggested

Returns:

  • (Boolean)


4189
4190
4191
# File 'lib/google/apis/docs_v1/classes.rb', line 4189

def spacing_mode_suggested
  @spacing_mode_suggested
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4197
4198
4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
4212
4213
4214
4215
4216
4217
4218
4219
# File 'lib/google/apis/docs_v1/classes.rb', line 4197

def update!(**args)
  @alignment_suggested = args[:alignment_suggested] if args.key?(:alignment_suggested)
  @avoid_widow_and_orphan_suggested = args[:avoid_widow_and_orphan_suggested] if args.key?(:avoid_widow_and_orphan_suggested)
  @border_between_suggested = args[:border_between_suggested] if args.key?(:border_between_suggested)
  @border_bottom_suggested = args[:border_bottom_suggested] if args.key?(:border_bottom_suggested)
  @border_left_suggested = args[:border_left_suggested] if args.key?(:border_left_suggested)
  @border_right_suggested = args[:border_right_suggested] if args.key?(:border_right_suggested)
  @border_top_suggested = args[:border_top_suggested] if args.key?(:border_top_suggested)
  @direction_suggested = args[:direction_suggested] if args.key?(:direction_suggested)
  @heading_id_suggested = args[:heading_id_suggested] if args.key?(:heading_id_suggested)
  @indent_end_suggested = args[:indent_end_suggested] if args.key?(:indent_end_suggested)
  @indent_first_line_suggested = args[:indent_first_line_suggested] if args.key?(:indent_first_line_suggested)
  @indent_start_suggested = args[:indent_start_suggested] if args.key?(:indent_start_suggested)
  @keep_lines_together_suggested = args[:keep_lines_together_suggested] if args.key?(:keep_lines_together_suggested)
  @keep_with_next_suggested = args[:keep_with_next_suggested] if args.key?(:keep_with_next_suggested)
  @line_spacing_suggested = args[:line_spacing_suggested] if args.key?(:line_spacing_suggested)
  @named_style_type_suggested = args[:named_style_type_suggested] if args.key?(:named_style_type_suggested)
  @page_break_before_suggested = args[:page_break_before_suggested] if args.key?(:page_break_before_suggested)
  @shading_suggestion_state = args[:shading_suggestion_state] if args.key?(:shading_suggestion_state)
  @space_above_suggested = args[:space_above_suggested] if args.key?(:space_above_suggested)
  @space_below_suggested = args[:space_below_suggested] if args.key?(:space_below_suggested)
  @spacing_mode_suggested = args[:spacing_mode_suggested] if args.key?(:spacing_mode_suggested)
end