Class: Google::Apis::DocsV1::PositionedObjectPositioning

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

The positioning of a PositionedObject. The positioned object is positioned relative to the beginning of the Paragraph it's tethered to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PositionedObjectPositioning

Returns a new instance of PositionedObjectPositioning.



4404
4405
4406
# File 'lib/google/apis/docs_v1/classes.rb', line 4404

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#layoutString

The layout of this positioned object. Corresponds to the JSON property layout

Returns:

  • (String)


4392
4393
4394
# File 'lib/google/apis/docs_v1/classes.rb', line 4392

def layout
  @layout
end

#left_offsetGoogle::Apis::DocsV1::Dimension

A magnitude in a single direction in the specified units. Corresponds to the JSON property leftOffset



4397
4398
4399
# File 'lib/google/apis/docs_v1/classes.rb', line 4397

def left_offset
  @left_offset
end

#top_offsetGoogle::Apis::DocsV1::Dimension

A magnitude in a single direction in the specified units. Corresponds to the JSON property topOffset



4402
4403
4404
# File 'lib/google/apis/docs_v1/classes.rb', line 4402

def top_offset
  @top_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4409
4410
4411
4412
4413
# File 'lib/google/apis/docs_v1/classes.rb', line 4409

def update!(**args)
  @layout = args[:layout] if args.key?(:layout)
  @left_offset = args[:left_offset] if args.key?(:left_offset)
  @top_offset = args[:top_offset] if args.key?(:top_offset)
end