Class: Google::Apis::DocsV1::Range
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::Range
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
Specifies a contiguous range of text.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
The zero-based end index of this range, exclusive, in UTF-16 code units.
-
#segment_id ⇒ String
The ID of the header, footer, or footnote that this range is contained in.
-
#start_index ⇒ Fixnum
The zero-based start index of this range, in UTF-16 code units.
-
#tab_id ⇒ String
The tab that contains this range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Range
constructor
A new instance of Range.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Range
Returns a new instance of Range.
4544 4545 4546 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4544 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
The zero-based end index of this range, exclusive, in UTF-16 code units. In
all current uses, an end index must be provided. This field is an Int32Value
in order to accommodate future use cases with open-ended ranges.
Corresponds to the JSON property endIndex
4519 4520 4521 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4519 def end_index @end_index end |
#segment_id ⇒ String
The ID of the header, footer, or footnote that this range is contained in. An
empty segment ID signifies the document's body.
Corresponds to the JSON property segmentId
4525 4526 4527 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4525 def segment_id @segment_id end |
#start_index ⇒ Fixnum
The zero-based start index of this range, in UTF-16 code units. In all current
uses, a start index must be provided. This field is an Int32Value in order to
accommodate future use cases with open-ended ranges.
Corresponds to the JSON property startIndex
4532 4533 4534 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4532 def start_index @start_index end |
#tab_id ⇒ String
The tab that contains this range. When omitted, the request applies to the
first tab. In a document containing a single tab: - If provided, must match
the singular tab's ID. - If omitted, the request applies to the singular tab.
In a document containing multiple tabs: - If provided, the request applies to
the specified tab. - If omitted, the request applies to the first tab in the
document.
Corresponds to the JSON property tabId
4542 4543 4544 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4542 def tab_id @tab_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4549 4550 4551 4552 4553 4554 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4549 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @segment_id = args[:segment_id] if args.key?(:segment_id) @start_index = args[:start_index] if args.key?(:start_index) @tab_id = args[:tab_id] if args.key?(:tab_id) end |