Class: Google::Apis::DocsV1::ReplaceAllTextRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Replaces all instances of text matching a criteria with replace text.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReplaceAllTextRequest

Returns a new instance of ReplaceAllTextRequest.



4575
4576
4577
# File 'lib/google/apis/docs_v1/classes.rb', line 4575

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contains_textGoogle::Apis::DocsV1::SubstringMatchCriteria

A criteria that matches a specific string of text in the document. Corresponds to the JSON property containsText



4563
4564
4565
# File 'lib/google/apis/docs_v1/classes.rb', line 4563

def contains_text
  @contains_text
end

#replace_textString

The text that will replace the matched text. Corresponds to the JSON property replaceText

Returns:

  • (String)


4568
4569
4570
# File 'lib/google/apis/docs_v1/classes.rb', line 4568

def replace_text
  @replace_text
end

#tabs_criteriaGoogle::Apis::DocsV1::TabsCriteria

A criteria that specifies in which tabs a request executes. Corresponds to the JSON property tabsCriteria



4573
4574
4575
# File 'lib/google/apis/docs_v1/classes.rb', line 4573

def tabs_criteria
  @tabs_criteria
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4580
4581
4582
4583
4584
# File 'lib/google/apis/docs_v1/classes.rb', line 4580

def update!(**args)
  @contains_text = args[:contains_text] if args.key?(:contains_text)
  @replace_text = args[:replace_text] if args.key?(:replace_text)
  @tabs_criteria = args[:tabs_criteria] if args.key?(:tabs_criteria)
end