Class: Google::Apis::DocsV1::ReplaceAllTextResponse
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::ReplaceAllTextResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
The result of replacing text.
Instance Attribute Summary collapse
-
#occurrences_changed ⇒ Fixnum
The number of occurrences changed by replacing all text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReplaceAllTextResponse
constructor
A new instance of ReplaceAllTextResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReplaceAllTextResponse
Returns a new instance of ReplaceAllTextResponse.
4558 4559 4560 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#occurrences_changed ⇒ Fixnum
The number of occurrences changed by replacing all text.
Corresponds to the JSON property occurrencesChanged
4556 4557 4558 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4556 def occurrences_changed @occurrences_changed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4563 4564 4565 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4563 def update!(**args) @occurrences_changed = args[:occurrences_changed] if args.key?(:occurrences_changed) end |