Class: Google::Apis::DocsV1::RichLinkProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Properties specific to a RichLink.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RichLinkProperties

Returns a new instance of RichLinkProperties.



5159
5160
5161
# File 'lib/google/apis/docs_v1/classes.rb', line 5159

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mime_typeString

The MIME type of the RichLink, if there's one (for example, when it's a file in Drive). Corresponds to the JSON property mimeType

Returns:

  • (String)


5145
5146
5147
# File 'lib/google/apis/docs_v1/classes.rb', line 5145

def mime_type
  @mime_type
end

#titleString

The title of the RichLink as displayed in the link. This title matches the title of the linked resource at the time of the insertion or last update of the link. This field is always present. Corresponds to the JSON property title

Returns:

  • (String)


5152
5153
5154
# File 'lib/google/apis/docs_v1/classes.rb', line 5152

def title
  @title
end

#uriString

The URI to the RichLink. This is always present. Corresponds to the JSON property uri

Returns:

  • (String)


5157
5158
5159
# File 'lib/google/apis/docs_v1/classes.rb', line 5157

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5164
5165
5166
5167
5168
# File 'lib/google/apis/docs_v1/classes.rb', line 5164

def update!(**args)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end