Class: Google::Apis::DocsV1::SectionColumnProperties
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::SectionColumnProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
Properties that apply to a section's column.
Instance Attribute Summary collapse
-
#padding_end ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#width ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SectionColumnProperties
constructor
A new instance of SectionColumnProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SectionColumnProperties
Returns a new instance of SectionColumnProperties.
5221 5222 5223 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5221 def initialize(**args) update!(**args) end |
Instance Attribute Details
#padding_end ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property paddingEnd
5214 5215 5216 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5214 def padding_end @padding_end end |
#width ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property width
5219 5220 5221 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5219 def width @width end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5226 5227 5228 5229 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5226 def update!(**args) @padding_end = args[:padding_end] if args.key?(:padding_end) @width = args[:width] if args.key?(:width) end |