Class: Google::Apis::DocsV1::Size
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::Size
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
A width and height.
Instance Attribute Summary collapse
-
#height ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#width ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Size
constructor
A new instance of Size.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Size
Returns a new instance of Size.
5526 5527 5528 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5526 def initialize(**args) update!(**args) end |
Instance Attribute Details
#height ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property height
5519 5520 5521 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5519 def height @height end |
#width ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property width
5524 5525 5526 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5524 def width @width end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5531 5532 5533 5534 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5531 def update!(**args) @height = args[:height] if args.key?(:height) @width = args[:width] if args.key?(:width) end |