Class: Google::Apis::DocsV1::SubstringMatchCriteria
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::SubstringMatchCriteria
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
A criteria that matches a specific string of text in the document.
Instance Attribute Summary collapse
-
#match_case ⇒ Boolean
(also: #match_case?)
Indicates whether the search should respect case: -
True: the search is case sensitive. -
#search_by_regex ⇒ Boolean
(also: #search_by_regex?)
Optional.
-
#text ⇒ String
The text to search for in the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubstringMatchCriteria
constructor
A new instance of SubstringMatchCriteria.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubstringMatchCriteria
Returns a new instance of SubstringMatchCriteria.
5600 5601 5602 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5600 def initialize(**args) update!(**args) end |
Instance Attribute Details
#match_case ⇒ Boolean Also known as: match_case?
Indicates whether the search should respect case: - True: the search is case
sensitive. - False: the search is case insensitive.
Corresponds to the JSON property matchCase
5583 5584 5585 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5583 def match_case @match_case end |
#search_by_regex ⇒ Boolean Also known as: search_by_regex?
Optional. True if the find value should be treated as a regular expression.
Any backslashes in the pattern should be escaped. - True: the search text is
treated as a regular expressions. - False: the search text is treated as a
substring for matching.
Corresponds to the JSON property searchByRegex
5592 5593 5594 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5592 def search_by_regex @search_by_regex end |
#text ⇒ String
The text to search for in the document.
Corresponds to the JSON property text
5598 5599 5600 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5598 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5605 5606 5607 5608 5609 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5605 def update!(**args) @match_case = args[:match_case] if args.key?(:match_case) @search_by_regex = args[:search_by_regex] if args.key?(:search_by_regex) @text = args[:text] if args.key?(:text) end |