Class: Google::Apis::DocsV1::SuggestedDateElementProperties
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::SuggestedDateElementProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
A suggested change to a DateElementProperties.
Instance Attribute Summary collapse
-
#date_element_properties ⇒ Google::Apis::DocsV1::DateElementProperties
Properties of a DateElement.
-
#date_element_properties_suggestion_state ⇒ Google::Apis::DocsV1::DateElementPropertiesSuggestionState
A mask that indicates which of the fields on the base DateElementProperties have been changed in this suggestion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SuggestedDateElementProperties
constructor
A new instance of SuggestedDateElementProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SuggestedDateElementProperties
5649 5650 5651 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5649 def initialize(**args) update!(**args) end |
Instance Attribute Details
#date_element_properties ⇒ Google::Apis::DocsV1::DateElementProperties
Properties of a DateElement.
Corresponds to the JSON property dateElementProperties
5640 5641 5642 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5640 def date_element_properties @date_element_properties end |
#date_element_properties_suggestion_state ⇒ Google::Apis::DocsV1::DateElementPropertiesSuggestionState
A mask that indicates which of the fields on the base DateElementProperties
have been changed in this suggestion. For any field set to true, there's a new
suggested value.
Corresponds to the JSON property dateElementPropertiesSuggestionState
5647 5648 5649 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5647 def date_element_properties_suggestion_state @date_element_properties_suggestion_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5654 5655 5656 5657 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5654 def update!(**args) @date_element_properties = args[:date_element_properties] if args.key?(:date_element_properties) @date_element_properties_suggestion_state = args[:date_element_properties_suggestion_state] if args.key?(:date_element_properties_suggestion_state) end |