Class: Google::Apis::DocsV1::SuggestedTableCellStyle

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

A suggested change to a TableCellStyle.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SuggestedTableCellStyle

Returns a new instance of SuggestedTableCellStyle.



5900
5901
5902
# File 'lib/google/apis/docs_v1/classes.rb', line 5900

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#table_cell_styleGoogle::Apis::DocsV1::TableCellStyle

The style of a TableCell. Inherited table cell styles are represented as unset fields in this message. A table cell style can inherit from the table's style. Corresponds to the JSON property tableCellStyle



5891
5892
5893
# File 'lib/google/apis/docs_v1/classes.rb', line 5891

def table_cell_style
  @table_cell_style
end

#table_cell_style_suggestion_stateGoogle::Apis::DocsV1::TableCellStyleSuggestionState

A mask that indicates which of the fields on the base TableCellStyle have been changed in this suggestion. For any field set to true, there's a new suggested value. Corresponds to the JSON property tableCellStyleSuggestionState



5898
5899
5900
# File 'lib/google/apis/docs_v1/classes.rb', line 5898

def table_cell_style_suggestion_state
  @table_cell_style_suggestion_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5905
5906
5907
5908
# File 'lib/google/apis/docs_v1/classes.rb', line 5905

def update!(**args)
  @table_cell_style = args[:table_cell_style] if args.key?(:table_cell_style)
  @table_cell_style_suggestion_state = args[:table_cell_style_suggestion_state] if args.key?(:table_cell_style_suggestion_state)
end