Class: Google::Apis::DocsV1::TabProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Properties of a tab.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TabProperties

Returns a new instance of TabProperties.



5994
5995
5996
# File 'lib/google/apis/docs_v1/classes.rb', line 5994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#icon_emojiString

Optional. The emoji icon displayed with the tab. A valid emoji icon is represented by a non-empty Unicode string. Any set of characters that don't represent a single emoji is invalid. If an emoji is invalid, a 400 bad request error is returned. If this value is unset or empty, the tab will display the default tab icon. Corresponds to the JSON property iconEmoji

Returns:

  • (String)


5965
5966
5967
# File 'lib/google/apis/docs_v1/classes.rb', line 5965

def icon_emoji
  @icon_emoji
end

#indexFixnum

The zero-based index of the tab within the parent. Corresponds to the JSON property index

Returns:

  • (Fixnum)


5970
5971
5972
# File 'lib/google/apis/docs_v1/classes.rb', line 5970

def index
  @index
end

#nesting_levelFixnum

Output only. The depth of the tab within the document. Root-level tabs start at 0. Corresponds to the JSON property nestingLevel

Returns:

  • (Fixnum)


5976
5977
5978
# File 'lib/google/apis/docs_v1/classes.rb', line 5976

def nesting_level
  @nesting_level
end

#parent_tab_idString

Optional. The ID of the parent tab. Empty when the current tab is a root-level tab, which means it doesn't have any parents. Corresponds to the JSON property parentTabId

Returns:

  • (String)


5982
5983
5984
# File 'lib/google/apis/docs_v1/classes.rb', line 5982

def parent_tab_id
  @parent_tab_id
end

#tab_idString

The immutable ID of the tab. Corresponds to the JSON property tabId

Returns:

  • (String)


5987
5988
5989
# File 'lib/google/apis/docs_v1/classes.rb', line 5987

def tab_id
  @tab_id
end

#titleString

The user-visible name of the tab. Corresponds to the JSON property title

Returns:

  • (String)


5992
5993
5994
# File 'lib/google/apis/docs_v1/classes.rb', line 5992

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5999
6000
6001
6002
6003
6004
6005
6006
# File 'lib/google/apis/docs_v1/classes.rb', line 5999

def update!(**args)
  @icon_emoji = args[:icon_emoji] if args.key?(:icon_emoji)
  @index = args[:index] if args.key?(:index)
  @nesting_level = args[:nesting_level] if args.key?(:nesting_level)
  @parent_tab_id = args[:parent_tab_id] if args.key?(:parent_tab_id)
  @tab_id = args[:tab_id] if args.key?(:tab_id)
  @title = args[:title] if args.key?(:title)
end