Class: Google::Apis::DocsV1::TableCellStyleSuggestionState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

A mask that indicates which of the fields on the base TableCellStyle have been changed in this suggestion. For any field set to true, there's a new suggested value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TableCellStyleSuggestionState

Returns a new instance of TableCellStyleSuggestionState.



6429
6430
6431
# File 'lib/google/apis/docs_v1/classes.rb', line 6429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#background_color_suggestedBoolean Also known as: background_color_suggested?

Indicates if there was a suggested change to background_color. Corresponds to the JSON property backgroundColorSuggested

Returns:

  • (Boolean)


6360
6361
6362
# File 'lib/google/apis/docs_v1/classes.rb', line 6360

def background_color_suggested
  @background_color_suggested
end

#border_bottom_suggestedBoolean Also known as: border_bottom_suggested?

Indicates if there was a suggested change to border_bottom. Corresponds to the JSON property borderBottomSuggested

Returns:

  • (Boolean)


6366
6367
6368
# File 'lib/google/apis/docs_v1/classes.rb', line 6366

def border_bottom_suggested
  @border_bottom_suggested
end

#border_left_suggestedBoolean Also known as: border_left_suggested?

Indicates if there was a suggested change to border_left. Corresponds to the JSON property borderLeftSuggested

Returns:

  • (Boolean)


6372
6373
6374
# File 'lib/google/apis/docs_v1/classes.rb', line 6372

def border_left_suggested
  @border_left_suggested
end

#border_right_suggestedBoolean Also known as: border_right_suggested?

Indicates if there was a suggested change to border_right. Corresponds to the JSON property borderRightSuggested

Returns:

  • (Boolean)


6378
6379
6380
# File 'lib/google/apis/docs_v1/classes.rb', line 6378

def border_right_suggested
  @border_right_suggested
end

#border_top_suggestedBoolean Also known as: border_top_suggested?

Indicates if there was a suggested change to border_top. Corresponds to the JSON property borderTopSuggested

Returns:

  • (Boolean)


6384
6385
6386
# File 'lib/google/apis/docs_v1/classes.rb', line 6384

def border_top_suggested
  @border_top_suggested
end

#column_span_suggestedBoolean Also known as: column_span_suggested?

Indicates if there was a suggested change to column_span. Corresponds to the JSON property columnSpanSuggested

Returns:

  • (Boolean)


6390
6391
6392
# File 'lib/google/apis/docs_v1/classes.rb', line 6390

def column_span_suggested
  @column_span_suggested
end

#content_alignment_suggestedBoolean Also known as: content_alignment_suggested?

Indicates if there was a suggested change to content_alignment. Corresponds to the JSON property contentAlignmentSuggested

Returns:

  • (Boolean)


6396
6397
6398
# File 'lib/google/apis/docs_v1/classes.rb', line 6396

def content_alignment_suggested
  @content_alignment_suggested
end

#padding_bottom_suggestedBoolean Also known as: padding_bottom_suggested?

Indicates if there was a suggested change to padding_bottom. Corresponds to the JSON property paddingBottomSuggested

Returns:

  • (Boolean)


6402
6403
6404
# File 'lib/google/apis/docs_v1/classes.rb', line 6402

def padding_bottom_suggested
  @padding_bottom_suggested
end

#padding_left_suggestedBoolean Also known as: padding_left_suggested?

Indicates if there was a suggested change to padding_left. Corresponds to the JSON property paddingLeftSuggested

Returns:

  • (Boolean)


6408
6409
6410
# File 'lib/google/apis/docs_v1/classes.rb', line 6408

def padding_left_suggested
  @padding_left_suggested
end

#padding_right_suggestedBoolean Also known as: padding_right_suggested?

Indicates if there was a suggested change to padding_right. Corresponds to the JSON property paddingRightSuggested

Returns:

  • (Boolean)


6414
6415
6416
# File 'lib/google/apis/docs_v1/classes.rb', line 6414

def padding_right_suggested
  @padding_right_suggested
end

#padding_top_suggestedBoolean Also known as: padding_top_suggested?

Indicates if there was a suggested change to padding_top. Corresponds to the JSON property paddingTopSuggested

Returns:

  • (Boolean)


6420
6421
6422
# File 'lib/google/apis/docs_v1/classes.rb', line 6420

def padding_top_suggested
  @padding_top_suggested
end

#row_span_suggestedBoolean Also known as: row_span_suggested?

Indicates if there was a suggested change to row_span. Corresponds to the JSON property rowSpanSuggested

Returns:

  • (Boolean)


6426
6427
6428
# File 'lib/google/apis/docs_v1/classes.rb', line 6426

def row_span_suggested
  @row_span_suggested
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6434
6435
6436
6437
6438
6439
6440
6441
6442
6443
6444
6445
6446
6447
# File 'lib/google/apis/docs_v1/classes.rb', line 6434

def update!(**args)
  @background_color_suggested = args[:background_color_suggested] if args.key?(:background_color_suggested)
  @border_bottom_suggested = args[:border_bottom_suggested] if args.key?(:border_bottom_suggested)
  @border_left_suggested = args[:border_left_suggested] if args.key?(:border_left_suggested)
  @border_right_suggested = args[:border_right_suggested] if args.key?(:border_right_suggested)
  @border_top_suggested = args[:border_top_suggested] if args.key?(:border_top_suggested)
  @column_span_suggested = args[:column_span_suggested] if args.key?(:column_span_suggested)
  @content_alignment_suggested = args[:content_alignment_suggested] if args.key?(:content_alignment_suggested)
  @padding_bottom_suggested = args[:padding_bottom_suggested] if args.key?(:padding_bottom_suggested)
  @padding_left_suggested = args[:padding_left_suggested] if args.key?(:padding_left_suggested)
  @padding_right_suggested = args[:padding_right_suggested] if args.key?(:padding_right_suggested)
  @padding_top_suggested = args[:padding_top_suggested] if args.key?(:padding_top_suggested)
  @row_span_suggested = args[:row_span_suggested] if args.key?(:row_span_suggested)
end