Class: Google::Apis::DocsV1::UpdateNamedStyleRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Updates a named style.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateNamedStyleRequest

Returns a new instance of UpdateNamedStyleRequest.



7061
7062
7063
# File 'lib/google/apis/docs_v1/classes.rb', line 7061

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsString

The NamedStyle fields that should be updated. At least named_style_type must be specified. The root named_style is implied and should not be specified. A single "*" can be used as short-hand for listing every field. For example, to update the text style to bold, set fields to include "text_style" and " text_style.bold". To update the paragraph style's alignment property, set fields to include "paragraph_style" and "paragraph_style.alignment". To reset a property to its default value, include its field name in the field mask but leave the field itself unset. Specifying "text_style" or " paragraph_style" with an empty TextStyle or ParagraphStyle will reset all of its nested fields. Corresponds to the JSON property fields

Returns:

  • (String)


7048
7049
7050
# File 'lib/google/apis/docs_v1/classes.rb', line 7048

def fields
  @fields
end

#named_styleGoogle::Apis::DocsV1::NamedStyle

A named style. Paragraphs in the document can inherit their TextStyle and ParagraphStyle from this named style when they have the same named style type. Corresponds to the JSON property namedStyle



7054
7055
7056
# File 'lib/google/apis/docs_v1/classes.rb', line 7054

def named_style
  @named_style
end

#tab_idString

The document tab to update. By default, the update is applied to the first tab. Corresponds to the JSON property tabId

Returns:

  • (String)


7059
7060
7061
# File 'lib/google/apis/docs_v1/classes.rb', line 7059

def tab_id
  @tab_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7066
7067
7068
7069
7070
# File 'lib/google/apis/docs_v1/classes.rb', line 7066

def update!(**args)
  @fields = args[:fields] if args.key?(:fields)
  @named_style = args[:named_style] if args.key?(:named_style)
  @tab_id = args[:tab_id] if args.key?(:tab_id)
end