Class: Google::Apis::DocsV1::UpdateTableColumnPropertiesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Updates the TableColumnProperties of columns in a table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateTableColumnPropertiesRequest

Returns a new instance of UpdateTableColumnPropertiesRequest.



7228
7229
7230
# File 'lib/google/apis/docs_v1/classes.rb', line 7228

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#column_indicesArray<Fixnum>

The list of zero-based column indices whose property should be updated. If no indices are specified, all columns will be updated. Corresponds to the JSON property columnIndices

Returns:

  • (Array<Fixnum>)


7208
7209
7210
# File 'lib/google/apis/docs_v1/classes.rb', line 7208

def column_indices
  @column_indices
end

#fieldsString

The fields that should be updated. At least one field must be specified. The root tableColumnProperties is implied and should not be specified. A single "*" can be used as short-hand for listing every field. For example to update the column width, set fields to "width". Corresponds to the JSON property fields

Returns:

  • (String)


7216
7217
7218
# File 'lib/google/apis/docs_v1/classes.rb', line 7216

def fields
  @fields
end

#table_column_propertiesGoogle::Apis::DocsV1::TableColumnProperties

The properties of a column in a table. Corresponds to the JSON property tableColumnProperties



7221
7222
7223
# File 'lib/google/apis/docs_v1/classes.rb', line 7221

def table_column_properties
  @table_column_properties
end

#table_start_locationGoogle::Apis::DocsV1::Location

A particular location in the document. Corresponds to the JSON property tableStartLocation



7226
7227
7228
# File 'lib/google/apis/docs_v1/classes.rb', line 7226

def table_start_location
  @table_start_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7233
7234
7235
7236
7237
7238
# File 'lib/google/apis/docs_v1/classes.rb', line 7233

def update!(**args)
  @column_indices = args[:column_indices] if args.key?(:column_indices)
  @fields = args[:fields] if args.key?(:fields)
  @table_column_properties = args[:table_column_properties] if args.key?(:table_column_properties)
  @table_start_location = args[:table_start_location] if args.key?(:table_start_location)
end