Class: Google::Apis::DocsV1::WeightedFontFamily

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Represents a font family and weight of text.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WeightedFontFamily

Returns a new instance of WeightedFontFamily.



7356
7357
7358
# File 'lib/google/apis/docs_v1/classes.rb', line 7356

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#font_familyString

The font family of the text. The font family can be any font from the Font menu in Docs or from [Google Fonts] (https://fonts.google.com/). If the font name is unrecognized, the text is rendered in Arial. Corresponds to the JSON property fontFamily

Returns:

  • (String)


7337
7338
7339
# File 'lib/google/apis/docs_v1/classes.rb', line 7337

def font_family
  @font_family
end

#weightFixnum

The weight of the font. This field can have any value that's a multiple of 100 between 100 and 900, inclusive. This range corresponds to the numerical values described in the CSS 2.1 Specification, [section 15.6](https:/ /www.w3.org/TR/CSS21/fonts.html#font-boldness), with non-numerical values disallowed. The default value is 400 ("normal"). The font weight makes up just one component of the rendered font weight. A combination of the weight and the text style's resolved bold value determine the rendered weight, after accounting for inheritance: * If the text is bold and the weight is less than 400, the rendered weight is 400. * If the text is bold and the weight is greater than or equal to 400 but is less than 700, the rendered weight is 700. * If the weight is greater than or equal to 700, the rendered weight is equal to the weight. * If the text is not bold, the rendered weight is equal to the weight. Corresponds to the JSON property weight

Returns:

  • (Fixnum)


7354
7355
7356
# File 'lib/google/apis/docs_v1/classes.rb', line 7354

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7361
7362
7363
7364
# File 'lib/google/apis/docs_v1/classes.rb', line 7361

def update!(**args)
  @font_family = args[:font_family] if args.key?(:font_family)
  @weight = args[:weight] if args.key?(:weight)
end