Class: Google::Apis::DocsV1::DeleteFooterRequest
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::DeleteFooterRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
Deletes a Footer from the document.
Instance Attribute Summary collapse
-
#footer_id ⇒ String
The id of the footer to delete.
-
#tab_id ⇒ String
The tab that contains the footer to delete.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeleteFooterRequest
constructor
A new instance of DeleteFooterRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeleteFooterRequest
Returns a new instance of DeleteFooterRequest.
966 967 968 |
# File 'lib/google/apis/docs_v1/classes.rb', line 966 def initialize(**args) update!(**args) end |
Instance Attribute Details
#footer_id ⇒ String
The id of the footer to delete. If this footer is defined on DocumentStyle,
the reference to this footer is removed, resulting in no footer of that type
for the first section of the document. If this footer is defined on a
SectionStyle, the reference to this footer is removed and the footer of that
type is now continued from the previous section.
Corresponds to the JSON property footerId
954 955 956 |
# File 'lib/google/apis/docs_v1/classes.rb', line 954 def @footer_id end |
#tab_id ⇒ String
The tab that contains the footer to delete. When omitted, the request is
applied to the first tab. In a document containing a single tab: - If provided,
must match the singular tab's ID. - If omitted, the request applies to the
singular tab. In a document containing multiple tabs: - If provided, the
request applies to the specified tab. - If omitted, the request applies to the
first tab in the document.
Corresponds to the JSON property tabId
964 965 966 |
# File 'lib/google/apis/docs_v1/classes.rb', line 964 def tab_id @tab_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
971 972 973 974 |
# File 'lib/google/apis/docs_v1/classes.rb', line 971 def update!(**args) @footer_id = args[:footer_id] if args.key?(:footer_id) @tab_id = args[:tab_id] if args.key?(:tab_id) end |