Class: Google::Apis::DocsV1::DeleteFooterRequest
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::DeleteFooterRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
Deletes a Footer from the document.
Instance Attribute Summary collapse
-
#footer_id ⇒ String
The id of the footer to delete.
-
#tab_id ⇒ String
The tab that contains the footer to delete.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeleteFooterRequest
constructor
A new instance of DeleteFooterRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeleteFooterRequest
Returns a new instance of DeleteFooterRequest.
921 922 923 |
# File 'lib/google/apis/docs_v1/classes.rb', line 921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#footer_id ⇒ String
The id of the footer to delete. If this footer is defined on DocumentStyle,
the reference to this footer is removed, resulting in no footer of that type
for the first section of the document. If this footer is defined on a
SectionStyle, the reference to this footer is removed and the footer of that
type is now continued from the previous section.
Corresponds to the JSON property footerId
909 910 911 |
# File 'lib/google/apis/docs_v1/classes.rb', line 909 def end |
#tab_id ⇒ String
The tab that contains the footer to delete. When omitted, the request is
applied to the first tab. In a document containing a single tab: - If provided,
must match the singular tab's ID. - If omitted, the request applies to the
singular tab. In a document containing multiple tabs: - If provided, the
request applies to the specified tab. - If omitted, the request applies to the
first tab in the document.
Corresponds to the JSON property tabId
919 920 921 |
# File 'lib/google/apis/docs_v1/classes.rb', line 919 def tab_id @tab_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
926 927 928 929 |
# File 'lib/google/apis/docs_v1/classes.rb', line 926 def update!(**args) = args[:footer_id] if args.key?(:footer_id) @tab_id = args[:tab_id] if args.key?(:tab_id) end |