Class: Google::Apis::DocsV1::DeleteParagraphBulletsRequest
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::DeleteParagraphBulletsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
Deletes bullets from all of the paragraphs that overlap with the given range. The nesting level of each paragraph will be visually preserved by adding indent to the start of the corresponding paragraph.
Instance Attribute Summary collapse
-
#range ⇒ Google::Apis::DocsV1::Range
Specifies a contiguous range of text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeleteParagraphBulletsRequest
constructor
A new instance of DeleteParagraphBulletsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeleteParagraphBulletsRequest
Returns a new instance of DeleteParagraphBulletsRequest.
1054 1055 1056 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1054 def initialize(**args) update!(**args) end |
Instance Attribute Details
#range ⇒ Google::Apis::DocsV1::Range
Specifies a contiguous range of text.
Corresponds to the JSON property range
1052 1053 1054 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1052 def range @range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1059 1060 1061 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1059 def update!(**args) @range = args[:range] if args.key?(:range) end |