Class: Google::Apis::DocsV1::Document
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::Document
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
A Google Docs document.
Instance Attribute Summary collapse
-
#body ⇒ Google::Apis::DocsV1::Body
The document body.
-
#document_id ⇒ String
Output only.
-
#document_style ⇒ Google::Apis::DocsV1::DocumentStyle
The style of the document.
-
#footers ⇒ Hash<String,Google::Apis::DocsV1::Footer>
Output only.
-
#footnotes ⇒ Hash<String,Google::Apis::DocsV1::Footnote>
Output only.
-
#headers ⇒ Hash<String,Google::Apis::DocsV1::Header>
Output only.
-
#inline_objects ⇒ Hash<String,Google::Apis::DocsV1::InlineObject>
Output only.
-
#lists ⇒ Hash<String,Google::Apis::DocsV1::List>
Output only.
-
#named_ranges ⇒ Hash<String,Google::Apis::DocsV1::NamedRanges>
Output only.
-
#named_styles ⇒ Google::Apis::DocsV1::NamedStyles
The named styles.
-
#positioned_objects ⇒ Hash<String,Google::Apis::DocsV1::PositionedObject>
Output only.
-
#revision_id ⇒ String
Output only.
-
#suggested_document_style_changes ⇒ Hash<String,Google::Apis::DocsV1::SuggestedDocumentStyle>
Output only.
-
#suggested_named_styles_changes ⇒ Hash<String,Google::Apis::DocsV1::SuggestedNamedStyles>
Output only.
-
#suggestions_view_mode ⇒ String
Output only.
-
#tabs ⇒ Array<Google::Apis::DocsV1::Tab>
Tabs that are part of a document.
-
#title ⇒ String
The title of the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Document
constructor
A new instance of Document.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Document
Returns a new instance of Document.
1316 1317 1318 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1316 def initialize(**args) update!(**args) end |
Instance Attribute Details
#body ⇒ Google::Apis::DocsV1::Body
The document body. The body typically contains the full document contents
except for headers, footers, and footnotes.
Corresponds to the JSON property body
1184 1185 1186 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1184 def body @body end |
#document_id ⇒ String
Output only. The ID of the document.
Corresponds to the JSON property documentId
1189 1190 1191 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1189 def document_id @document_id end |
#document_style ⇒ Google::Apis::DocsV1::DocumentStyle
The style of the document.
Corresponds to the JSON property documentStyle
1194 1195 1196 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1194 def document_style @document_style end |
#footers ⇒ Hash<String,Google::Apis::DocsV1::Footer>
Output only. The footers in the document, keyed by footer ID. Legacy field:
Instead, use Document.tabs.documentTab.footers, which exposes the actual
document content from all tabs when the includeTabsContent parameter is set to
true. If false or unset, this field contains information about the first
tab in the document.
Corresponds to the JSON property footers
1203 1204 1205 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1203 def @footers end |
#footnotes ⇒ Hash<String,Google::Apis::DocsV1::Footnote>
Output only. The footnotes in the document, keyed by footnote ID. Legacy field:
Instead, use Document.tabs.documentTab.footnotes, which exposes the actual
document content from all tabs when the includeTabsContent parameter is set to
true. If false or unset, this field contains information about the first
tab in the document.
Corresponds to the JSON property footnotes
1212 1213 1214 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1212 def footnotes @footnotes end |
#headers ⇒ Hash<String,Google::Apis::DocsV1::Header>
Output only. The headers in the document, keyed by header ID. Legacy field:
Instead, use Document.tabs.documentTab.headers, which exposes the actual
document content from all tabs when the includeTabsContent parameter is set to
true. If false or unset, this field contains information about the first
tab in the document.
Corresponds to the JSON property headers
1221 1222 1223 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1221 def headers @headers end |
#inline_objects ⇒ Hash<String,Google::Apis::DocsV1::InlineObject>
Output only. The inline objects in the document, keyed by object ID. Legacy
field: Instead, use Document.tabs.documentTab.inlineObjects, which exposes the
actual document content from all tabs when the includeTabsContent parameter is
set to true. If false or unset, this field contains information about the
first tab in the document.
Corresponds to the JSON property inlineObjects
1230 1231 1232 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1230 def inline_objects @inline_objects end |
#lists ⇒ Hash<String,Google::Apis::DocsV1::List>
Output only. The lists in the document, keyed by list ID. Legacy field:
Instead, use Document.tabs.documentTab.lists, which exposes the actual
document content from all tabs when the includeTabsContent parameter is set to
true. If false or unset, this field contains information about the first
tab in the document.
Corresponds to the JSON property lists
1239 1240 1241 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1239 def lists @lists end |
#named_ranges ⇒ Hash<String,Google::Apis::DocsV1::NamedRanges>
Output only. The named ranges in the document, keyed by name. Legacy field:
Instead, use Document.tabs.documentTab.namedRanges, which exposes the actual
document content from all tabs when the includeTabsContent parameter is set to
true. If false or unset, this field contains information about the first
tab in the document.
Corresponds to the JSON property namedRanges
1248 1249 1250 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1248 def named_ranges @named_ranges end |
#named_styles ⇒ Google::Apis::DocsV1::NamedStyles
The named styles. Paragraphs in the document can inherit their TextStyle and
ParagraphStyle from these named styles.
Corresponds to the JSON property namedStyles
1254 1255 1256 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1254 def named_styles @named_styles end |
#positioned_objects ⇒ Hash<String,Google::Apis::DocsV1::PositionedObject>
Output only. The positioned objects in the document, keyed by object ID.
Legacy field: Instead, use Document.tabs.documentTab.positionedObjects, which
exposes the actual document content from all tabs when the includeTabsContent
parameter is set to true. If false or unset, this field contains
information about the first tab in the document.
Corresponds to the JSON property positionedObjects
1263 1264 1265 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1263 def positioned_objects @positioned_objects end |
#revision_id ⇒ String
Output only. The revision ID of the document. Can be used in update requests
to specify which revision of a document to apply updates to and how the
request should behave if the document has been edited since that revision.
Only populated if the user has edit access to the document. The revision ID is
not a sequential number but an opaque string. The format of the revision ID
might change over time. A returned revision ID is only guaranteed to be valid
for 24 hours after it has been returned and cannot be shared across users. If
the revision ID is unchanged between calls, then the document has not changed.
Conversely, a changed ID (for the same document and user) usually means the
document has been updated. However, a changed ID can also be due to internal
factors such as ID format changes.
Corresponds to the JSON property revisionId
1278 1279 1280 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1278 def revision_id @revision_id end |
#suggested_document_style_changes ⇒ Hash<String,Google::Apis::DocsV1::SuggestedDocumentStyle>
Output only. The suggested changes to the style of the document, keyed by
suggestion ID. Legacy field: Instead, use Document.tabs.documentTab.
suggestedDocumentStyleChanges, which exposes the actual document content from
all tabs when the includeTabsContent parameter is set to true. If false or
unset, this field contains information about the first tab in the document.
Corresponds to the JSON property suggestedDocumentStyleChanges
1287 1288 1289 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1287 def suggested_document_style_changes @suggested_document_style_changes end |
#suggested_named_styles_changes ⇒ Hash<String,Google::Apis::DocsV1::SuggestedNamedStyles>
Output only. The suggested changes to the named styles of the document, keyed
by suggestion ID. Legacy field: Instead, use Document.tabs.documentTab.
suggestedNamedStylesChanges, which exposes the actual document content from
all tabs when the includeTabsContent parameter is set to true. If false or
unset, this field contains information about the first tab in the document.
Corresponds to the JSON property suggestedNamedStylesChanges
1296 1297 1298 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1296 def suggested_named_styles_changes @suggested_named_styles_changes end |
#suggestions_view_mode ⇒ String
Output only. The suggestions view mode applied to the document. Note: When
editing a document, changes must be based on a document with
SUGGESTIONS_INLINE.
Corresponds to the JSON property suggestionsViewMode
1303 1304 1305 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1303 def suggestions_view_mode @suggestions_view_mode end |
#tabs ⇒ Array<Google::Apis::DocsV1::Tab>
Tabs that are part of a document. Tabs can contain child tabs, a tab nested
within another tab. Child tabs are represented by the Tab.childTabs field.
Corresponds to the JSON property tabs
1309 1310 1311 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1309 def tabs @tabs end |
#title ⇒ String
The title of the document.
Corresponds to the JSON property title
1314 1315 1316 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1314 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1321 def update!(**args) @body = args[:body] if args.key?(:body) @document_id = args[:document_id] if args.key?(:document_id) @document_style = args[:document_style] if args.key?(:document_style) @footers = args[:footers] if args.key?(:footers) @footnotes = args[:footnotes] if args.key?(:footnotes) @headers = args[:headers] if args.key?(:headers) @inline_objects = args[:inline_objects] if args.key?(:inline_objects) @lists = args[:lists] if args.key?(:lists) @named_ranges = args[:named_ranges] if args.key?(:named_ranges) @named_styles = args[:named_styles] if args.key?(:named_styles) @positioned_objects = args[:positioned_objects] if args.key?(:positioned_objects) @revision_id = args[:revision_id] if args.key?(:revision_id) @suggested_document_style_changes = args[:suggested_document_style_changes] if args.key?(:suggested_document_style_changes) @suggested_named_styles_changes = args[:suggested_named_styles_changes] if args.key?(:suggested_named_styles_changes) @suggestions_view_mode = args[:suggestions_view_mode] if args.key?(:suggestions_view_mode) @tabs = args[:tabs] if args.key?(:tabs) @title = args[:title] if args.key?(:title) end |