Class: Google::Apis::DocsV1::DocumentStyle
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::DocumentStyle
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
The style of the document.
Instance Attribute Summary collapse
-
#background ⇒ Google::Apis::DocsV1::Background
Represents the background of a document.
-
#default_footer_id ⇒ String
The ID of the default footer.
-
#default_header_id ⇒ String
The ID of the default header.
-
#document_format ⇒ Google::Apis::DocsV1::DocumentFormat
Represents document-level format settings.
-
#even_page_footer_id ⇒ String
The ID of the footer used only for even pages.
-
#even_page_header_id ⇒ String
The ID of the header used only for even pages.
-
#first_page_footer_id ⇒ String
The ID of the footer used only for the first page.
-
#first_page_header_id ⇒ String
The ID of the header used only for the first page.
-
#flip_page_orientation ⇒ Boolean
(also: #flip_page_orientation?)
Optional.
-
#margin_bottom ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#margin_footer ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#margin_header ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#margin_left ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#margin_right ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#margin_top ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#page_number_start ⇒ Fixnum
The page number from which to start counting the number of pages.
-
#page_size ⇒ Google::Apis::DocsV1::Size
A width and height.
-
#use_custom_header_footer_margins ⇒ Boolean
(also: #use_custom_header_footer_margins?)
Indicates whether DocumentStyle margin_header, SectionStyle margin_header and DocumentStyle margin_footer, SectionStyle margin_footer are respected.
-
#use_even_page_header_footer ⇒ Boolean
(also: #use_even_page_header_footer?)
Indicates whether to use the even page header / footer IDs for the even pages.
-
#use_first_page_header_footer ⇒ Boolean
(also: #use_first_page_header_footer?)
Indicates whether to use the first page header / footer IDs for the first page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DocumentStyle
constructor
A new instance of DocumentStyle.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DocumentStyle
Returns a new instance of DocumentStyle.
1317 1318 1319 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background ⇒ Google::Apis::DocsV1::Background
Represents the background of a document.
Corresponds to the JSON property background
1185 1186 1187 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1185 def background @background end |
#default_footer_id ⇒ String
The ID of the default footer. If not set, there's no default footer. If
DocumentMode is PAGELESS, this property will not be rendered. This property is
read-only.
Corresponds to the JSON property defaultFooterId
1192 1193 1194 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1192 def end |
#default_header_id ⇒ String
The ID of the default header. If not set, there's no default header. If
DocumentMode is PAGELESS, this property will not be rendered. This property is
read-only.
Corresponds to the JSON property defaultHeaderId
1199 1200 1201 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1199 def default_header_id @default_header_id end |
#document_format ⇒ Google::Apis::DocsV1::DocumentFormat
Represents document-level format settings.
Corresponds to the JSON property documentFormat
1204 1205 1206 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1204 def document_format @document_format end |
#even_page_footer_id ⇒ String
The ID of the footer used only for even pages. The value of
use_even_page_header_footer determines whether to use the default_footer_id or
this value for the footer on even pages. If not set, there's no even page
footer. If DocumentMode is PAGELESS, this property will not be rendered. This
property is read-only.
Corresponds to the JSON property evenPageFooterId
1213 1214 1215 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1213 def end |
#even_page_header_id ⇒ String
The ID of the header used only for even pages. The value of
use_even_page_header_footer determines whether to use the default_header_id or
this value for the header on even pages. If not set, there's no even page
header. If DocumentMode is PAGELESS, this property will not be rendered. This
property is read-only.
Corresponds to the JSON property evenPageHeaderId
1222 1223 1224 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1222 def even_page_header_id @even_page_header_id end |
#first_page_footer_id ⇒ String
The ID of the footer used only for the first page. If not set then a unique
footer for the first page does not exist. The value of
use_first_page_header_footer determines whether to use the default_footer_id
or this value for the footer on the first page. If not set, there's no first
page footer. If DocumentMode is PAGELESS, this property will not be rendered.
This property is read-only.
Corresponds to the JSON property firstPageFooterId
1232 1233 1234 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1232 def end |
#first_page_header_id ⇒ String
The ID of the header used only for the first page. If not set then a unique
header for the first page does not exist. The value of
use_first_page_header_footer determines whether to use the default_header_id
or this value for the header on the first page. If not set, there's no first
page header. If DocumentMode is PAGELESS, this property will not be rendered.
This property is read-only.
Corresponds to the JSON property firstPageHeaderId
1242 1243 1244 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1242 def first_page_header_id @first_page_header_id end |
#flip_page_orientation ⇒ Boolean Also known as: flip_page_orientation?
Optional. Indicates whether to flip the dimensions of the page_size, which
allows changing the page orientation between portrait and landscape. If
DocumentMode is PAGELESS, this property will not be rendered.
Corresponds to the JSON property flipPageOrientation
1249 1250 1251 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1249 def flip_page_orientation @flip_page_orientation end |
#margin_bottom ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property marginBottom
1255 1256 1257 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1255 def margin_bottom @margin_bottom end |
#margin_footer ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property marginFooter
1260 1261 1262 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1260 def end |
#margin_header ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property marginHeader
1265 1266 1267 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1265 def margin_header @margin_header end |
#margin_left ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property marginLeft
1270 1271 1272 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1270 def margin_left @margin_left end |
#margin_right ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property marginRight
1275 1276 1277 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1275 def margin_right @margin_right end |
#margin_top ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property marginTop
1280 1281 1282 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1280 def margin_top @margin_top end |
#page_number_start ⇒ Fixnum
The page number from which to start counting the number of pages. If
DocumentMode is PAGELESS, this property will not be rendered.
Corresponds to the JSON property pageNumberStart
1286 1287 1288 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1286 def page_number_start @page_number_start end |
#page_size ⇒ Google::Apis::DocsV1::Size
A width and height.
Corresponds to the JSON property pageSize
1291 1292 1293 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1291 def page_size @page_size end |
#use_custom_header_footer_margins ⇒ Boolean Also known as:
Indicates whether DocumentStyle margin_header, SectionStyle margin_header and
DocumentStyle margin_footer, SectionStyle margin_footer are respected. When
false, the default values in the Docs editor for header and footer margin is
used. If DocumentMode is PAGELESS, this property will not be rendered. This
property is read-only.
Corresponds to the JSON property useCustomHeaderFooterMargins
1300 1301 1302 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1300 def end |
#use_even_page_header_footer ⇒ Boolean Also known as:
Indicates whether to use the even page header / footer IDs for the even pages.
If DocumentMode is PAGELESS, this property will not be rendered.
Corresponds to the JSON property useEvenPageHeaderFooter
1307 1308 1309 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1307 def end |
#use_first_page_header_footer ⇒ Boolean Also known as:
Indicates whether to use the first page header / footer IDs for the first page.
If DocumentMode is PAGELESS, this property will not be rendered.
Corresponds to the JSON property useFirstPageHeaderFooter
1314 1315 1316 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1314 def end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1322 def update!(**args) @background = args[:background] if args.key?(:background) = args[:default_footer_id] if args.key?(:default_footer_id) @default_header_id = args[:default_header_id] if args.key?(:default_header_id) @document_format = args[:document_format] if args.key?(:document_format) = args[:even_page_footer_id] if args.key?(:even_page_footer_id) @even_page_header_id = args[:even_page_header_id] if args.key?(:even_page_header_id) = args[:first_page_footer_id] if args.key?(:first_page_footer_id) @first_page_header_id = args[:first_page_header_id] if args.key?(:first_page_header_id) @flip_page_orientation = args[:flip_page_orientation] if args.key?(:flip_page_orientation) @margin_bottom = args[:margin_bottom] if args.key?(:margin_bottom) = args[:margin_footer] if args.key?(:margin_footer) @margin_header = args[:margin_header] if args.key?(:margin_header) @margin_left = args[:margin_left] if args.key?(:margin_left) @margin_right = args[:margin_right] if args.key?(:margin_right) @margin_top = args[:margin_top] if args.key?(:margin_top) @page_number_start = args[:page_number_start] if args.key?(:page_number_start) @page_size = args[:page_size] if args.key?(:page_size) = args[:use_custom_header_footer_margins] if args.key?(:use_custom_header_footer_margins) = args[:use_even_page_header_footer] if args.key?(:use_even_page_header_footer) = args[:use_first_page_header_footer] if args.key?(:use_first_page_header_footer) end |