Class: Google::Apis::DocsV1::DocumentTab
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::DocumentTab
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
A tab with document contents.
Instance Attribute Summary collapse
-
#body ⇒ Google::Apis::DocsV1::Body
The document body.
-
#document_style ⇒ Google::Apis::DocsV1::DocumentStyle
The style of the document.
-
#footers ⇒ Hash<String,Google::Apis::DocsV1::Footer>
The footers in the document tab, keyed by footer ID.
-
#footnotes ⇒ Hash<String,Google::Apis::DocsV1::Footnote>
The footnotes in the document tab, keyed by footnote ID.
-
#headers ⇒ Hash<String,Google::Apis::DocsV1::Header>
The headers in the document tab, keyed by header ID.
-
#inline_objects ⇒ Hash<String,Google::Apis::DocsV1::InlineObject>
The inline objects in the document tab, keyed by object ID.
-
#lists ⇒ Hash<String,Google::Apis::DocsV1::List>
The lists in the document tab, keyed by list ID.
-
#named_ranges ⇒ Hash<String,Google::Apis::DocsV1::NamedRanges>
The named ranges in the document tab, keyed by name.
-
#named_styles ⇒ Google::Apis::DocsV1::NamedStyles
The named styles.
-
#positioned_objects ⇒ Hash<String,Google::Apis::DocsV1::PositionedObject>
The positioned objects in the document tab, keyed by object ID.
-
#suggested_document_style_changes ⇒ Hash<String,Google::Apis::DocsV1::SuggestedDocumentStyle>
The suggested changes to the style of the document tab, keyed by suggestion ID.
-
#suggested_named_styles_changes ⇒ Hash<String,Google::Apis::DocsV1::SuggestedNamedStyles>
The suggested changes to the named styles of the document tab, keyed by suggestion ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DocumentTab
constructor
A new instance of DocumentTab.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DocumentTab
Returns a new instance of DocumentTab.
1746 1747 1748 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1746 def initialize(**args) update!(**args) end |
Instance Attribute Details
#body ⇒ Google::Apis::DocsV1::Body
The document body. The body typically contains the full document contents
except for headers, footers, and footnotes.
Corresponds to the JSON property body
1687 1688 1689 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1687 def body @body end |
#document_style ⇒ Google::Apis::DocsV1::DocumentStyle
The style of the document.
Corresponds to the JSON property documentStyle
1692 1693 1694 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1692 def document_style @document_style end |
#footers ⇒ Hash<String,Google::Apis::DocsV1::Footer>
The footers in the document tab, keyed by footer ID.
Corresponds to the JSON property footers
1697 1698 1699 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1697 def @footers end |
#footnotes ⇒ Hash<String,Google::Apis::DocsV1::Footnote>
The footnotes in the document tab, keyed by footnote ID.
Corresponds to the JSON property footnotes
1702 1703 1704 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1702 def footnotes @footnotes end |
#headers ⇒ Hash<String,Google::Apis::DocsV1::Header>
The headers in the document tab, keyed by header ID.
Corresponds to the JSON property headers
1707 1708 1709 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1707 def headers @headers end |
#inline_objects ⇒ Hash<String,Google::Apis::DocsV1::InlineObject>
The inline objects in the document tab, keyed by object ID.
Corresponds to the JSON property inlineObjects
1712 1713 1714 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1712 def inline_objects @inline_objects end |
#lists ⇒ Hash<String,Google::Apis::DocsV1::List>
The lists in the document tab, keyed by list ID.
Corresponds to the JSON property lists
1717 1718 1719 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1717 def lists @lists end |
#named_ranges ⇒ Hash<String,Google::Apis::DocsV1::NamedRanges>
The named ranges in the document tab, keyed by name.
Corresponds to the JSON property namedRanges
1722 1723 1724 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1722 def named_ranges @named_ranges end |
#named_styles ⇒ Google::Apis::DocsV1::NamedStyles
The named styles. Paragraphs in the document can inherit their TextStyle and
ParagraphStyle from these named styles.
Corresponds to the JSON property namedStyles
1728 1729 1730 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1728 def named_styles @named_styles end |
#positioned_objects ⇒ Hash<String,Google::Apis::DocsV1::PositionedObject>
The positioned objects in the document tab, keyed by object ID.
Corresponds to the JSON property positionedObjects
1733 1734 1735 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1733 def positioned_objects @positioned_objects end |
#suggested_document_style_changes ⇒ Hash<String,Google::Apis::DocsV1::SuggestedDocumentStyle>
The suggested changes to the style of the document tab, keyed by suggestion ID.
Corresponds to the JSON property suggestedDocumentStyleChanges
1738 1739 1740 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1738 def suggested_document_style_changes @suggested_document_style_changes end |
#suggested_named_styles_changes ⇒ Hash<String,Google::Apis::DocsV1::SuggestedNamedStyles>
The suggested changes to the named styles of the document tab, keyed by
suggestion ID.
Corresponds to the JSON property suggestedNamedStylesChanges
1744 1745 1746 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1744 def suggested_named_styles_changes @suggested_named_styles_changes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 |
# File 'lib/google/apis/docs_v1/classes.rb', line 1751 def update!(**args) @body = args[:body] if args.key?(:body) @document_style = args[:document_style] if args.key?(:document_style) @footers = args[:footers] if args.key?(:footers) @footnotes = args[:footnotes] if args.key?(:footnotes) @headers = args[:headers] if args.key?(:headers) @inline_objects = args[:inline_objects] if args.key?(:inline_objects) @lists = args[:lists] if args.key?(:lists) @named_ranges = args[:named_ranges] if args.key?(:named_ranges) @named_styles = args[:named_styles] if args.key?(:named_styles) @positioned_objects = args[:positioned_objects] if args.key?(:positioned_objects) @suggested_document_style_changes = args[:suggested_document_style_changes] if args.key?(:suggested_document_style_changes) @suggested_named_styles_changes = args[:suggested_named_styles_changes] if args.key?(:suggested_named_styles_changes) end |