Class: Google::Apis::DocsV1::InsertInlineImageRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Inserts an InlineObject containing an image at the given location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertInlineImageRequest

Returns a new instance of InsertInlineImageRequest.



2484
2485
2486
# File 'lib/google/apis/docs_v1/classes.rb', line 2484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_of_segment_locationGoogle::Apis::DocsV1::EndOfSegmentLocation

Location at the end of a body, header, footer or footnote. The location is immediately before the last newline in the document segment. Corresponds to the JSON property endOfSegmentLocation



2462
2463
2464
# File 'lib/google/apis/docs_v1/classes.rb', line 2462

def end_of_segment_location
  @end_of_segment_location
end

#locationGoogle::Apis::DocsV1::Location

A particular location in the document. Corresponds to the JSON property location



2467
2468
2469
# File 'lib/google/apis/docs_v1/classes.rb', line 2467

def location
  @location
end

#object_sizeGoogle::Apis::DocsV1::Size

A width and height. Corresponds to the JSON property objectSize



2472
2473
2474
# File 'lib/google/apis/docs_v1/classes.rb', line 2472

def object_size
  @object_size
end

#uriString

The image URI. The image is fetched once at insertion time and a copy is stored for display inside the document. Images must be less than 50MB in size, cannot exceed 25 megapixels, and must be in one of PNG, JPEG, or GIF format. The provided URI must be publicly accessible and at most 2 kB in length. The URI itself is saved with the image, and exposed via the ImageProperties. content_uri field. Corresponds to the JSON property uri

Returns:

  • (String)


2482
2483
2484
# File 'lib/google/apis/docs_v1/classes.rb', line 2482

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2489
2490
2491
2492
2493
2494
# File 'lib/google/apis/docs_v1/classes.rb', line 2489

def update!(**args)
  @end_of_segment_location = args[:end_of_segment_location] if args.key?(:end_of_segment_location)
  @location = args[:location] if args.key?(:location)
  @object_size = args[:object_size] if args.key?(:object_size)
  @uri = args[:uri] if args.key?(:uri)
end