Class: Google::Apis::DocsV1::InsertPersonRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Inserts a person mention.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertPersonRequest

Returns a new instance of InsertPersonRequest.



2764
2765
2766
# File 'lib/google/apis/docs_v1/classes.rb', line 2764

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_of_segment_locationGoogle::Apis::DocsV1::EndOfSegmentLocation

Location at the end of a body, header, footer or footnote. The location is immediately before the last newline in the document segment. Corresponds to the JSON property endOfSegmentLocation



2752
2753
2754
# File 'lib/google/apis/docs_v1/classes.rb', line 2752

def end_of_segment_location
  @end_of_segment_location
end

#locationGoogle::Apis::DocsV1::Location

A particular location in the document. Corresponds to the JSON property location



2757
2758
2759
# File 'lib/google/apis/docs_v1/classes.rb', line 2757

def location
  @location
end

#person_propertiesGoogle::Apis::DocsV1::PersonProperties

Properties specific to a linked Person. Corresponds to the JSON property personProperties



2762
2763
2764
# File 'lib/google/apis/docs_v1/classes.rb', line 2762

def person_properties
  @person_properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2769
2770
2771
2772
2773
# File 'lib/google/apis/docs_v1/classes.rb', line 2769

def update!(**args)
  @end_of_segment_location = args[:end_of_segment_location] if args.key?(:end_of_segment_location)
  @location = args[:location] if args.key?(:location)
  @person_properties = args[:person_properties] if args.key?(:person_properties)
end