Class: Google::Apis::DocsV1::InsertRichLinkRequest
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::InsertRichLinkRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
Inserts a RichLink at the specified location.
Instance Attribute Summary collapse
-
#end_of_segment_location ⇒ Google::Apis::DocsV1::EndOfSegmentLocation
Location at the end of a body, header, footer or footnote.
-
#location ⇒ Google::Apis::DocsV1::Location
A particular location in the document.
-
#rich_link_properties ⇒ Google::Apis::DocsV1::RichLinkProperties
Properties specific to a RichLink.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InsertRichLinkRequest
constructor
A new instance of InsertRichLinkRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InsertRichLinkRequest
Returns a new instance of InsertRichLinkRequest.
2796 2797 2798 |
# File 'lib/google/apis/docs_v1/classes.rb', line 2796 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_of_segment_location ⇒ Google::Apis::DocsV1::EndOfSegmentLocation
Location at the end of a body, header, footer or footnote. The location is
immediately before the last newline in the document segment.
Corresponds to the JSON property endOfSegmentLocation
2784 2785 2786 |
# File 'lib/google/apis/docs_v1/classes.rb', line 2784 def end_of_segment_location @end_of_segment_location end |
#location ⇒ Google::Apis::DocsV1::Location
A particular location in the document.
Corresponds to the JSON property location
2789 2790 2791 |
# File 'lib/google/apis/docs_v1/classes.rb', line 2789 def location @location end |
#rich_link_properties ⇒ Google::Apis::DocsV1::RichLinkProperties
Properties specific to a RichLink.
Corresponds to the JSON property richLinkProperties
2794 2795 2796 |
# File 'lib/google/apis/docs_v1/classes.rb', line 2794 def rich_link_properties @rich_link_properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2801 2802 2803 2804 2805 |
# File 'lib/google/apis/docs_v1/classes.rb', line 2801 def update!(**args) @end_of_segment_location = args[:end_of_segment_location] if args.key?(:end_of_segment_location) @location = args[:location] if args.key?(:location) @rich_link_properties = args[:rich_link_properties] if args.key?(:rich_link_properties) end |