Class: Google::Apis::DocsV1::InsertTableRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Inserts a table at the specified location. A newline character will be inserted before the inserted table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertTableRequest

Returns a new instance of InsertTableRequest.



2894
2895
2896
# File 'lib/google/apis/docs_v1/classes.rb', line 2894

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnsFixnum

The number of columns in the table. Corresponds to the JSON property columns

Returns:

  • (Fixnum)


2876
2877
2878
# File 'lib/google/apis/docs_v1/classes.rb', line 2876

def columns
  @columns
end

#end_of_segment_locationGoogle::Apis::DocsV1::EndOfSegmentLocation

Location at the end of a body, header, footer or footnote. The location is immediately before the last newline in the document segment. Corresponds to the JSON property endOfSegmentLocation



2882
2883
2884
# File 'lib/google/apis/docs_v1/classes.rb', line 2882

def end_of_segment_location
  @end_of_segment_location
end

#locationGoogle::Apis::DocsV1::Location

A particular location in the document. Corresponds to the JSON property location



2887
2888
2889
# File 'lib/google/apis/docs_v1/classes.rb', line 2887

def location
  @location
end

#rowsFixnum

The number of rows in the table. Corresponds to the JSON property rows

Returns:

  • (Fixnum)


2892
2893
2894
# File 'lib/google/apis/docs_v1/classes.rb', line 2892

def rows
  @rows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2899
2900
2901
2902
2903
2904
# File 'lib/google/apis/docs_v1/classes.rb', line 2899

def update!(**args)
  @columns = args[:columns] if args.key?(:columns)
  @end_of_segment_location = args[:end_of_segment_location] if args.key?(:end_of_segment_location)
  @location = args[:location] if args.key?(:location)
  @rows = args[:rows] if args.key?(:rows)
end