Class: Google::Apis::DocsV1::NamedRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

A collection of Ranges with the same named range ID. Named ranges allow developers to associate parts of a document with an arbitrary user-defined label so their contents can be programmatically read or edited later. A document can contain multiple named ranges with the same name, but every named range has a unique ID. A named range is created with a single Range, and content inserted inside a named range generally expands that range. However, certain document changes can cause the range to be split into multiple ranges. Named ranges are not private. All applications and collaborators that have access to the document can see its named ranges.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NamedRange

Returns a new instance of NamedRange.



3218
3219
3220
# File 'lib/google/apis/docs_v1/classes.rb', line 3218

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the named range. Corresponds to the JSON property name

Returns:

  • (String)


3206
3207
3208
# File 'lib/google/apis/docs_v1/classes.rb', line 3206

def name
  @name
end

#named_range_idString

The ID of the named range. Corresponds to the JSON property namedRangeId

Returns:

  • (String)


3211
3212
3213
# File 'lib/google/apis/docs_v1/classes.rb', line 3211

def named_range_id
  @named_range_id
end

#rangesArray<Google::Apis::DocsV1::Range>

The ranges that belong to this named range. Corresponds to the JSON property ranges

Returns:



3216
3217
3218
# File 'lib/google/apis/docs_v1/classes.rb', line 3216

def ranges
  @ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3223
3224
3225
3226
3227
# File 'lib/google/apis/docs_v1/classes.rb', line 3223

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @named_range_id = args[:named_range_id] if args.key?(:named_range_id)
  @ranges = args[:ranges] if args.key?(:ranges)
end