Class: Google::Apis::DocsV1::NamedStylesSuggestionState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

The suggestion state of a NamedStyles message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NamedStylesSuggestionState

Returns a new instance of NamedStylesSuggestionState.



3413
3414
3415
# File 'lib/google/apis/docs_v1/classes.rb', line 3413

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#styles_suggestion_statesArray<Google::Apis::DocsV1::NamedStyleSuggestionState>

A mask that indicates which of the fields on the corresponding NamedStyle in styles have been changed in this suggestion. The order of these named style suggestion states matches the order of the corresponding named style within the named styles suggestion. Corresponds to the JSON property stylesSuggestionStates



3411
3412
3413
# File 'lib/google/apis/docs_v1/classes.rb', line 3411

def styles_suggestion_states
  @styles_suggestion_states
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3418
3419
3420
# File 'lib/google/apis/docs_v1/classes.rb', line 3418

def update!(**args)
  @styles_suggestion_states = args[:styles_suggestion_states] if args.key?(:styles_suggestion_states)
end