Class: Google::Apis::DocsV1::NamedStylesSuggestionState
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::NamedStylesSuggestionState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
The suggestion state of a NamedStyles message.
Instance Attribute Summary collapse
-
#styles_suggestion_states ⇒ Array<Google::Apis::DocsV1::NamedStyleSuggestionState>
A mask that indicates which of the fields on the corresponding NamedStyle in styles have been changed in this suggestion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NamedStylesSuggestionState
constructor
A new instance of NamedStylesSuggestionState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NamedStylesSuggestionState
Returns a new instance of NamedStylesSuggestionState.
3375 3376 3377 |
# File 'lib/google/apis/docs_v1/classes.rb', line 3375 def initialize(**args) update!(**args) end |
Instance Attribute Details
#styles_suggestion_states ⇒ Array<Google::Apis::DocsV1::NamedStyleSuggestionState>
A mask that indicates which of the fields on the corresponding NamedStyle in
styles have been changed in this suggestion. The order of these named style
suggestion states matches the order of the corresponding named style within
the named styles suggestion.
Corresponds to the JSON property stylesSuggestionStates
3373 3374 3375 |
# File 'lib/google/apis/docs_v1/classes.rb', line 3373 def styles_suggestion_states @styles_suggestion_states end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3380 3381 3382 |
# File 'lib/google/apis/docs_v1/classes.rb', line 3380 def update!(**args) @styles_suggestion_states = args[:styles_suggestion_states] if args.key?(:styles_suggestion_states) end |