Class: Google::Apis::DocsV1::ParagraphBorder
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::ParagraphBorder
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
A border around a paragraph.
Instance Attribute Summary collapse
-
#color ⇒ Google::Apis::DocsV1::OptionalColor
A color that can either be fully opaque or fully transparent.
-
#dash_style ⇒ String
The dash style of the border.
-
#padding ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#width ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ParagraphBorder
constructor
A new instance of ParagraphBorder.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ParagraphBorder
Returns a new instance of ParagraphBorder.
3679 3680 3681 |
# File 'lib/google/apis/docs_v1/classes.rb', line 3679 def initialize(**args) update!(**args) end |
Instance Attribute Details
#color ⇒ Google::Apis::DocsV1::OptionalColor
A color that can either be fully opaque or fully transparent.
Corresponds to the JSON property color
3662 3663 3664 |
# File 'lib/google/apis/docs_v1/classes.rb', line 3662 def color @color end |
#dash_style ⇒ String
The dash style of the border.
Corresponds to the JSON property dashStyle
3667 3668 3669 |
# File 'lib/google/apis/docs_v1/classes.rb', line 3667 def dash_style @dash_style end |
#padding ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property padding
3672 3673 3674 |
# File 'lib/google/apis/docs_v1/classes.rb', line 3672 def padding @padding end |
#width ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property width
3677 3678 3679 |
# File 'lib/google/apis/docs_v1/classes.rb', line 3677 def width @width end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3684 3685 3686 3687 3688 3689 |
# File 'lib/google/apis/docs_v1/classes.rb', line 3684 def update!(**args) @color = args[:color] if args.key?(:color) @dash_style = args[:dash_style] if args.key?(:dash_style) @padding = args[:padding] if args.key?(:padding) @width = args[:width] if args.key?(:width) end |