Class: Google::Apis::DocsV1::ParagraphStyle

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Styles that apply to a whole paragraph. Inherited paragraph styles are represented as unset fields in this message. A paragraph style's parent depends on where the paragraph style is defined: * The ParagraphStyle on a Paragraph inherits from the paragraph's corresponding named style type. * The ParagraphStyle on a named style inherits from the normal text named style. * The ParagraphStyle of the normal text named style inherits from the default paragraph style in the Docs editor. * The ParagraphStyle on a Paragraph element that's contained in a table may inherit its paragraph style from the table style. If the paragraph style does not inherit from a parent, unsetting fields will revert the style to a value matching the defaults in the Docs editor.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ParagraphStyle

Returns a new instance of ParagraphStyle.



4028
4029
4030
# File 'lib/google/apis/docs_v1/classes.rb', line 4028

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alignmentString

The text alignment for this paragraph. Corresponds to the JSON property alignment

Returns:

  • (String)


3903
3904
3905
# File 'lib/google/apis/docs_v1/classes.rb', line 3903

def alignment
  @alignment
end

#avoid_widow_and_orphanBoolean Also known as: avoid_widow_and_orphan?

Whether to avoid widows and orphans for the paragraph. If unset, the value is inherited from the parent. Corresponds to the JSON property avoidWidowAndOrphan

Returns:

  • (Boolean)


3909
3910
3911
# File 'lib/google/apis/docs_v1/classes.rb', line 3909

def avoid_widow_and_orphan
  @avoid_widow_and_orphan
end

#border_betweenGoogle::Apis::DocsV1::ParagraphBorder

A border around a paragraph. Corresponds to the JSON property borderBetween



3915
3916
3917
# File 'lib/google/apis/docs_v1/classes.rb', line 3915

def border_between
  @border_between
end

#border_bottomGoogle::Apis::DocsV1::ParagraphBorder

A border around a paragraph. Corresponds to the JSON property borderBottom



3920
3921
3922
# File 'lib/google/apis/docs_v1/classes.rb', line 3920

def border_bottom
  @border_bottom
end

#border_leftGoogle::Apis::DocsV1::ParagraphBorder

A border around a paragraph. Corresponds to the JSON property borderLeft



3925
3926
3927
# File 'lib/google/apis/docs_v1/classes.rb', line 3925

def border_left
  @border_left
end

#border_rightGoogle::Apis::DocsV1::ParagraphBorder

A border around a paragraph. Corresponds to the JSON property borderRight



3930
3931
3932
# File 'lib/google/apis/docs_v1/classes.rb', line 3930

def border_right
  @border_right
end

#border_topGoogle::Apis::DocsV1::ParagraphBorder

A border around a paragraph. Corresponds to the JSON property borderTop



3935
3936
3937
# File 'lib/google/apis/docs_v1/classes.rb', line 3935

def border_top
  @border_top
end

#directionString

The text direction of this paragraph. If unset, the value defaults to LEFT_TO_RIGHT since paragraph direction is not inherited. Corresponds to the JSON property direction

Returns:

  • (String)


3941
3942
3943
# File 'lib/google/apis/docs_v1/classes.rb', line 3941

def direction
  @direction
end

#heading_idString

The heading ID of the paragraph. If empty, then this paragraph is not a heading. This property is read-only. Corresponds to the JSON property headingId

Returns:

  • (String)


3947
3948
3949
# File 'lib/google/apis/docs_v1/classes.rb', line 3947

def heading_id
  @heading_id
end

#indent_endGoogle::Apis::DocsV1::Dimension

A magnitude in a single direction in the specified units. Corresponds to the JSON property indentEnd



3952
3953
3954
# File 'lib/google/apis/docs_v1/classes.rb', line 3952

def indent_end
  @indent_end
end

#indent_first_lineGoogle::Apis::DocsV1::Dimension

A magnitude in a single direction in the specified units. Corresponds to the JSON property indentFirstLine



3957
3958
3959
# File 'lib/google/apis/docs_v1/classes.rb', line 3957

def indent_first_line
  @indent_first_line
end

#indent_startGoogle::Apis::DocsV1::Dimension

A magnitude in a single direction in the specified units. Corresponds to the JSON property indentStart



3962
3963
3964
# File 'lib/google/apis/docs_v1/classes.rb', line 3962

def indent_start
  @indent_start
end

#keep_lines_togetherBoolean Also known as: keep_lines_together?

Whether all lines of the paragraph should be laid out on the same page or column if possible. If unset, the value is inherited from the parent. Corresponds to the JSON property keepLinesTogether

Returns:

  • (Boolean)


3968
3969
3970
# File 'lib/google/apis/docs_v1/classes.rb', line 3968

def keep_lines_together
  @keep_lines_together
end

#keep_with_nextBoolean Also known as: keep_with_next?

Whether at least a part of this paragraph should be laid out on the same page or column as the next paragraph if possible. If unset, the value is inherited from the parent. Corresponds to the JSON property keepWithNext

Returns:

  • (Boolean)


3976
3977
3978
# File 'lib/google/apis/docs_v1/classes.rb', line 3976

def keep_with_next
  @keep_with_next
end

#line_spacingFloat

The amount of space between lines, as a percentage of normal, where normal is represented as 100.0. If unset, the value is inherited from the parent. Corresponds to the JSON property lineSpacing

Returns:

  • (Float)


3983
3984
3985
# File 'lib/google/apis/docs_v1/classes.rb', line 3983

def line_spacing
  @line_spacing
end

#named_style_typeString

The named style type of the paragraph. Since updating the named style type affects other properties within ParagraphStyle, the named style type is applied before the other properties are updated. Corresponds to the JSON property namedStyleType

Returns:

  • (String)


3990
3991
3992
# File 'lib/google/apis/docs_v1/classes.rb', line 3990

def named_style_type
  @named_style_type
end

#page_break_beforeBoolean Also known as: page_break_before?

Whether the current paragraph should always start at the beginning of a page. If unset, the value is inherited from the parent. Attempting to update page_break_before for paragraphs in unsupported regions, including Table, Header, Footer and Footnote, can result in an invalid document state that returns a 400 bad request error. Corresponds to the JSON property pageBreakBefore

Returns:

  • (Boolean)


3999
4000
4001
# File 'lib/google/apis/docs_v1/classes.rb', line 3999

def page_break_before
  @page_break_before
end

#shadingGoogle::Apis::DocsV1::Shading

The shading of a paragraph. Corresponds to the JSON property shading



4005
4006
4007
# File 'lib/google/apis/docs_v1/classes.rb', line 4005

def shading
  @shading
end

#space_aboveGoogle::Apis::DocsV1::Dimension

A magnitude in a single direction in the specified units. Corresponds to the JSON property spaceAbove



4010
4011
4012
# File 'lib/google/apis/docs_v1/classes.rb', line 4010

def space_above
  @space_above
end

#space_belowGoogle::Apis::DocsV1::Dimension

A magnitude in a single direction in the specified units. Corresponds to the JSON property spaceBelow



4015
4016
4017
# File 'lib/google/apis/docs_v1/classes.rb', line 4015

def space_below
  @space_below
end

#spacing_modeString

The spacing mode for the paragraph. Corresponds to the JSON property spacingMode

Returns:

  • (String)


4020
4021
4022
# File 'lib/google/apis/docs_v1/classes.rb', line 4020

def spacing_mode
  @spacing_mode
end

#tab_stopsArray<Google::Apis::DocsV1::TabStop>

A list of the tab stops for this paragraph. The list of tab stops is not inherited. This property is read-only. Corresponds to the JSON property tabStops

Returns:



4026
4027
4028
# File 'lib/google/apis/docs_v1/classes.rb', line 4026

def tab_stops
  @tab_stops
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4033
4034
4035
4036
4037
4038
4039
4040
4041
4042
4043
4044
4045
4046
4047
4048
4049
4050
4051
4052
4053
4054
4055
4056
# File 'lib/google/apis/docs_v1/classes.rb', line 4033

def update!(**args)
  @alignment = args[:alignment] if args.key?(:alignment)
  @avoid_widow_and_orphan = args[:avoid_widow_and_orphan] if args.key?(:avoid_widow_and_orphan)
  @border_between = args[:border_between] if args.key?(:border_between)
  @border_bottom = args[:border_bottom] if args.key?(:border_bottom)
  @border_left = args[:border_left] if args.key?(:border_left)
  @border_right = args[:border_right] if args.key?(:border_right)
  @border_top = args[:border_top] if args.key?(:border_top)
  @direction = args[:direction] if args.key?(:direction)
  @heading_id = args[:heading_id] if args.key?(:heading_id)
  @indent_end = args[:indent_end] if args.key?(:indent_end)
  @indent_first_line = args[:indent_first_line] if args.key?(:indent_first_line)
  @indent_start = args[:indent_start] if args.key?(:indent_start)
  @keep_lines_together = args[:keep_lines_together] if args.key?(:keep_lines_together)
  @keep_with_next = args[:keep_with_next] if args.key?(:keep_with_next)
  @line_spacing = args[:line_spacing] if args.key?(:line_spacing)
  @named_style_type = args[:named_style_type] if args.key?(:named_style_type)
  @page_break_before = args[:page_break_before] if args.key?(:page_break_before)
  @shading = args[:shading] if args.key?(:shading)
  @space_above = args[:space_above] if args.key?(:space_above)
  @space_below = args[:space_below] if args.key?(:space_below)
  @spacing_mode = args[:spacing_mode] if args.key?(:spacing_mode)
  @tab_stops = args[:tab_stops] if args.key?(:tab_stops)
end