Class: Google::Apis::DocsV1::ParagraphStyleSuggestionState
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::ParagraphStyleSuggestionState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
A mask that indicates which of the fields on the base ParagraphStyle have been changed in this suggestion. For any field set to true, there's a new suggested value.
Instance Attribute Summary collapse
-
#alignment_suggested ⇒ Boolean
(also: #alignment_suggested?)
Indicates if there was a suggested change to alignment.
-
#avoid_widow_and_orphan_suggested ⇒ Boolean
(also: #avoid_widow_and_orphan_suggested?)
Indicates if there was a suggested change to avoid_widow_and_orphan.
-
#border_between_suggested ⇒ Boolean
(also: #border_between_suggested?)
Indicates if there was a suggested change to border_between.
-
#border_bottom_suggested ⇒ Boolean
(also: #border_bottom_suggested?)
Indicates if there was a suggested change to border_bottom.
-
#border_left_suggested ⇒ Boolean
(also: #border_left_suggested?)
Indicates if there was a suggested change to border_left.
-
#border_right_suggested ⇒ Boolean
(also: #border_right_suggested?)
Indicates if there was a suggested change to border_right.
-
#border_top_suggested ⇒ Boolean
(also: #border_top_suggested?)
Indicates if there was a suggested change to border_top.
-
#direction_suggested ⇒ Boolean
(also: #direction_suggested?)
Indicates if there was a suggested change to direction.
-
#heading_id_suggested ⇒ Boolean
(also: #heading_id_suggested?)
Indicates if there was a suggested change to heading_id.
-
#indent_end_suggested ⇒ Boolean
(also: #indent_end_suggested?)
Indicates if there was a suggested change to indent_end.
-
#indent_first_line_suggested ⇒ Boolean
(also: #indent_first_line_suggested?)
Indicates if there was a suggested change to indent_first_line.
-
#indent_start_suggested ⇒ Boolean
(also: #indent_start_suggested?)
Indicates if there was a suggested change to indent_start.
-
#keep_lines_together_suggested ⇒ Boolean
(also: #keep_lines_together_suggested?)
Indicates if there was a suggested change to keep_lines_together.
-
#keep_with_next_suggested ⇒ Boolean
(also: #keep_with_next_suggested?)
Indicates if there was a suggested change to keep_with_next.
-
#line_spacing_suggested ⇒ Boolean
(also: #line_spacing_suggested?)
Indicates if there was a suggested change to line_spacing.
-
#named_style_type_suggested ⇒ Boolean
(also: #named_style_type_suggested?)
Indicates if there was a suggested change to named_style_type.
-
#page_break_before_suggested ⇒ Boolean
(also: #page_break_before_suggested?)
Indicates if there was a suggested change to page_break_before.
-
#shading_suggestion_state ⇒ Google::Apis::DocsV1::ShadingSuggestionState
A mask that indicates which of the fields on the base Shading have been changed in this suggested change.
-
#space_above_suggested ⇒ Boolean
(also: #space_above_suggested?)
Indicates if there was a suggested change to space_above.
-
#space_below_suggested ⇒ Boolean
(also: #space_below_suggested?)
Indicates if there was a suggested change to space_below.
-
#spacing_mode_suggested ⇒ Boolean
(also: #spacing_mode_suggested?)
Indicates if there was a suggested change to spacing_mode.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ParagraphStyleSuggestionState
constructor
A new instance of ParagraphStyleSuggestionState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ParagraphStyleSuggestionState
Returns a new instance of ParagraphStyleSuggestionState.
4192 4193 4194 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4192 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alignment_suggested ⇒ Boolean Also known as: alignment_suggested?
Indicates if there was a suggested change to alignment.
Corresponds to the JSON property alignmentSuggested
4068 4069 4070 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4068 def alignment_suggested @alignment_suggested end |
#avoid_widow_and_orphan_suggested ⇒ Boolean Also known as: avoid_widow_and_orphan_suggested?
Indicates if there was a suggested change to avoid_widow_and_orphan.
Corresponds to the JSON property avoidWidowAndOrphanSuggested
4074 4075 4076 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4074 def avoid_widow_and_orphan_suggested @avoid_widow_and_orphan_suggested end |
#border_between_suggested ⇒ Boolean Also known as: border_between_suggested?
Indicates if there was a suggested change to border_between.
Corresponds to the JSON property borderBetweenSuggested
4080 4081 4082 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4080 def border_between_suggested @border_between_suggested end |
#border_bottom_suggested ⇒ Boolean Also known as: border_bottom_suggested?
Indicates if there was a suggested change to border_bottom.
Corresponds to the JSON property borderBottomSuggested
4086 4087 4088 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4086 def border_bottom_suggested @border_bottom_suggested end |
#border_left_suggested ⇒ Boolean Also known as: border_left_suggested?
Indicates if there was a suggested change to border_left.
Corresponds to the JSON property borderLeftSuggested
4092 4093 4094 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4092 def border_left_suggested @border_left_suggested end |
#border_right_suggested ⇒ Boolean Also known as: border_right_suggested?
Indicates if there was a suggested change to border_right.
Corresponds to the JSON property borderRightSuggested
4098 4099 4100 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4098 def border_right_suggested @border_right_suggested end |
#border_top_suggested ⇒ Boolean Also known as: border_top_suggested?
Indicates if there was a suggested change to border_top.
Corresponds to the JSON property borderTopSuggested
4104 4105 4106 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4104 def border_top_suggested @border_top_suggested end |
#direction_suggested ⇒ Boolean Also known as: direction_suggested?
Indicates if there was a suggested change to direction.
Corresponds to the JSON property directionSuggested
4110 4111 4112 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4110 def direction_suggested @direction_suggested end |
#heading_id_suggested ⇒ Boolean Also known as: heading_id_suggested?
Indicates if there was a suggested change to heading_id.
Corresponds to the JSON property headingIdSuggested
4116 4117 4118 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4116 def heading_id_suggested @heading_id_suggested end |
#indent_end_suggested ⇒ Boolean Also known as: indent_end_suggested?
Indicates if there was a suggested change to indent_end.
Corresponds to the JSON property indentEndSuggested
4122 4123 4124 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4122 def indent_end_suggested @indent_end_suggested end |
#indent_first_line_suggested ⇒ Boolean Also known as: indent_first_line_suggested?
Indicates if there was a suggested change to indent_first_line.
Corresponds to the JSON property indentFirstLineSuggested
4128 4129 4130 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4128 def indent_first_line_suggested @indent_first_line_suggested end |
#indent_start_suggested ⇒ Boolean Also known as: indent_start_suggested?
Indicates if there was a suggested change to indent_start.
Corresponds to the JSON property indentStartSuggested
4134 4135 4136 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4134 def indent_start_suggested @indent_start_suggested end |
#keep_lines_together_suggested ⇒ Boolean Also known as: keep_lines_together_suggested?
Indicates if there was a suggested change to keep_lines_together.
Corresponds to the JSON property keepLinesTogetherSuggested
4140 4141 4142 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4140 def keep_lines_together_suggested @keep_lines_together_suggested end |
#keep_with_next_suggested ⇒ Boolean Also known as: keep_with_next_suggested?
Indicates if there was a suggested change to keep_with_next.
Corresponds to the JSON property keepWithNextSuggested
4146 4147 4148 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4146 def keep_with_next_suggested @keep_with_next_suggested end |
#line_spacing_suggested ⇒ Boolean Also known as: line_spacing_suggested?
Indicates if there was a suggested change to line_spacing.
Corresponds to the JSON property lineSpacingSuggested
4152 4153 4154 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4152 def line_spacing_suggested @line_spacing_suggested end |
#named_style_type_suggested ⇒ Boolean Also known as: named_style_type_suggested?
Indicates if there was a suggested change to named_style_type.
Corresponds to the JSON property namedStyleTypeSuggested
4158 4159 4160 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4158 def named_style_type_suggested @named_style_type_suggested end |
#page_break_before_suggested ⇒ Boolean Also known as: page_break_before_suggested?
Indicates if there was a suggested change to page_break_before.
Corresponds to the JSON property pageBreakBeforeSuggested
4164 4165 4166 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4164 def page_break_before_suggested @page_break_before_suggested end |
#shading_suggestion_state ⇒ Google::Apis::DocsV1::ShadingSuggestionState
A mask that indicates which of the fields on the base Shading have been
changed in this suggested change. For any field set to true, there's a new
suggested value.
Corresponds to the JSON property shadingSuggestionState
4172 4173 4174 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4172 def shading_suggestion_state @shading_suggestion_state end |
#space_above_suggested ⇒ Boolean Also known as: space_above_suggested?
Indicates if there was a suggested change to space_above.
Corresponds to the JSON property spaceAboveSuggested
4177 4178 4179 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4177 def space_above_suggested @space_above_suggested end |
#space_below_suggested ⇒ Boolean Also known as: space_below_suggested?
Indicates if there was a suggested change to space_below.
Corresponds to the JSON property spaceBelowSuggested
4183 4184 4185 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4183 def space_below_suggested @space_below_suggested end |
#spacing_mode_suggested ⇒ Boolean Also known as: spacing_mode_suggested?
Indicates if there was a suggested change to spacing_mode.
Corresponds to the JSON property spacingModeSuggested
4189 4190 4191 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4189 def spacing_mode_suggested @spacing_mode_suggested end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4197 def update!(**args) @alignment_suggested = args[:alignment_suggested] if args.key?(:alignment_suggested) @avoid_widow_and_orphan_suggested = args[:avoid_widow_and_orphan_suggested] if args.key?(:avoid_widow_and_orphan_suggested) @border_between_suggested = args[:border_between_suggested] if args.key?(:border_between_suggested) @border_bottom_suggested = args[:border_bottom_suggested] if args.key?(:border_bottom_suggested) @border_left_suggested = args[:border_left_suggested] if args.key?(:border_left_suggested) @border_right_suggested = args[:border_right_suggested] if args.key?(:border_right_suggested) @border_top_suggested = args[:border_top_suggested] if args.key?(:border_top_suggested) @direction_suggested = args[:direction_suggested] if args.key?(:direction_suggested) @heading_id_suggested = args[:heading_id_suggested] if args.key?(:heading_id_suggested) @indent_end_suggested = args[:indent_end_suggested] if args.key?(:indent_end_suggested) @indent_first_line_suggested = args[:indent_first_line_suggested] if args.key?(:indent_first_line_suggested) @indent_start_suggested = args[:indent_start_suggested] if args.key?(:indent_start_suggested) @keep_lines_together_suggested = args[:keep_lines_together_suggested] if args.key?(:keep_lines_together_suggested) @keep_with_next_suggested = args[:keep_with_next_suggested] if args.key?(:keep_with_next_suggested) @line_spacing_suggested = args[:line_spacing_suggested] if args.key?(:line_spacing_suggested) @named_style_type_suggested = args[:named_style_type_suggested] if args.key?(:named_style_type_suggested) @page_break_before_suggested = args[:page_break_before_suggested] if args.key?(:page_break_before_suggested) @shading_suggestion_state = args[:shading_suggestion_state] if args.key?(:shading_suggestion_state) @space_above_suggested = args[:space_above_suggested] if args.key?(:space_above_suggested) @space_below_suggested = args[:space_below_suggested] if args.key?(:space_below_suggested) @spacing_mode_suggested = args[:spacing_mode_suggested] if args.key?(:spacing_mode_suggested) end |