Class: Google::Apis::DocsV1::Person
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::Person
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
A person or email address mentioned in a document. These mentions behave as a single, immutable element containing the person's name or email address.
Instance Attribute Summary collapse
-
#person_id ⇒ String
Output only.
-
#person_properties ⇒ Google::Apis::DocsV1::PersonProperties
Properties specific to a linked Person.
-
#suggested_deletion_ids ⇒ Array<String>
IDs for suggestions that remove this person link from the document.
-
#suggested_insertion_ids ⇒ Array<String>
IDs for suggestions that insert this person link into the document.
-
#suggested_text_style_changes ⇒ Hash<String,Google::Apis::DocsV1::SuggestedTextStyle>
The suggested text style changes to this Person, keyed by suggestion ID.
-
#text_style ⇒ Google::Apis::DocsV1::TextStyle
Represents the styling that can be applied to text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Person
constructor
A new instance of Person.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Person
Returns a new instance of Person.
4233 4234 4235 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4233 def initialize(**args) update!(**args) end |
Instance Attribute Details
#person_id ⇒ String
Output only. The unique ID of this link.
Corresponds to the JSON property personId
4192 4193 4194 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4192 def person_id @person_id end |
#person_properties ⇒ Google::Apis::DocsV1::PersonProperties
Properties specific to a linked Person.
Corresponds to the JSON property personProperties
4197 4198 4199 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4197 def person_properties @person_properties end |
#suggested_deletion_ids ⇒ Array<String>
IDs for suggestions that remove this person link from the document. A Person
might have multiple deletion IDs if, for example, multiple users suggest
deleting it. If empty, then this person link isn't suggested for deletion.
Corresponds to the JSON property suggestedDeletionIds
4204 4205 4206 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4204 def suggested_deletion_ids @suggested_deletion_ids end |
#suggested_insertion_ids ⇒ Array<String>
IDs for suggestions that insert this person link into the document. A Person
might have multiple insertion IDs if it's a nested suggested change (a
suggestion within a suggestion made by a different user, for example). If
empty, then this person link isn't a suggested insertion.
Corresponds to the JSON property suggestedInsertionIds
4212 4213 4214 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4212 def suggested_insertion_ids @suggested_insertion_ids end |
#suggested_text_style_changes ⇒ Hash<String,Google::Apis::DocsV1::SuggestedTextStyle>
The suggested text style changes to this Person, keyed by suggestion ID.
Corresponds to the JSON property suggestedTextStyleChanges
4217 4218 4219 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4217 def suggested_text_style_changes @suggested_text_style_changes end |
#text_style ⇒ Google::Apis::DocsV1::TextStyle
Represents the styling that can be applied to text. Inherited text styles are
represented as unset fields in this message. A text style's parent depends on
where the text style is defined: * The TextStyle of text in a Paragraph
inherits from the paragraph's corresponding named style type. * The TextStyle
on a named style inherits from the normal text named style. * The TextStyle of
the normal text named style inherits from the default text style in the Docs
editor. * The TextStyle on a Paragraph element that's contained in a table may
inherit its text style from the table style. If the text style does not
inherit from a parent, unsetting fields will revert the style to a value
matching the defaults in the Docs editor.
Corresponds to the JSON property textStyle
4231 4232 4233 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4231 def text_style @text_style end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4238 4239 4240 4241 4242 4243 4244 4245 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4238 def update!(**args) @person_id = args[:person_id] if args.key?(:person_id) @person_properties = args[:person_properties] if args.key?(:person_properties) @suggested_deletion_ids = args[:suggested_deletion_ids] if args.key?(:suggested_deletion_ids) @suggested_insertion_ids = args[:suggested_insertion_ids] if args.key?(:suggested_insertion_ids) @suggested_text_style_changes = args[:suggested_text_style_changes] if args.key?(:suggested_text_style_changes) @text_style = args[:text_style] if args.key?(:text_style) end |