Class: Google::Apis::DocsV1::PersonProperties
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::PersonProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
Properties specific to a linked Person.
Instance Attribute Summary collapse
-
#email ⇒ String
The email address linked to this Person.
-
#name ⇒ String
The name of the person if it's displayed in the link text instead of the person's email address.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PersonProperties
constructor
A new instance of PersonProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PersonProperties
Returns a new instance of PersonProperties.
4301 4302 4303 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4301 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email ⇒ String
The email address linked to this Person. This field is always present.
Corresponds to the JSON property email
4293 4294 4295 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4293 def email @email end |
#name ⇒ String
The name of the person if it's displayed in the link text instead of the
person's email address.
Corresponds to the JSON property name
4299 4300 4301 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4299 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4306 4307 4308 4309 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4306 def update!(**args) @email = args[:email] if args.key?(:email) @name = args[:name] if args.key?(:name) end |