Class: Google::Apis::DocsV1::Range
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::Range
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
Specifies a contiguous range of text.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
The zero-based end index of this range, exclusive, in UTF-16 code units.
-
#segment_id ⇒ String
The ID of the header, footer, or footnote that this range is contained in.
-
#start_index ⇒ Fixnum
The zero-based start index of this range, in UTF-16 code units.
-
#tab_id ⇒ String
The tab that contains this range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Range
constructor
A new instance of Range.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Range
Returns a new instance of Range.
4543 4544 4545 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4543 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
The zero-based end index of this range, exclusive, in UTF-16 code units. In
all current uses, an end index must be provided. This field is an Int32Value
in order to accommodate future use cases with open-ended ranges.
Corresponds to the JSON property endIndex
4518 4519 4520 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4518 def end_index @end_index end |
#segment_id ⇒ String
The ID of the header, footer, or footnote that this range is contained in. An
empty segment ID signifies the document's body.
Corresponds to the JSON property segmentId
4524 4525 4526 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4524 def segment_id @segment_id end |
#start_index ⇒ Fixnum
The zero-based start index of this range, in UTF-16 code units. In all current
uses, a start index must be provided. This field is an Int32Value in order to
accommodate future use cases with open-ended ranges.
Corresponds to the JSON property startIndex
4531 4532 4533 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4531 def start_index @start_index end |
#tab_id ⇒ String
The tab that contains this range. When omitted, the request applies to the
first tab. In a document containing a single tab: - If provided, must match
the singular tab's ID. - If omitted, the request applies to the singular tab.
In a document containing multiple tabs: - If provided, the request applies to
the specified tab. - If omitted, the request applies to the first tab in the
document.
Corresponds to the JSON property tabId
4541 4542 4543 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4541 def tab_id @tab_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4548 4549 4550 4551 4552 4553 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4548 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @segment_id = args[:segment_id] if args.key?(:segment_id) @start_index = args[:start_index] if args.key?(:start_index) @tab_id = args[:tab_id] if args.key?(:tab_id) end |