Class: Google::Apis::DocsV1::ReplaceNamedRangeContentRequest
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::ReplaceNamedRangeContentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
Replaces the contents of the specified NamedRange or NamedRanges with the given replacement content. Note that an individual NamedRange may consist of multiple discontinuous ranges. In this case, only the content in the first range will be replaced. The other ranges and their content will be deleted. In cases where replacing or deleting any ranges would result in an invalid document structure, a 400 bad request error is returned.
Instance Attribute Summary collapse
-
#named_range_id ⇒ String
The ID of the named range whose content will be replaced.
-
#named_range_name ⇒ String
The name of the NamedRanges whose content will be replaced.
-
#tabs_criteria ⇒ Google::Apis::DocsV1::TabsCriteria
A criteria that specifies in which tabs a request executes.
-
#text ⇒ String
Replaces the content of the specified named range(s) with the given text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReplaceNamedRangeContentRequest
constructor
A new instance of ReplaceNamedRangeContentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReplaceNamedRangeContentRequest
Returns a new instance of ReplaceNamedRangeContentRequest.
4688 4689 4690 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4688 def initialize(**args) update!(**args) end |
Instance Attribute Details
#named_range_id ⇒ String
The ID of the named range whose content will be replaced. If there is no named
range with the given ID a 400 bad request error is returned.
Corresponds to the JSON property namedRangeId
4668 4669 4670 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4668 def named_range_id @named_range_id end |
#named_range_name ⇒ String
The name of the NamedRanges whose content will be replaced. If there are
multiple named ranges with the given name, then the content of each one will
be replaced. If there are no named ranges with the given name, then the
request will be a no-op.
Corresponds to the JSON property namedRangeName
4676 4677 4678 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4676 def named_range_name @named_range_name end |
#tabs_criteria ⇒ Google::Apis::DocsV1::TabsCriteria
A criteria that specifies in which tabs a request executes.
Corresponds to the JSON property tabsCriteria
4681 4682 4683 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4681 def tabs_criteria @tabs_criteria end |
#text ⇒ String
Replaces the content of the specified named range(s) with the given text.
Corresponds to the JSON property text
4686 4687 4688 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4686 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4693 4694 4695 4696 4697 4698 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4693 def update!(**args) @named_range_id = args[:named_range_id] if args.key?(:named_range_id) @named_range_name = args[:named_range_name] if args.key?(:named_range_name) @tabs_criteria = args[:tabs_criteria] if args.key?(:tabs_criteria) @text = args[:text] if args.key?(:text) end |