Class: Google::Apis::DocsV1::ReplaceNamedRangeContentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Replaces the contents of the specified NamedRange or NamedRanges with the given replacement content. Note that an individual NamedRange may consist of multiple discontinuous ranges. In this case, only the content in the first range will be replaced. The other ranges and their content will be deleted. In cases where replacing or deleting any ranges would result in an invalid document structure, a 400 bad request error is returned.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReplaceNamedRangeContentRequest

Returns a new instance of ReplaceNamedRangeContentRequest.



4650
4651
4652
# File 'lib/google/apis/docs_v1/classes.rb', line 4650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#named_range_idString

The ID of the named range whose content will be replaced. If there is no named range with the given ID a 400 bad request error is returned. Corresponds to the JSON property namedRangeId

Returns:



4630
4631
4632
# File 'lib/google/apis/docs_v1/classes.rb', line 4630

def named_range_id
  @named_range_id
end

#named_range_nameString

The name of the NamedRanges whose content will be replaced. If there are multiple named ranges with the given name, then the content of each one will be replaced. If there are no named ranges with the given name, then the request will be a no-op. Corresponds to the JSON property namedRangeName

Returns:



4638
4639
4640
# File 'lib/google/apis/docs_v1/classes.rb', line 4638

def named_range_name
  @named_range_name
end

#tabs_criteriaGoogle::Apis::DocsV1::TabsCriteria

A criteria that specifies in which tabs a request executes. Corresponds to the JSON property tabsCriteria

Returns:



4643
4644
4645
# File 'lib/google/apis/docs_v1/classes.rb', line 4643

def tabs_criteria
  @tabs_criteria
end

#textString

Replaces the content of the specified named range(s) with the given text. Corresponds to the JSON property text

Returns:



4648
4649
4650
# File 'lib/google/apis/docs_v1/classes.rb', line 4648

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4655
4656
4657
4658
4659
4660
# File 'lib/google/apis/docs_v1/classes.rb', line 4655

def update!(**args)
  @named_range_id = args[:named_range_id] if args.key?(:named_range_id)
  @named_range_name = args[:named_range_name] if args.key?(:named_range_name)
  @tabs_criteria = args[:tabs_criteria] if args.key?(:tabs_criteria)
  @text = args[:text] if args.key?(:text)
end