Class: Google::Apis::DocsV1::Request
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::Request
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
A single update to apply to a document.
Instance Attribute Summary collapse
-
#add_document_tab ⇒ Google::Apis::DocsV1::AddDocumentTabRequest
Adds a document tab.
-
#create_footer ⇒ Google::Apis::DocsV1::CreateFooterRequest
Creates a Footer.
-
#create_footnote ⇒ Google::Apis::DocsV1::CreateFootnoteRequest
Creates a Footnote segment and inserts a new FootnoteReference to it at the given location.
-
#create_header ⇒ Google::Apis::DocsV1::CreateHeaderRequest
Creates a Header.
-
#create_named_range ⇒ Google::Apis::DocsV1::CreateNamedRangeRequest
Creates a NamedRange referencing the given range.
-
#create_paragraph_bullets ⇒ Google::Apis::DocsV1::CreateParagraphBulletsRequest
Creates bullets for all of the paragraphs that overlap with the given range.
-
#delete_content_range ⇒ Google::Apis::DocsV1::DeleteContentRangeRequest
Deletes content from the document.
-
#delete_footer ⇒ Google::Apis::DocsV1::DeleteFooterRequest
Deletes a Footer from the document.
-
#delete_header ⇒ Google::Apis::DocsV1::DeleteHeaderRequest
Deletes a Header from the document.
-
#delete_named_range ⇒ Google::Apis::DocsV1::DeleteNamedRangeRequest
Deletes a NamedRange.
-
#delete_paragraph_bullets ⇒ Google::Apis::DocsV1::DeleteParagraphBulletsRequest
Deletes bullets from all of the paragraphs that overlap with the given range.
-
#delete_positioned_object ⇒ Google::Apis::DocsV1::DeletePositionedObjectRequest
Deletes a PositionedObject from the document.
-
#delete_tab ⇒ Google::Apis::DocsV1::DeleteTabRequest
Deletes a tab.
-
#delete_table_column ⇒ Google::Apis::DocsV1::DeleteTableColumnRequest
Deletes a column from a table.
-
#delete_table_row ⇒ Google::Apis::DocsV1::DeleteTableRowRequest
Deletes a row from a table.
-
#insert_date ⇒ Google::Apis::DocsV1::InsertDateRequest
Inserts a date at the specified location.
-
#insert_inline_image ⇒ Google::Apis::DocsV1::InsertInlineImageRequest
Inserts an InlineObject containing an image at the given location.
-
#insert_page_break ⇒ Google::Apis::DocsV1::InsertPageBreakRequest
Inserts a page break followed by a newline at the specified location.
-
#insert_person ⇒ Google::Apis::DocsV1::InsertPersonRequest
Inserts a person mention.
-
#insert_rich_link ⇒ Google::Apis::DocsV1::InsertRichLinkRequest
Inserts a RichLink at the specified location.
-
#insert_section_break ⇒ Google::Apis::DocsV1::InsertSectionBreakRequest
Inserts a section break at the given location.
-
#insert_table ⇒ Google::Apis::DocsV1::InsertTableRequest
Inserts a table at the specified location.
-
#insert_table_column ⇒ Google::Apis::DocsV1::InsertTableColumnRequest
Inserts an empty column into a table.
-
#insert_table_row ⇒ Google::Apis::DocsV1::InsertTableRowRequest
Inserts an empty row into a table.
-
#insert_text ⇒ Google::Apis::DocsV1::InsertTextRequest
Inserts text at the specified location.
-
#merge_table_cells ⇒ Google::Apis::DocsV1::MergeTableCellsRequest
Merges cells in a Table.
-
#pin_table_header_rows ⇒ Google::Apis::DocsV1::PinTableHeaderRowsRequest
Updates the number of pinned table header rows in a table.
-
#replace_all_text ⇒ Google::Apis::DocsV1::ReplaceAllTextRequest
Replaces all instances of text matching a criteria with replace text.
-
#replace_image ⇒ Google::Apis::DocsV1::ReplaceImageRequest
Replaces an existing image with a new image.
-
#replace_named_range_content ⇒ Google::Apis::DocsV1::ReplaceNamedRangeContentRequest
Replaces the contents of the specified NamedRange or NamedRanges with the given replacement content.
-
#unmerge_table_cells ⇒ Google::Apis::DocsV1::UnmergeTableCellsRequest
Unmerges cells in a Table.
-
#update_document_style ⇒ Google::Apis::DocsV1::UpdateDocumentStyleRequest
Updates the DocumentStyle.
-
#update_document_tab_properties ⇒ Google::Apis::DocsV1::UpdateDocumentTabPropertiesRequest
Update the properties of a document tab.
-
#update_named_style ⇒ Google::Apis::DocsV1::UpdateNamedStyleRequest
Updates a named style.
-
#update_paragraph_style ⇒ Google::Apis::DocsV1::UpdateParagraphStyleRequest
Update the styling of all paragraphs that overlap with the given range.
-
#update_section_style ⇒ Google::Apis::DocsV1::UpdateSectionStyleRequest
Updates the SectionStyle.
-
#update_table_cell_style ⇒ Google::Apis::DocsV1::UpdateTableCellStyleRequest
Updates the style of a range of table cells.
-
#update_table_column_properties ⇒ Google::Apis::DocsV1::UpdateTableColumnPropertiesRequest
Updates the TableColumnProperties of columns in a table.
-
#update_table_row_style ⇒ Google::Apis::DocsV1::UpdateTableRowStyleRequest
Updates the TableRowStyle of rows in a table.
-
#update_text_style ⇒ Google::Apis::DocsV1::UpdateTextStyleRequest
Update the styling of text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Request
constructor
A new instance of Request.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Request
Returns a new instance of Request.
4931 4932 4933 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4931 def initialize(**args) update!(**args) end |
Instance Attribute Details
#add_document_tab ⇒ Google::Apis::DocsV1::AddDocumentTabRequest
Adds a document tab. When a tab is added at a given index, all subsequent tabs'
indexes are incremented.
Corresponds to the JSON property addDocumentTab
4709 4710 4711 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4709 def add_document_tab @add_document_tab end |
#create_footer ⇒ Google::Apis::DocsV1::CreateFooterRequest
Creates a Footer. The new footer is applied to the SectionStyle at the
location of the SectionBreak if specified, otherwise it is applied to the
DocumentStyle. If a footer of the specified type already exists, a 400 bad
request error is returned.
Corresponds to the JSON property createFooter
4717 4718 4719 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4717 def @create_footer end |
#create_footnote ⇒ Google::Apis::DocsV1::CreateFootnoteRequest
Creates a Footnote segment and inserts a new FootnoteReference to it at the
given location. The new Footnote segment will contain a space followed by a
newline character.
Corresponds to the JSON property createFootnote
4724 4725 4726 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4724 def create_footnote @create_footnote end |
#create_header ⇒ Google::Apis::DocsV1::CreateHeaderRequest
Creates a Header. The new header is applied to the SectionStyle at the
location of the SectionBreak if specified, otherwise it is applied to the
DocumentStyle. If a header of the specified type already exists, a 400 bad
request error is returned.
Corresponds to the JSON property createHeader
4732 4733 4734 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4732 def create_header @create_header end |
#create_named_range ⇒ Google::Apis::DocsV1::CreateNamedRangeRequest
Creates a NamedRange referencing the given range.
Corresponds to the JSON property createNamedRange
4737 4738 4739 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4737 def create_named_range @create_named_range end |
#create_paragraph_bullets ⇒ Google::Apis::DocsV1::CreateParagraphBulletsRequest
Creates bullets for all of the paragraphs that overlap with the given range.
The nesting level of each paragraph will be determined by counting leading
tabs in front of each paragraph. To avoid excess space between the bullet and
the corresponding paragraph, these leading tabs are removed by this request.
This may change the indices of parts of the text. If the paragraph immediately
before paragraphs being updated is in a list with a matching preset, the
paragraphs being updated are added to that preceding list.
Corresponds to the JSON property createParagraphBullets
4748 4749 4750 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4748 def create_paragraph_bullets @create_paragraph_bullets end |
#delete_content_range ⇒ Google::Apis::DocsV1::DeleteContentRangeRequest
Deletes content from the document.
Corresponds to the JSON property deleteContentRange
4753 4754 4755 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4753 def delete_content_range @delete_content_range end |
#delete_footer ⇒ Google::Apis::DocsV1::DeleteFooterRequest
Deletes a Footer from the document.
Corresponds to the JSON property deleteFooter
4758 4759 4760 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4758 def @delete_footer end |
#delete_header ⇒ Google::Apis::DocsV1::DeleteHeaderRequest
Deletes a Header from the document.
Corresponds to the JSON property deleteHeader
4763 4764 4765 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4763 def delete_header @delete_header end |
#delete_named_range ⇒ Google::Apis::DocsV1::DeleteNamedRangeRequest
Deletes a NamedRange.
Corresponds to the JSON property deleteNamedRange
4768 4769 4770 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4768 def delete_named_range @delete_named_range end |
#delete_paragraph_bullets ⇒ Google::Apis::DocsV1::DeleteParagraphBulletsRequest
Deletes bullets from all of the paragraphs that overlap with the given range.
The nesting level of each paragraph will be visually preserved by adding
indent to the start of the corresponding paragraph.
Corresponds to the JSON property deleteParagraphBullets
4775 4776 4777 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4775 def delete_paragraph_bullets @delete_paragraph_bullets end |
#delete_positioned_object ⇒ Google::Apis::DocsV1::DeletePositionedObjectRequest
Deletes a PositionedObject from the document.
Corresponds to the JSON property deletePositionedObject
4780 4781 4782 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4780 def delete_positioned_object @delete_positioned_object end |
#delete_tab ⇒ Google::Apis::DocsV1::DeleteTabRequest
Deletes a tab. If the tab has child tabs, they are deleted as well.
Corresponds to the JSON property deleteTab
4785 4786 4787 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4785 def delete_tab @delete_tab end |
#delete_table_column ⇒ Google::Apis::DocsV1::DeleteTableColumnRequest
Deletes a column from a table.
Corresponds to the JSON property deleteTableColumn
4790 4791 4792 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4790 def delete_table_column @delete_table_column end |
#delete_table_row ⇒ Google::Apis::DocsV1::DeleteTableRowRequest
Deletes a row from a table.
Corresponds to the JSON property deleteTableRow
4795 4796 4797 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4795 def delete_table_row @delete_table_row end |
#insert_date ⇒ Google::Apis::DocsV1::InsertDateRequest
Inserts a date at the specified location.
Corresponds to the JSON property insertDate
4800 4801 4802 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4800 def insert_date @insert_date end |
#insert_inline_image ⇒ Google::Apis::DocsV1::InsertInlineImageRequest
Inserts an InlineObject containing an image at the given location.
Corresponds to the JSON property insertInlineImage
4805 4806 4807 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4805 def insert_inline_image @insert_inline_image end |
#insert_page_break ⇒ Google::Apis::DocsV1::InsertPageBreakRequest
Inserts a page break followed by a newline at the specified location.
Corresponds to the JSON property insertPageBreak
4810 4811 4812 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4810 def insert_page_break @insert_page_break end |
#insert_person ⇒ Google::Apis::DocsV1::InsertPersonRequest
Inserts a person mention.
Corresponds to the JSON property insertPerson
4815 4816 4817 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4815 def insert_person @insert_person end |
#insert_rich_link ⇒ Google::Apis::DocsV1::InsertRichLinkRequest
Inserts a RichLink at the specified location.
Corresponds to the JSON property insertRichLink
4820 4821 4822 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4820 def insert_rich_link @insert_rich_link end |
#insert_section_break ⇒ Google::Apis::DocsV1::InsertSectionBreakRequest
Inserts a section break at the given location. A newline character will be
inserted before the section break.
Corresponds to the JSON property insertSectionBreak
4826 4827 4828 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4826 def insert_section_break @insert_section_break end |
#insert_table ⇒ Google::Apis::DocsV1::InsertTableRequest
Inserts a table at the specified location. A newline character will be
inserted before the inserted table.
Corresponds to the JSON property insertTable
4832 4833 4834 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4832 def insert_table @insert_table end |
#insert_table_column ⇒ Google::Apis::DocsV1::InsertTableColumnRequest
Inserts an empty column into a table.
Corresponds to the JSON property insertTableColumn
4837 4838 4839 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4837 def insert_table_column @insert_table_column end |
#insert_table_row ⇒ Google::Apis::DocsV1::InsertTableRowRequest
Inserts an empty row into a table.
Corresponds to the JSON property insertTableRow
4842 4843 4844 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4842 def insert_table_row @insert_table_row end |
#insert_text ⇒ Google::Apis::DocsV1::InsertTextRequest
Inserts text at the specified location.
Corresponds to the JSON property insertText
4847 4848 4849 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4847 def insert_text @insert_text end |
#merge_table_cells ⇒ Google::Apis::DocsV1::MergeTableCellsRequest
Merges cells in a Table.
Corresponds to the JSON property mergeTableCells
4852 4853 4854 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4852 def merge_table_cells @merge_table_cells end |
#pin_table_header_rows ⇒ Google::Apis::DocsV1::PinTableHeaderRowsRequest
Updates the number of pinned table header rows in a table.
Corresponds to the JSON property pinTableHeaderRows
4857 4858 4859 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4857 def pin_table_header_rows @pin_table_header_rows end |
#replace_all_text ⇒ Google::Apis::DocsV1::ReplaceAllTextRequest
Replaces all instances of text matching a criteria with replace text.
Corresponds to the JSON property replaceAllText
4862 4863 4864 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4862 def replace_all_text @replace_all_text end |
#replace_image ⇒ Google::Apis::DocsV1::ReplaceImageRequest
Replaces an existing image with a new image. Replacing an image removes some
image effects from the existing image in order to mirror the behavior of the
Docs editor.
Corresponds to the JSON property replaceImage
4869 4870 4871 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4869 def replace_image @replace_image end |
#replace_named_range_content ⇒ Google::Apis::DocsV1::ReplaceNamedRangeContentRequest
Replaces the contents of the specified NamedRange or NamedRanges with the
given replacement content. Note that an individual NamedRange may consist of
multiple discontinuous ranges. In this case, only the content in the first
range will be replaced. The other ranges and their content will be deleted. In
cases where replacing or deleting any ranges would result in an invalid
document structure, a 400 bad request error is returned.
Corresponds to the JSON property replaceNamedRangeContent
4879 4880 4881 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4879 def replace_named_range_content @replace_named_range_content end |
#unmerge_table_cells ⇒ Google::Apis::DocsV1::UnmergeTableCellsRequest
Unmerges cells in a Table.
Corresponds to the JSON property unmergeTableCells
4884 4885 4886 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4884 def unmerge_table_cells @unmerge_table_cells end |
#update_document_style ⇒ Google::Apis::DocsV1::UpdateDocumentStyleRequest
Updates the DocumentStyle.
Corresponds to the JSON property updateDocumentStyle
4889 4890 4891 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4889 def update_document_style @update_document_style end |
#update_document_tab_properties ⇒ Google::Apis::DocsV1::UpdateDocumentTabPropertiesRequest
Update the properties of a document tab.
Corresponds to the JSON property updateDocumentTabProperties
4894 4895 4896 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4894 def update_document_tab_properties @update_document_tab_properties end |
#update_named_style ⇒ Google::Apis::DocsV1::UpdateNamedStyleRequest
Updates a named style.
Corresponds to the JSON property updateNamedStyle
4899 4900 4901 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4899 def update_named_style @update_named_style end |
#update_paragraph_style ⇒ Google::Apis::DocsV1::UpdateParagraphStyleRequest
Update the styling of all paragraphs that overlap with the given range.
Corresponds to the JSON property updateParagraphStyle
4904 4905 4906 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4904 def update_paragraph_style @update_paragraph_style end |
#update_section_style ⇒ Google::Apis::DocsV1::UpdateSectionStyleRequest
Updates the SectionStyle.
Corresponds to the JSON property updateSectionStyle
4909 4910 4911 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4909 def update_section_style @update_section_style end |
#update_table_cell_style ⇒ Google::Apis::DocsV1::UpdateTableCellStyleRequest
Updates the style of a range of table cells.
Corresponds to the JSON property updateTableCellStyle
4914 4915 4916 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4914 def update_table_cell_style @update_table_cell_style end |
#update_table_column_properties ⇒ Google::Apis::DocsV1::UpdateTableColumnPropertiesRequest
Updates the TableColumnProperties of columns in a table.
Corresponds to the JSON property updateTableColumnProperties
4919 4920 4921 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4919 def update_table_column_properties @update_table_column_properties end |
#update_table_row_style ⇒ Google::Apis::DocsV1::UpdateTableRowStyleRequest
Updates the TableRowStyle of rows in a table.
Corresponds to the JSON property updateTableRowStyle
4924 4925 4926 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4924 def update_table_row_style @update_table_row_style end |
#update_text_style ⇒ Google::Apis::DocsV1::UpdateTextStyleRequest
Update the styling of text.
Corresponds to the JSON property updateTextStyle
4929 4930 4931 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4929 def update_text_style @update_text_style end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4936 4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 4969 4970 4971 4972 4973 4974 4975 4976 4977 |
# File 'lib/google/apis/docs_v1/classes.rb', line 4936 def update!(**args) @add_document_tab = args[:add_document_tab] if args.key?(:add_document_tab) @create_footer = args[:create_footer] if args.key?(:create_footer) @create_footnote = args[:create_footnote] if args.key?(:create_footnote) @create_header = args[:create_header] if args.key?(:create_header) @create_named_range = args[:create_named_range] if args.key?(:create_named_range) @create_paragraph_bullets = args[:create_paragraph_bullets] if args.key?(:create_paragraph_bullets) @delete_content_range = args[:delete_content_range] if args.key?(:delete_content_range) @delete_footer = args[:delete_footer] if args.key?(:delete_footer) @delete_header = args[:delete_header] if args.key?(:delete_header) @delete_named_range = args[:delete_named_range] if args.key?(:delete_named_range) @delete_paragraph_bullets = args[:delete_paragraph_bullets] if args.key?(:delete_paragraph_bullets) @delete_positioned_object = args[:delete_positioned_object] if args.key?(:delete_positioned_object) @delete_tab = args[:delete_tab] if args.key?(:delete_tab) @delete_table_column = args[:delete_table_column] if args.key?(:delete_table_column) @delete_table_row = args[:delete_table_row] if args.key?(:delete_table_row) @insert_date = args[:insert_date] if args.key?(:insert_date) @insert_inline_image = args[:insert_inline_image] if args.key?(:insert_inline_image) @insert_page_break = args[:insert_page_break] if args.key?(:insert_page_break) @insert_person = args[:insert_person] if args.key?(:insert_person) @insert_rich_link = args[:insert_rich_link] if args.key?(:insert_rich_link) @insert_section_break = args[:insert_section_break] if args.key?(:insert_section_break) @insert_table = args[:insert_table] if args.key?(:insert_table) @insert_table_column = args[:insert_table_column] if args.key?(:insert_table_column) @insert_table_row = args[:insert_table_row] if args.key?(:insert_table_row) @insert_text = args[:insert_text] if args.key?(:insert_text) @merge_table_cells = args[:merge_table_cells] if args.key?(:merge_table_cells) @pin_table_header_rows = args[:pin_table_header_rows] if args.key?(:pin_table_header_rows) @replace_all_text = args[:replace_all_text] if args.key?(:replace_all_text) @replace_image = args[:replace_image] if args.key?(:replace_image) @replace_named_range_content = args[:replace_named_range_content] if args.key?(:replace_named_range_content) @unmerge_table_cells = args[:unmerge_table_cells] if args.key?(:unmerge_table_cells) @update_document_style = args[:update_document_style] if args.key?(:update_document_style) @update_document_tab_properties = args[:update_document_tab_properties] if args.key?(:update_document_tab_properties) @update_named_style = args[:update_named_style] if args.key?(:update_named_style) @update_paragraph_style = args[:update_paragraph_style] if args.key?(:update_paragraph_style) @update_section_style = args[:update_section_style] if args.key?(:update_section_style) @update_table_cell_style = args[:update_table_cell_style] if args.key?(:update_table_cell_style) @update_table_column_properties = args[:update_table_column_properties] if args.key?(:update_table_column_properties) @update_table_row_style = args[:update_table_row_style] if args.key?(:update_table_row_style) @update_text_style = args[:update_text_style] if args.key?(:update_text_style) end |