Class: Google::Apis::DocsV1::RichLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

A link to a Google resource (such as a file in Drive, a YouTube video, or a Calendar event).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RichLink

Returns a new instance of RichLink.



5071
5072
5073
# File 'lib/google/apis/docs_v1/classes.rb', line 5071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Output only. The ID of this link. Corresponds to the JSON property richLinkId

Returns:

  • (String)


5030
5031
5032
# File 'lib/google/apis/docs_v1/classes.rb', line 5030

def rich_link_id
  @rich_link_id
end

Properties specific to a RichLink. Corresponds to the JSON property richLinkProperties



5035
5036
5037
# File 'lib/google/apis/docs_v1/classes.rb', line 5035

def rich_link_properties
  @rich_link_properties
end

#suggested_deletion_idsArray<String>

IDs for suggestions that remove this link from the document. A RichLink might have multiple deletion IDs if, for example, multiple users suggest deleting it. If empty, then this person link isn't suggested for deletion. Corresponds to the JSON property suggestedDeletionIds

Returns:

  • (Array<String>)


5042
5043
5044
# File 'lib/google/apis/docs_v1/classes.rb', line 5042

def suggested_deletion_ids
  @suggested_deletion_ids
end

#suggested_insertion_idsArray<String>

IDs for suggestions that insert this link into the document. A RichLink might have multiple insertion IDs if it's a nested suggested change (a suggestion within a suggestion made by a different user, for example). If empty, then this person link isn't a suggested insertion. Corresponds to the JSON property suggestedInsertionIds

Returns:

  • (Array<String>)


5050
5051
5052
# File 'lib/google/apis/docs_v1/classes.rb', line 5050

def suggested_insertion_ids
  @suggested_insertion_ids
end

#suggested_text_style_changesHash<String,Google::Apis::DocsV1::SuggestedTextStyle>

The suggested text style changes to this RichLink, keyed by suggestion ID. Corresponds to the JSON property suggestedTextStyleChanges



5055
5056
5057
# File 'lib/google/apis/docs_v1/classes.rb', line 5055

def suggested_text_style_changes
  @suggested_text_style_changes
end

#text_styleGoogle::Apis::DocsV1::TextStyle

Represents the styling that can be applied to text. Inherited text styles are represented as unset fields in this message. A text style's parent depends on where the text style is defined: * The TextStyle of text in a Paragraph inherits from the paragraph's corresponding named style type. * The TextStyle on a named style inherits from the normal text named style. * The TextStyle of the normal text named style inherits from the default text style in the Docs editor. * The TextStyle on a Paragraph element that's contained in a table may inherit its text style from the table style. If the text style does not inherit from a parent, unsetting fields will revert the style to a value matching the defaults in the Docs editor. Corresponds to the JSON property textStyle



5069
5070
5071
# File 'lib/google/apis/docs_v1/classes.rb', line 5069

def text_style
  @text_style
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5076
5077
5078
5079
5080
5081
5082
5083
# File 'lib/google/apis/docs_v1/classes.rb', line 5076

def update!(**args)
  @rich_link_id = args[:rich_link_id] if args.key?(:rich_link_id)
  @rich_link_properties = args[:rich_link_properties] if args.key?(:rich_link_properties)
  @suggested_deletion_ids = args[:suggested_deletion_ids] if args.key?(:suggested_deletion_ids)
  @suggested_insertion_ids = args[:suggested_insertion_ids] if args.key?(:suggested_insertion_ids)
  @suggested_text_style_changes = args[:suggested_text_style_changes] if args.key?(:suggested_text_style_changes)
  @text_style = args[:text_style] if args.key?(:text_style)
end