Class: Google::Apis::DocsV1::RichLinkProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Properties specific to a RichLink.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RichLinkProperties

Returns a new instance of RichLinkProperties.



5108
5109
5110
# File 'lib/google/apis/docs_v1/classes.rb', line 5108

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mime_typeString

The MIME type of the RichLink, if there's one (for example, when it's a file in Drive). Corresponds to the JSON property mimeType

Returns:

  • (String)


5094
5095
5096
# File 'lib/google/apis/docs_v1/classes.rb', line 5094

def mime_type
  @mime_type
end

#titleString

The title of the RichLink as displayed in the link. This title matches the title of the linked resource at the time of the insertion or last update of the link. This field is always present. Corresponds to the JSON property title

Returns:

  • (String)


5101
5102
5103
# File 'lib/google/apis/docs_v1/classes.rb', line 5101

def title
  @title
end

#uriString

The URI to the RichLink. This is always present. Corresponds to the JSON property uri

Returns:

  • (String)


5106
5107
5108
# File 'lib/google/apis/docs_v1/classes.rb', line 5106

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5113
5114
5115
5116
5117
# File 'lib/google/apis/docs_v1/classes.rb', line 5113

def update!(**args)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end