Class: Google::Apis::DocsV1::SectionStyle
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::SectionStyle
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
The styling that applies to a section.
Instance Attribute Summary collapse
-
#column_properties ⇒ Array<Google::Apis::DocsV1::SectionColumnProperties>
The section's columns properties.
-
#column_separator_style ⇒ String
The style of column separators.
-
#content_direction ⇒ String
The content direction of this section.
-
#default_footer_id ⇒ String
The ID of the default footer.
-
#default_header_id ⇒ String
The ID of the default header.
-
#even_page_footer_id ⇒ String
The ID of the footer used only for even pages.
-
#even_page_header_id ⇒ String
The ID of the header used only for even pages.
-
#first_page_footer_id ⇒ String
The ID of the footer used only for the first page of the section.
-
#first_page_header_id ⇒ String
The ID of the header used only for the first page of the section.
-
#flip_page_orientation ⇒ Boolean
(also: #flip_page_orientation?)
Optional.
-
#margin_bottom ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#margin_footer ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#margin_header ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#margin_left ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#margin_right ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#margin_top ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#page_number_start ⇒ Fixnum
The page number from which to start counting the number of pages for this section.
-
#section_type ⇒ String
Output only.
-
#use_first_page_header_footer ⇒ Boolean
(also: #use_first_page_header_footer?)
Indicates whether to use the first page header / footer IDs for the first page of the section.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SectionStyle
constructor
A new instance of SectionStyle.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SectionStyle
Returns a new instance of SectionStyle.
5389 5390 5391 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column_properties ⇒ Array<Google::Apis::DocsV1::SectionColumnProperties>
The section's columns properties. If empty, the section contains one column
with the default properties in the Docs editor. A section can be updated to
have no more than 3 columns. When updating this property, setting a concrete
value is required. Unsetting this property will result in a 400 bad request
error.
Corresponds to the JSON property columnProperties
5243 5244 5245 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5243 def column_properties @column_properties end |
#column_separator_style ⇒ String
The style of column separators. This style can be set even when there's one
column in the section. When updating this property, setting a concrete value
is required. Unsetting this property results in a 400 bad request error.
Corresponds to the JSON property columnSeparatorStyle
5250 5251 5252 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5250 def column_separator_style @column_separator_style end |
#content_direction ⇒ String
The content direction of this section. If unset, the value defaults to
LEFT_TO_RIGHT. When updating this property, setting a concrete value is
required. Unsetting this property results in a 400 bad request error.
Corresponds to the JSON property contentDirection
5257 5258 5259 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5257 def content_direction @content_direction end |
#default_footer_id ⇒ String
The ID of the default footer. If unset, the value inherits from the previous
SectionBreak's SectionStyle. If the value is unset in the first SectionBreak,
it inherits from DocumentStyle's default_footer_id. If DocumentMode is
PAGELESS, this property will not be rendered. This property is read-only.
Corresponds to the JSON property defaultFooterId
5265 5266 5267 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5265 def @default_footer_id end |
#default_header_id ⇒ String
The ID of the default header. If unset, the value inherits from the previous
SectionBreak's SectionStyle. If the value is unset in the first SectionBreak,
it inherits from DocumentStyle's default_header_id. If DocumentMode is
PAGELESS, this property will not be rendered. This property is read-only.
Corresponds to the JSON property defaultHeaderId
5273 5274 5275 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5273 def default_header_id @default_header_id end |
#even_page_footer_id ⇒ String
The ID of the footer used only for even pages. If the value of DocumentStyle's
use_even_page_header_footer is true, this value is used for the footers on
even pages in the section. If it is false, the footers on even pages use the
default_footer_id. If unset, the value inherits from the previous SectionBreak'
s SectionStyle. If the value is unset in the first SectionBreak, it inherits
from DocumentStyle's even_page_footer_id. If DocumentMode is PAGELESS, this
property will not be rendered. This property is read-only.
Corresponds to the JSON property evenPageFooterId
5284 5285 5286 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5284 def @even_page_footer_id end |
#even_page_header_id ⇒ String
The ID of the header used only for even pages. If the value of DocumentStyle's
use_even_page_header_footer is true, this value is used for the headers on
even pages in the section. If it is false, the headers on even pages use the
default_header_id. If unset, the value inherits from the previous SectionBreak'
s SectionStyle. If the value is unset in the first SectionBreak, it inherits
from DocumentStyle's even_page_header_id. If DocumentMode is PAGELESS, this
property will not be rendered. This property is read-only.
Corresponds to the JSON property evenPageHeaderId
5295 5296 5297 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5295 def even_page_header_id @even_page_header_id end |
#first_page_footer_id ⇒ String
The ID of the footer used only for the first page of the section. If
use_first_page_header_footer is true, this value is used for the footer on the
first page of the section. If it's false, the footer on the first page of the
section uses the default_footer_id. If unset, the value inherits from the
previous SectionBreak's SectionStyle. If the value is unset in the first
SectionBreak, it inherits from DocumentStyle's first_page_footer_id. If
DocumentMode is PAGELESS, this property will not be rendered. This property is
read-only.
Corresponds to the JSON property firstPageFooterId
5307 5308 5309 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5307 def @first_page_footer_id end |
#first_page_header_id ⇒ String
The ID of the header used only for the first page of the section. If
use_first_page_header_footer is true, this value is used for the header on the
first page of the section. If it's false, the header on the first page of the
section uses the default_header_id. If unset, the value inherits from the
previous SectionBreak's SectionStyle. If the value is unset in the first
SectionBreak, it inherits from DocumentStyle's first_page_header_id. If
DocumentMode is PAGELESS, this property will not be rendered. This property is
read-only.
Corresponds to the JSON property firstPageHeaderId
5319 5320 5321 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5319 def first_page_header_id @first_page_header_id end |
#flip_page_orientation ⇒ Boolean Also known as: flip_page_orientation?
Optional. Indicates whether to flip the dimensions of DocumentStyle's
page_size for this section, which allows changing the page orientation between
portrait and landscape. If unset, the value inherits from DocumentStyle's
flip_page_orientation. If DocumentMode is PAGELESS, this property will not be
rendered. When updating this property, setting a concrete value is required.
Unsetting this property results in a 400 bad request error.
Corresponds to the JSON property flipPageOrientation
5329 5330 5331 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5329 def flip_page_orientation @flip_page_orientation end |
#margin_bottom ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property marginBottom
5335 5336 5337 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5335 def margin_bottom @margin_bottom end |
#margin_footer ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property marginFooter
5340 5341 5342 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5340 def @margin_footer end |
#margin_header ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property marginHeader
5345 5346 5347 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5345 def margin_header @margin_header end |
#margin_left ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property marginLeft
5350 5351 5352 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5350 def margin_left @margin_left end |
#margin_right ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property marginRight
5355 5356 5357 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5355 def margin_right @margin_right end |
#margin_top ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property marginTop
5360 5361 5362 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5360 def margin_top @margin_top end |
#page_number_start ⇒ Fixnum
The page number from which to start counting the number of pages for this
section. If unset, page numbering continues from the previous section. If the
value is unset in the first SectionBreak, refer to DocumentStyle's
page_number_start. If DocumentMode is PAGELESS, this property will not be
rendered. When updating this property, setting a concrete value is required.
Unsetting this property results in a 400 bad request error.
Corresponds to the JSON property pageNumberStart
5370 5371 5372 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5370 def page_number_start @page_number_start end |
#section_type ⇒ String
Output only. The type of section.
Corresponds to the JSON property sectionType
5375 5376 5377 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5375 def section_type @section_type end |
#use_first_page_header_footer ⇒ Boolean Also known as:
Indicates whether to use the first page header / footer IDs for the first page
of the section. If unset, it inherits from DocumentStyle's
use_first_page_header_footer for the first section. If the value is unset for
subsequent sectors, it should be interpreted as false. If DocumentMode is
PAGELESS, this property will not be rendered. When updating this property,
setting a concrete value is required. Unsetting this property results in a 400
bad request error.
Corresponds to the JSON property useFirstPageHeaderFooter
5386 5387 5388 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5386 def @use_first_page_header_footer end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5394 5395 5396 5397 5398 5399 5400 5401 5402 5403 5404 5405 5406 5407 5408 5409 5410 5411 5412 5413 5414 |
# File 'lib/google/apis/docs_v1/classes.rb', line 5394 def update!(**args) @column_properties = args[:column_properties] if args.key?(:column_properties) @column_separator_style = args[:column_separator_style] if args.key?(:column_separator_style) @content_direction = args[:content_direction] if args.key?(:content_direction) @default_footer_id = args[:default_footer_id] if args.key?(:default_footer_id) @default_header_id = args[:default_header_id] if args.key?(:default_header_id) @even_page_footer_id = args[:even_page_footer_id] if args.key?(:even_page_footer_id) @even_page_header_id = args[:even_page_header_id] if args.key?(:even_page_header_id) @first_page_footer_id = args[:first_page_footer_id] if args.key?(:first_page_footer_id) @first_page_header_id = args[:first_page_header_id] if args.key?(:first_page_header_id) @flip_page_orientation = args[:flip_page_orientation] if args.key?(:flip_page_orientation) @margin_bottom = args[:margin_bottom] if args.key?(:margin_bottom) @margin_footer = args[:margin_footer] if args.key?(:margin_footer) @margin_header = args[:margin_header] if args.key?(:margin_header) @margin_left = args[:margin_left] if args.key?(:margin_left) @margin_right = args[:margin_right] if args.key?(:margin_right) @margin_top = args[:margin_top] if args.key?(:margin_top) @page_number_start = args[:page_number_start] if args.key?(:page_number_start) @section_type = args[:section_type] if args.key?(:section_type) @use_first_page_header_footer = args[:use_first_page_header_footer] if args.key?(:use_first_page_header_footer) end |