Class: Google::Apis::DocsV1::TabProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

Properties of a tab.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TabProperties

Returns a new instance of TabProperties.



6044
6045
6046
# File 'lib/google/apis/docs_v1/classes.rb', line 6044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#icon_emojiString

Optional. The emoji icon displayed with the tab. A valid emoji icon is represented by a non-empty Unicode string. Any set of characters that don't represent a single emoji is invalid. If an emoji is invalid, a 400 bad request error is returned. If this value is unset or empty, the tab will display the default tab icon. Corresponds to the JSON property iconEmoji

Returns:

  • (String)


6015
6016
6017
# File 'lib/google/apis/docs_v1/classes.rb', line 6015

def icon_emoji
  @icon_emoji
end

#indexFixnum

The zero-based index of the tab within the parent. Corresponds to the JSON property index

Returns:

  • (Fixnum)


6020
6021
6022
# File 'lib/google/apis/docs_v1/classes.rb', line 6020

def index
  @index
end

#nesting_levelFixnum

Output only. The depth of the tab within the document. Root-level tabs start at 0. Corresponds to the JSON property nestingLevel

Returns:

  • (Fixnum)


6026
6027
6028
# File 'lib/google/apis/docs_v1/classes.rb', line 6026

def nesting_level
  @nesting_level
end

#parent_tab_idString

Optional. The ID of the parent tab. Empty when the current tab is a root-level tab, which means it doesn't have any parents. Corresponds to the JSON property parentTabId

Returns:

  • (String)


6032
6033
6034
# File 'lib/google/apis/docs_v1/classes.rb', line 6032

def parent_tab_id
  @parent_tab_id
end

#tab_idString

The immutable ID of the tab. Corresponds to the JSON property tabId

Returns:

  • (String)


6037
6038
6039
# File 'lib/google/apis/docs_v1/classes.rb', line 6037

def tab_id
  @tab_id
end

#titleString

The user-visible name of the tab. Corresponds to the JSON property title

Returns:

  • (String)


6042
6043
6044
# File 'lib/google/apis/docs_v1/classes.rb', line 6042

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6049
6050
6051
6052
6053
6054
6055
6056
# File 'lib/google/apis/docs_v1/classes.rb', line 6049

def update!(**args)
  @icon_emoji = args[:icon_emoji] if args.key?(:icon_emoji)
  @index = args[:index] if args.key?(:index)
  @nesting_level = args[:nesting_level] if args.key?(:nesting_level)
  @parent_tab_id = args[:parent_tab_id] if args.key?(:parent_tab_id)
  @tab_id = args[:tab_id] if args.key?(:tab_id)
  @title = args[:title] if args.key?(:title)
end