Class: Google::Apis::DocsV1::Table

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

A StructuralElement representing a table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Table

Returns a new instance of Table.



6121
6122
6123
# File 'lib/google/apis/docs_v1/classes.rb', line 6121

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnsFixnum

Number of columns in the table. It's possible for a table to be non- rectangular, so some rows may have a different number of cells. Corresponds to the JSON property columns

Returns:

  • (Fixnum)


6092
6093
6094
# File 'lib/google/apis/docs_v1/classes.rb', line 6092

def columns
  @columns
end

#rowsFixnum

Number of rows in the table. Corresponds to the JSON property rows

Returns:

  • (Fixnum)


6097
6098
6099
# File 'lib/google/apis/docs_v1/classes.rb', line 6097

def rows
  @rows
end

#suggested_deletion_idsArray<String>

The suggested deletion IDs. If empty, then there are no suggested deletions of this content. Corresponds to the JSON property suggestedDeletionIds

Returns:

  • (Array<String>)


6103
6104
6105
# File 'lib/google/apis/docs_v1/classes.rb', line 6103

def suggested_deletion_ids
  @suggested_deletion_ids
end

#suggested_insertion_idsArray<String>

The suggested insertion IDs. A Table may have multiple insertion IDs if it's a nested suggested change. If empty, then this is not a suggested insertion. Corresponds to the JSON property suggestedInsertionIds

Returns:

  • (Array<String>)


6109
6110
6111
# File 'lib/google/apis/docs_v1/classes.rb', line 6109

def suggested_insertion_ids
  @suggested_insertion_ids
end

#table_rowsArray<Google::Apis::DocsV1::TableRow>

The contents and style of each row. Corresponds to the JSON property tableRows

Returns:



6114
6115
6116
# File 'lib/google/apis/docs_v1/classes.rb', line 6114

def table_rows
  @table_rows
end

#table_styleGoogle::Apis::DocsV1::TableStyle

Styles that apply to a table. Corresponds to the JSON property tableStyle



6119
6120
6121
# File 'lib/google/apis/docs_v1/classes.rb', line 6119

def table_style
  @table_style
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6126
6127
6128
6129
6130
6131
6132
6133
# File 'lib/google/apis/docs_v1/classes.rb', line 6126

def update!(**args)
  @columns = args[:columns] if args.key?(:columns)
  @rows = args[:rows] if args.key?(:rows)
  @suggested_deletion_ids = args[:suggested_deletion_ids] if args.key?(:suggested_deletion_ids)
  @suggested_insertion_ids = args[:suggested_insertion_ids] if args.key?(:suggested_insertion_ids)
  @table_rows = args[:table_rows] if args.key?(:table_rows)
  @table_style = args[:table_style] if args.key?(:table_style)
end