Class: Google::Apis::DocsV1::TableCellStyle
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::TableCellStyle
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
The style of a TableCell. Inherited table cell styles are represented as unset fields in this message. A table cell style can inherit from the table's style.
Instance Attribute Summary collapse
-
#background_color ⇒ Google::Apis::DocsV1::OptionalColor
A color that can either be fully opaque or fully transparent.
-
#border_bottom ⇒ Google::Apis::DocsV1::TableCellBorder
A border around a table cell.
-
#border_left ⇒ Google::Apis::DocsV1::TableCellBorder
A border around a table cell.
-
#border_right ⇒ Google::Apis::DocsV1::TableCellBorder
A border around a table cell.
-
#border_top ⇒ Google::Apis::DocsV1::TableCellBorder
A border around a table cell.
-
#column_span ⇒ Fixnum
The column span of the cell.
-
#content_alignment ⇒ String
The alignment of the content in the table cell.
-
#padding_bottom ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#padding_left ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#padding_right ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#padding_top ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#row_span ⇒ Fixnum
The row span of the cell.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TableCellStyle
constructor
A new instance of TableCellStyle.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TableCellStyle
Returns a new instance of TableCellStyle.
6329 6330 6331 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6329 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background_color ⇒ Google::Apis::DocsV1::OptionalColor
A color that can either be fully opaque or fully transparent.
Corresponds to the JSON property backgroundColor
6267 6268 6269 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6267 def background_color @background_color end |
#border_bottom ⇒ Google::Apis::DocsV1::TableCellBorder
A border around a table cell. Table cell borders cannot be transparent. To
hide a table cell border, make its width 0.
Corresponds to the JSON property borderBottom
6273 6274 6275 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6273 def border_bottom @border_bottom end |
#border_left ⇒ Google::Apis::DocsV1::TableCellBorder
A border around a table cell. Table cell borders cannot be transparent. To
hide a table cell border, make its width 0.
Corresponds to the JSON property borderLeft
6279 6280 6281 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6279 def border_left @border_left end |
#border_right ⇒ Google::Apis::DocsV1::TableCellBorder
A border around a table cell. Table cell borders cannot be transparent. To
hide a table cell border, make its width 0.
Corresponds to the JSON property borderRight
6285 6286 6287 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6285 def border_right @border_right end |
#border_top ⇒ Google::Apis::DocsV1::TableCellBorder
A border around a table cell. Table cell borders cannot be transparent. To
hide a table cell border, make its width 0.
Corresponds to the JSON property borderTop
6291 6292 6293 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6291 def border_top @border_top end |
#column_span ⇒ Fixnum
The column span of the cell. This property is read-only.
Corresponds to the JSON property columnSpan
6296 6297 6298 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6296 def column_span @column_span end |
#content_alignment ⇒ String
The alignment of the content in the table cell. The default alignment matches
the alignment for newly created table cells in the Docs editor.
Corresponds to the JSON property contentAlignment
6302 6303 6304 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6302 def content_alignment @content_alignment end |
#padding_bottom ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property paddingBottom
6307 6308 6309 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6307 def padding_bottom @padding_bottom end |
#padding_left ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property paddingLeft
6312 6313 6314 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6312 def padding_left @padding_left end |
#padding_right ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property paddingRight
6317 6318 6319 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6317 def padding_right @padding_right end |
#padding_top ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property paddingTop
6322 6323 6324 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6322 def padding_top @padding_top end |
#row_span ⇒ Fixnum
The row span of the cell. This property is read-only.
Corresponds to the JSON property rowSpan
6327 6328 6329 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6327 def row_span @row_span end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6334 def update!(**args) @background_color = args[:background_color] if args.key?(:background_color) @border_bottom = args[:border_bottom] if args.key?(:border_bottom) @border_left = args[:border_left] if args.key?(:border_left) @border_right = args[:border_right] if args.key?(:border_right) @border_top = args[:border_top] if args.key?(:border_top) @column_span = args[:column_span] if args.key?(:column_span) @content_alignment = args[:content_alignment] if args.key?(:content_alignment) @padding_bottom = args[:padding_bottom] if args.key?(:padding_bottom) @padding_left = args[:padding_left] if args.key?(:padding_left) @padding_right = args[:padding_right] if args.key?(:padding_right) @padding_top = args[:padding_top] if args.key?(:padding_top) @row_span = args[:row_span] if args.key?(:row_span) end |