Class: Google::Apis::DocsV1::TableCellStyle
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::TableCellStyle
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
The style of a TableCell. Inherited table cell styles are represented as unset fields in this message. A table cell style can inherit from the table's style.
Instance Attribute Summary collapse
-
#background_color ⇒ Google::Apis::DocsV1::OptionalColor
A color that can either be fully opaque or fully transparent.
-
#border_bottom ⇒ Google::Apis::DocsV1::TableCellBorder
A border around a table cell.
-
#border_left ⇒ Google::Apis::DocsV1::TableCellBorder
A border around a table cell.
-
#border_right ⇒ Google::Apis::DocsV1::TableCellBorder
A border around a table cell.
-
#border_top ⇒ Google::Apis::DocsV1::TableCellBorder
A border around a table cell.
-
#column_span ⇒ Fixnum
The column span of the cell.
-
#content_alignment ⇒ String
The alignment of the content in the table cell.
-
#padding_bottom ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#padding_left ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#padding_right ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#padding_top ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
-
#row_span ⇒ Fixnum
The row span of the cell.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TableCellStyle
constructor
A new instance of TableCellStyle.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TableCellStyle
Returns a new instance of TableCellStyle.
6330 6331 6332 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6330 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background_color ⇒ Google::Apis::DocsV1::OptionalColor
A color that can either be fully opaque or fully transparent.
Corresponds to the JSON property backgroundColor
6268 6269 6270 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6268 def background_color @background_color end |
#border_bottom ⇒ Google::Apis::DocsV1::TableCellBorder
A border around a table cell. Table cell borders cannot be transparent. To
hide a table cell border, make its width 0.
Corresponds to the JSON property borderBottom
6274 6275 6276 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6274 def border_bottom @border_bottom end |
#border_left ⇒ Google::Apis::DocsV1::TableCellBorder
A border around a table cell. Table cell borders cannot be transparent. To
hide a table cell border, make its width 0.
Corresponds to the JSON property borderLeft
6280 6281 6282 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6280 def border_left @border_left end |
#border_right ⇒ Google::Apis::DocsV1::TableCellBorder
A border around a table cell. Table cell borders cannot be transparent. To
hide a table cell border, make its width 0.
Corresponds to the JSON property borderRight
6286 6287 6288 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6286 def border_right @border_right end |
#border_top ⇒ Google::Apis::DocsV1::TableCellBorder
A border around a table cell. Table cell borders cannot be transparent. To
hide a table cell border, make its width 0.
Corresponds to the JSON property borderTop
6292 6293 6294 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6292 def border_top @border_top end |
#column_span ⇒ Fixnum
The column span of the cell. This property is read-only.
Corresponds to the JSON property columnSpan
6297 6298 6299 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6297 def column_span @column_span end |
#content_alignment ⇒ String
The alignment of the content in the table cell. The default alignment matches
the alignment for newly created table cells in the Docs editor.
Corresponds to the JSON property contentAlignment
6303 6304 6305 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6303 def content_alignment @content_alignment end |
#padding_bottom ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property paddingBottom
6308 6309 6310 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6308 def padding_bottom @padding_bottom end |
#padding_left ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property paddingLeft
6313 6314 6315 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6313 def padding_left @padding_left end |
#padding_right ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property paddingRight
6318 6319 6320 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6318 def padding_right @padding_right end |
#padding_top ⇒ Google::Apis::DocsV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property paddingTop
6323 6324 6325 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6323 def padding_top @padding_top end |
#row_span ⇒ Fixnum
The row span of the cell. This property is read-only.
Corresponds to the JSON property rowSpan
6328 6329 6330 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6328 def row_span @row_span end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 |
# File 'lib/google/apis/docs_v1/classes.rb', line 6335 def update!(**args) @background_color = args[:background_color] if args.key?(:background_color) @border_bottom = args[:border_bottom] if args.key?(:border_bottom) @border_left = args[:border_left] if args.key?(:border_left) @border_right = args[:border_right] if args.key?(:border_right) @border_top = args[:border_top] if args.key?(:border_top) @column_span = args[:column_span] if args.key?(:column_span) @content_alignment = args[:content_alignment] if args.key?(:content_alignment) @padding_bottom = args[:padding_bottom] if args.key?(:padding_bottom) @padding_left = args[:padding_left] if args.key?(:padding_left) @padding_right = args[:padding_right] if args.key?(:padding_right) @padding_top = args[:padding_top] if args.key?(:padding_top) @row_span = args[:row_span] if args.key?(:row_span) end |