Class: Google::Apis::DocsV1::TextStyleSuggestionState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb

Overview

A mask that indicates which of the fields on the base TextStyle have been changed in this suggestion. For any field set to true, there's a new suggested value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TextStyleSuggestionState

Returns a new instance of TextStyleSuggestionState.



6921
6922
6923
# File 'lib/google/apis/docs_v1/classes.rb', line 6921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#background_color_suggestedBoolean Also known as: background_color_suggested?

Indicates if there was a suggested change to background_color. Corresponds to the JSON property backgroundColorSuggested

Returns:

  • (Boolean)


6858
6859
6860
# File 'lib/google/apis/docs_v1/classes.rb', line 6858

def background_color_suggested
  @background_color_suggested
end

#baseline_offset_suggestedBoolean Also known as: baseline_offset_suggested?

Indicates if there was a suggested change to baseline_offset. Corresponds to the JSON property baselineOffsetSuggested

Returns:

  • (Boolean)


6864
6865
6866
# File 'lib/google/apis/docs_v1/classes.rb', line 6864

def baseline_offset_suggested
  @baseline_offset_suggested
end

#bold_suggestedBoolean Also known as: bold_suggested?

Indicates if there was a suggested change to bold. Corresponds to the JSON property boldSuggested

Returns:

  • (Boolean)


6870
6871
6872
# File 'lib/google/apis/docs_v1/classes.rb', line 6870

def bold_suggested
  @bold_suggested
end

#font_size_suggestedBoolean Also known as: font_size_suggested?

Indicates if there was a suggested change to font_size. Corresponds to the JSON property fontSizeSuggested

Returns:

  • (Boolean)


6876
6877
6878
# File 'lib/google/apis/docs_v1/classes.rb', line 6876

def font_size_suggested
  @font_size_suggested
end

#foreground_color_suggestedBoolean Also known as: foreground_color_suggested?

Indicates if there was a suggested change to foreground_color. Corresponds to the JSON property foregroundColorSuggested

Returns:

  • (Boolean)


6882
6883
6884
# File 'lib/google/apis/docs_v1/classes.rb', line 6882

def foreground_color_suggested
  @foreground_color_suggested
end

#italic_suggestedBoolean Also known as: italic_suggested?

Indicates if there was a suggested change to italic. Corresponds to the JSON property italicSuggested

Returns:

  • (Boolean)


6888
6889
6890
# File 'lib/google/apis/docs_v1/classes.rb', line 6888

def italic_suggested
  @italic_suggested
end

Indicates if there was a suggested change to link. Corresponds to the JSON property linkSuggested

Returns:

  • (Boolean)


6894
6895
6896
# File 'lib/google/apis/docs_v1/classes.rb', line 6894

def link_suggested
  @link_suggested
end

#small_caps_suggestedBoolean Also known as: small_caps_suggested?

Indicates if there was a suggested change to small_caps. Corresponds to the JSON property smallCapsSuggested

Returns:

  • (Boolean)


6900
6901
6902
# File 'lib/google/apis/docs_v1/classes.rb', line 6900

def small_caps_suggested
  @small_caps_suggested
end

#strikethrough_suggestedBoolean Also known as: strikethrough_suggested?

Indicates if there was a suggested change to strikethrough. Corresponds to the JSON property strikethroughSuggested

Returns:

  • (Boolean)


6906
6907
6908
# File 'lib/google/apis/docs_v1/classes.rb', line 6906

def strikethrough_suggested
  @strikethrough_suggested
end

#underline_suggestedBoolean Also known as: underline_suggested?

Indicates if there was a suggested change to underline. Corresponds to the JSON property underlineSuggested

Returns:

  • (Boolean)


6912
6913
6914
# File 'lib/google/apis/docs_v1/classes.rb', line 6912

def underline_suggested
  @underline_suggested
end

#weighted_font_family_suggestedBoolean Also known as: weighted_font_family_suggested?

Indicates if there was a suggested change to weighted_font_family. Corresponds to the JSON property weightedFontFamilySuggested

Returns:

  • (Boolean)


6918
6919
6920
# File 'lib/google/apis/docs_v1/classes.rb', line 6918

def weighted_font_family_suggested
  @weighted_font_family_suggested
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6926
6927
6928
6929
6930
6931
6932
6933
6934
6935
6936
6937
6938
# File 'lib/google/apis/docs_v1/classes.rb', line 6926

def update!(**args)
  @background_color_suggested = args[:background_color_suggested] if args.key?(:background_color_suggested)
  @baseline_offset_suggested = args[:baseline_offset_suggested] if args.key?(:baseline_offset_suggested)
  @bold_suggested = args[:bold_suggested] if args.key?(:bold_suggested)
  @font_size_suggested = args[:font_size_suggested] if args.key?(:font_size_suggested)
  @foreground_color_suggested = args[:foreground_color_suggested] if args.key?(:foreground_color_suggested)
  @italic_suggested = args[:italic_suggested] if args.key?(:italic_suggested)
  @link_suggested = args[:link_suggested] if args.key?(:link_suggested)
  @small_caps_suggested = args[:small_caps_suggested] if args.key?(:small_caps_suggested)
  @strikethrough_suggested = args[:strikethrough_suggested] if args.key?(:strikethrough_suggested)
  @underline_suggested = args[:underline_suggested] if args.key?(:underline_suggested)
  @weighted_font_family_suggested = args[:weighted_font_family_suggested] if args.key?(:weighted_font_family_suggested)
end