Class: Google::Apis::DocsV1::UpdateNamedStyleRequest
- Inherits:
-
Object
- Object
- Google::Apis::DocsV1::UpdateNamedStyleRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/docs_v1/classes.rb,
lib/google/apis/docs_v1/representations.rb,
lib/google/apis/docs_v1/representations.rb
Overview
Updates a named style.
Instance Attribute Summary collapse
-
#fields ⇒ String
The NamedStyle fields that should be updated.
-
#named_style ⇒ Google::Apis::DocsV1::NamedStyle
A named style.
-
#tab_id ⇒ String
The document tab to update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateNamedStyleRequest
constructor
A new instance of UpdateNamedStyleRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateNamedStyleRequest
Returns a new instance of UpdateNamedStyleRequest.
7060 7061 7062 |
# File 'lib/google/apis/docs_v1/classes.rb', line 7060 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fields ⇒ String
The NamedStyle fields that should be updated. At least named_style_type must
be specified. The rootnamed_styleis implied and should not be specified. A
single"*"can be used as short-hand for listing every field. For example,
to update the text style to bold, setfieldsto include"text_style"and"
text_style.bold". To update the paragraph style's alignment property, set
fieldsto include"paragraph_style"and"paragraph_style.alignment". To
reset a property to its default value, include its field name in the field
mask but leave the field itself unset. Specifying"text_style"or"
paragraph_style"with an empty TextStyle or ParagraphStyle will reset all of
its nested fields.
Corresponds to the JSON propertyfields`
7047 7048 7049 |
# File 'lib/google/apis/docs_v1/classes.rb', line 7047 def fields @fields end |
#named_style ⇒ Google::Apis::DocsV1::NamedStyle
A named style. Paragraphs in the document can inherit their TextStyle and
ParagraphStyle from this named style when they have the same named style type.
Corresponds to the JSON property namedStyle
7053 7054 7055 |
# File 'lib/google/apis/docs_v1/classes.rb', line 7053 def named_style @named_style end |
#tab_id ⇒ String
The document tab to update. By default, the update is applied to the first tab.
Corresponds to the JSON property tabId
7058 7059 7060 |
# File 'lib/google/apis/docs_v1/classes.rb', line 7058 def tab_id @tab_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7065 7066 7067 7068 7069 |
# File 'lib/google/apis/docs_v1/classes.rb', line 7065 def update!(**args) @fields = args[:fields] if args.key?(:fields) @named_style = args[:named_style] if args.key?(:named_style) @tab_id = args[:tab_id] if args.key?(:tab_id) end |